#!/bin/bash

write_postfix_initscript() {
cat > /etc/rc.d/init.d/postfix << "EOF"
#!/bin/sh
# Begin $rc_base/init.d/postfix

# Based on sysklogd script from LFS-3.1 and earlier.
# Rewritten by Gerard Beekmans  - gerard@linuxfromscratch.org

#$LastChangedBy: bdubbs $
#$Date: 2005-08-01 14:29:19 -0500 (Mon, 01 Aug 2005) $

. /etc/sysconfig/rc
. $rc_functions

case "$1" in
	start)
		boot_mesg "Starting Postfix..."
		loadproc /usr/sbin/postfix start
		;;

	stop)
		boot_mesg "Stopping Postfix..."
		loadproc /usr/sbin/postfix stop
		;;

	reload)
		boot_mesg "Reloading Postfix..."
		loadproc /usr/sbin/postfix reload
		;;

	abort)
		boot_mesg "Aborting Postfix..."
		loadproc /usr/sbin/postfix abort
		;;

	flush)
		boot_mesg "Flushing Postfix..."
		loadproc /usr/sbin/postfix flush
		;;

	check)
		boot_mesg "Checking Postfix..."
		loadproc /usr/sbin/postfix check
		;;

	restart)
		$0 stop
		sleep 1
		$0 start
		;;
	status)
		PID=`pidof /usr/lib/postfix/master`
		MPID=`cat /var/spool/postfix/pid/master.pid`
		if [ ${MPID} = ${PID} ]; then
			echo -e "${INFO}postfix is running with Process"\
			"ID(s) ${MPID}.${NORMAL}"
		fi
		;;

	*)
		echo "Usage: $0 {start|stop|reload|abort|flush|check|restart}"
		exit 1
		;;
esac

# End $rc_base/init.d/postfix
EOF
chmod 755 /etc/rc.d/init.d/postfix 
}

write_amavisd_initscript() {
cat > /etc/rc.d/init.d/amavisd << "EOF"
#!/bin/sh
########################################################################
# Begin $rc_base/init.d/amavisd
#
# Description : Amavisd Init Script
#
# Authors     : Michael Tremer (ms@ipfire.org)
#
# Version     : 01.00
#
# Notes       :
#
########################################################################

. /etc/sysconfig/rc
. ${rc_functions}

case "${1}" in
	start)
		boot_mesg "Starting AMaViS Daemon..."
		loadproc /usr/bin/amavisd
		;;

	stop)
		boot_mesg "Stopping AMaViS Daemon..."
		killproc /usr/bin/amavisd
		;;

	restart)
		${0} stop
		sleep 1
		${0} start
		;;

	status)
		statusproc /usr/bin/amavisd
		;;

	*)
		echo "Usage: ${0} {start|stop|restart|status}"
		exit 1
		;;
esac

# End $rc_base/init.d/amavisd
EOF
chmod 755 /etc/rc.d/init.d/amavisd 
}

write_spamassassin_initscript() {
cat > /etc/rc.d/init.d/spamassassin << "EOF"
#!/bin/sh
########################################################################
# Begin $rc_base/init.d/spamassassin
#
# Description : Spamassassin Init Script
#
# Authors     : Michael Tremer (ms@ipfire.org)
#
# Version     : 01.00
#
# Notes       :
#
########################################################################

. /etc/sysconfig/rc
. ${rc_functions}

case "${1}" in
	start)
		boot_mesg "Starting Spamassassin Daemon..."
		loadproc -n 10 /usr/bin/spamd -d
		;;

	stop)
		boot_mesg "Stopping Spamassassin Daemon..."
		killproc /usr/bin/spamd
		;;

	restart)
		${0} stop
		sleep 1
		${0} start
		;;

	status)
		statusproc /usr/bin/spamd
		;;

	*)
		echo "Usage: ${0} {start|stop|restart|status}"
		exit 1
		;;
esac

# End $rc_base/init.d/spamassassin
EOF
chmod 755 /etc/rc.d/init.d/spamassassin
}
 
