#!/usr/bin/perl
###############################################################################
#                                                                             #
# IPFire.org - A linux based firewall                                         #
# Copyright (C) 2005-2022  IPFire Team  <info@ipfire.org>                     #
#                                                                             #
# This program is free software: you can redistribute it and/or modify        #
# it under the terms of the GNU General Public License as published by        #
# the Free Software Foundation, either version 3 of the License, or           #
# (at your option) any later version.                                         #
#                                                                             #
# This program is distributed in the hope that it will be useful,             #
# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
# GNU General Public License for more details.                                #
#                                                                             #
# You should have received a copy of the GNU General Public License           #
# along with this program.  If not, see <http://www.gnu.org/licenses/>.       #
#                                                                             #
###############################################################################
use strict;

# enable only the following on debugging purpose
use warnings;
use CGI::Carp 'fatalsToBrowser';

require '/var/ipfire/general-functions.pl';
require "${General::swroot}/lang.pl";
require "${General::swroot}/header.pl";
require "${General::swroot}/countries.pl";

my $cfgdir = "${General::swroot}/mailgateway";
my $mainconf = "$cfgdir/main.conf";
my $certconf = "$cfgdir/certs.conf";
my %mainsettings=();
my %certsettings=();
my %checked=();
my %selected=();
my @dhlength=("2048", "3072", "4096");
my @certype=("0", "1");
my @certhashes=("sha", "sha256", "sha384", "sha512");
my @certcurves=("secp256k1", "secp384r1", "secp521r1", "brainpoolP256r1", "brainpoolP384r1", "brainpoolP512r1");
my $message = "";
my $errormessage = "";
my $cfgdata="";
my @daemon=();
my @daemondata="";
my $dehydir="/etc/dehydrated";
our %color = ();

$mainsettings{'ACTION'}="";
$mainsettings{'MYDOMAIN'}="";
$mainsettings{'MYHOSTNAME'}="";
$mainsettings{'MSIP'}="";
$mainsettings{'MSPORT'}="";
$mainsettings{"RELAYON"}="off";
$certsettings{"DHFILE"}="dh2048.pem";
$certsettings{"CERTFILE"}="postfix";
$certsettings{'CRTY'}="";
$certsettings{'STAT'}="";
$certsettings{'ORGA'}="";
$certsettings{'UNIT'}="";
$certsettings{'HOST'}="";
$certsettings{'MAIL'}="";
$certsettings{'DHLE'}="";
$certsettings{'TYPE'}="0";
$certsettings{'CURV'}="secp384r1";
$certsettings{'HASH'}="sha256";
$certsettings{'LEDOMAIN'}="";

#workaround to suppress a warning when a variable is used only once
my @dummy = (
	${Header::colourred},
	${Header::colourgreen}
);
undef (@dummy);
&General::readhash("/srv/web/ipfire/html/themes/ipfire/include/colors.txt", \%color);

# create conf dir files if not exist
unless (-e "$cfgdir/cert") { &General::system("mkdir", "-p", "$cfgdir/cert"); }
unless (-e $mainconf) { &General::system("touch", "$mainconf"); }
unless (-e $certconf) { &General::system("touch", "$certconf"); }

$mainsettings{'ACTION'} = '';
$mainsettings{'VALID'} = '';

&Header::showhttpheaders();
&Header::openpage($Lang::tr{'mailgate quarantine'}, 1, '');
&Header::openbigbox('100%', 'left', '', $errormessage);
&Header::getcgihash(\%mainsettings);

# Debug
#print "$mainsettings{'ACTION'} $mainsettings{'MYDOMAIN'} $mainsettings{'MYHOSTNAME'} $mainsettings{'MSIP'} $mainsettings{'MSPORT'}";

# main settings save
if ($mainsettings{'ACTION'} eq $Lang::tr{'save'}) {

	if ($mainsettings{'MYDOMAIN'} eq '' || ! validdomain($mainsettings{'MYDOMAIN'})) {
		$errormessage=$errormessage.$Lang::tr{'mailgate invalid mydomain'}.": $mainsettings{'MYDOMAIN'}";}
	if ($mainsettings{'MYHOSTNAME'} eq '' || ! validdomain($mainsettings{'MYHOSTNAME'})) {
		$errormessage=$errormessage."<br>".$Lang::tr{'mailgate invalid myhostname'}.": $mainsettings{'MYHOSTNAME'}";}
	if ($mainsettings{'MSIP'} eq '' || ! &General::validip($mainsettings{'MSIP'})) {
		$errormessage=$errormessage."<br>".$Lang::tr{'mailgate invalid msip'}.": $mainsettings{'MSIP'}";}
	if ($mainsettings{'MSPORT'} ne '' && ! &General::validport($mainsettings{'MSPORT'})) {
		$errormessage=$errormessage."<br>".$Lang::tr{'invalid port'}.": $mainsettings{'MSPORT'}";}
	if ($mainsettings{'RELAYON'} eq 'on') {
		if ($mainsettings{'RELAYHOST'} eq '' || &General::validip($mainsettings{'RELAYHOST'}) || ! validdomain($mainsettings{'RELAYHOST'})) {
			$errormessage=$errormessage."<br>".$Lang::tr{'mailgate invalid relay host'}.": $mainsettings{'RELAYHOST'}";}
		if ($mainsettings{'RELAYUSER'} eq '' || $mainsettings{'RELAYPASS'} eq '') {
			$errormessage=$errormessage."<br>".$Lang::tr{'mailgate invalid relay account'}.": $mainsettings{'RELAYPASS'}";}
		if ($mainsettings{'RELAYPORT'} ne '' && ! &General::validport($mainsettings{'RELAYPORT'})) {
			$errormessage=$errormessage."<br>".$Lang::tr{'invalid port'}.": $mainsettings{'RELAYPORT'}";}}
	if ($mainsettings{'DOMAINLIST'} ne '') {
		my @domaindata=split /,/,$mainsettings{'DOMAINLIST'};
		foreach (@domaindata) {
			chomp($_);
			if ( ! validdomain($_)) { $errormessage=$errormessage."<br>".$Lang::tr{'mailgate invalid relaylist'}.": ".$_; }}}
	if ($mainsettings{'HOSTLIST'} ne '') {
		my @domaindata=split /,/,$mainsettings{'HOSTLIST'};
		foreach (@domaindata) {
			chomp($_);
			if ( ! &General::validip($_)) { $errormessage=$errormessage."<br>".$Lang::tr{'mailgate invalid hostlist'}.": ".$_; }}}

	# settings valid start
	if ( ! $errormessage) {
		&General::writehash("$mainconf", \%mainsettings);

		# update postfix main domain settings
		&General::system("/usr/local/bin/postfixctrl", "postconf", "mydomain=$mainsettings{'MYDOMAIN'}", "myhostname=$mainsettings{'MYHOSTNAME'}");

		# update transport file
		$cfgdata="\# Postfix transport map file\n\# Do not change this file manually\n";
		if ($mainsettings{'MSPORT'} ne '') {$cfgdata=$cfgdata."$mainsettings{'MYDOMAIN'} smtp:$mainsettings{'MSIP'}:$mainsettings{'MSPORT'}\n"
		} else { $cfgdata=$cfgdata."$mainsettings{'MYDOMAIN'} smtp:$mainsettings{'MSIP'}\n";}
		if ($mainsettings{'DOMAINLIST'} ne '') {
			my @domaindata=split /,/,$mainsettings{'DOMAINLIST'};
			foreach (@domaindata) {
				chomp($_);
				if ($mainsettings{'MSPORT'} ne '') {$cfgdata = "$cfgdata".$_." smtp:$mainsettings{'MSIP'}:$mainsettings{'MSPORT'}\n";
				} else { $cfgdata = "$cfgdata".$_." smtp:$mainsettings{'MSIP'}\n"; }}}
		&write_maps_file("transport", $cfgdata);

		# update relay_domains file
		$cfgdata="\# Postfix relay_domains map file\n\# Do not change this file manually\n";
		$cfgdata=$cfgdata.$mainsettings{'MYDOMAIN'}." 1\n";
		if ($mainsettings{'DOMAINLIST'} ne '') {
			my @domaindata=split /,/,$mainsettings{'DOMAINLIST'};
			foreach (@domaindata) {
				chomp($_);
				$cfgdata = "$cfgdata".$_." 1\n";}}
		&write_maps_file("relay_domains", $cfgdata);

		# update network_table file
		$cfgdata="\# Postfix network_table file\n\# Do not change this file manually\n";
		$cfgdata=$cfgdata."127.0.0.0/8 OK\n";
		$cfgdata=$cfgdata.$mainsettings{'MSIP'}."/32 OK\n";
		if ($mainsettings{'HOSTLIST'} ne '') {
			my @domaindata=split /,/,$mainsettings{'HOSTLIST'};
			foreach (@domaindata) {
				chomp($_);
				$cfgdata = "$cfgdata".$_." OK\n";}}
		&write_maps_file("network_table", $cfgdata);

		# set postfix main.cf settings
		&General::system("/usr/local/bin/postfixctrl", "postconf", "transport_maps=lmdb:$cfgdir/maps/transport");
		&General::system("/usr/local/bin/postfixctrl", "postconf", "relay_domains=lmdb:$cfgdir/maps/relay_domains");
		&General::system("/usr/local/bin/postfixctrl", "postconf", "mynetworks=cidr:$cfgdir/maps/network_table");

		# set outgoing relay configuration 
		if ($mainsettings{'RELAYON'} eq 'on') {
			&General::system("/usr/local/bin/postfixctrl", "postconf", "smtp_sasl_auth_enable=yes", "smtp_sasl_security_options=noanonymous");
			&General::system("/usr/local/bin/postfixctrl", "postconf", "relayhost=$mainsettings{'RELAYHOST'}:$mainsettings{'RELAYPORT'}");
			&General::system("/usr/local/bin/postfixctrl", "postconf", "smtp_sasl_password_maps=lmdb:$cfgdir/maps/sasl_passwd");

			# update sasl_passwd file
			$cfgdata="\# Postfix sasl_passwd file\n\# Do not change this file manually\n";
			$cfgdata=$cfgdata."$mainsettings{'RELAYHOST'}:$mainsettings{'RELAYPORT'} $mainsettings{'RELAYUSER'}:$mainsettings{'RELAYPASS'}";
			&write_maps_file("sasl_passwd", $cfgdata);
			&General::system("/usr/local/bin/postfixctrl", "postmap", "lmdb:$cfgdir/maps/sasl_passwd");
		} else {
			&General::system("/usr/local/bin/postfixctrl", "postconf", "smtp_sasl_auth_enable=no", "smtp_sasl_password_maps=", "relayhost=");
		}
		# generate lmdb files
		&General::system("/usr/local/bin/postfixctrl", "postmap", "lmdb:$cfgdir/maps/{transport,relay_domains}");
		# reload postfix configuration

		# Get current status of the daemons.
		@daemondata[0] = &daemonstats('postfix');
		@daemondata[1] = &daemonstats('amavisd');

		# check for running rspamd milter and enable it in postfix configuration
		if ( -f "/usr/local/bin/rspamdctrl" ) { @daemondata[2]=&daemonstats('rspamd'); }
		if (($daemondata[2][0] ne '') && ($daemondata[2][1] ne '0')) {
			&General::system("/usr/local/bin/postfixctrl", "postconf", "smtpd_milters=unix:/var/run/rspamd-proxy.sock", "non_smtpd_milters=\\\$smtpd_milters");
		} else {&General::system("/usr/local/bin/postfixctrl", "postconf", "smtpd_milters=", "non_smtpd_milters="); }

		# reload / restart daemons to update active configuration if running
		if (($daemondata[0][0] ne '') && ($daemondata[0][1] ne '0')) { &General::system("/usr/local/bin/postfixctrl", "reload"); }
		if (($daemondata[1][0] ne '') && ($daemondata[1][1] ne '0')) { &General::system("/usr/local/bin/amavisdctrl", "restart"); }
	}
} # end main settings save

# cert create
if ($mainsettings{'ACTION'} eq $Lang::tr{'mailgate cert create'} && "$certsettings{'TYPE'}" eq "0") {
	&Header::getcgihash(\%certsettings);

	&validate_cert_input;

	# Replace empty strings with a .
	(my $ou = $certsettings{'UNIT'}) =~ s/^\s*$/\./;
	(my $city = $certsettings{'CITY'}) =~ s/^\s*$/\./;
	(my $state = $certsettings{'STAT'}) =~ s/^\s*$/\./;
	(my $mail = $certsettings{'MAIL'}) =~ s/^\s*$/\./;

	# debug 
	# print "/C=$certsettings{CRTY}/ST=$state/L=$city/O=$certsettings{ORGA}/OU=$ou/CN=$certsettings{HOST}/emailAddress=$mail"; 

	if ($certsettings{'TYPE'} eq "0" && !$errormessage) {
		# Create RSA Certificate
		# Delete if old certifikate exists
		if (-f "$cfgdir/cert/$certsettings{'CERTFILE'}-rsa.crt") {
			unlink "$cfgdir/cert/$certsettings{'CERTFILE'}-rsa.key";
			unlink "$cfgdir/cert/$certsettings{'CERTFILE'}-rsa.crt";}
		# The system call is safe, because all arguments are passed as an array.
		system("/usr/bin/openssl", "genrsa", "-out", "$cfgdir/cert/$certsettings{'CERTFILE'}-rsa.key", "4096");
		system("/usr/bin/openssl", "req", "-new", "-x509", "-$certsettings{'HASH'}", "-extensions", "v3_req" , "-days", "1825",
			"-subj", "/C=$certsettings{CRTY}/ST=$state/L=$city/O=$certsettings{ORGA}/OU=$ou/CN=$certsettings{HOST}/emailAddress=$mail",
			"-key",  "$cfgdir/cert/$certsettings{'CERTFILE'}-rsa.key",
			"-out",  "$cfgdir/cert/$certsettings{'CERTFILE'}-rsa.crt");
		if ($?) {
			$errormessage = "$Lang::tr{'openssl produced an error'}: $?";
			unlink "$cfgdir/cert/$certsettings{'CERTFILE'}-rsa.key";
			unlink "$cfgdir/cert/$certsettings{'CERTFILE'}-rsa.crt";}

		# Create ECC Certificate
		# Delete if old certifikate exists
		if (-f "$cfgdir/cert/$certsettings{'CERTFILE'}-ecc.crt") {
			unlink "$cfgdir/cert/$certsettings{'CERTFILE'}-ecc.key";
			unlink "$cfgdir/cert/$certsettings{'CERTFILE'}-ecc.crt";}
		# The system call is safe, because all arguments are passed as an array.
		system("/usr/bin/openssl", "req", "-new", "-newkey", "ec", "-pkeyopt", "ec_paramgen_curve:$certsettings{CURV}",
			"-$certsettings{'HASH'}", "-nodes", "-x509", "-extensions", "v3_req" , "-days", "1825",
			"-subj", "/C=$certsettings{CRTY}/ST=$state/L=$city/O=$certsettings{ORGA}/OU=$ou/CN=$certsettings{HOST}/emailAddress=$mail",
			"-keyout",  "$cfgdir/cert/$certsettings{'CERTFILE'}-ecc.key",
			"-out",  "$cfgdir/cert/$certsettings{'CERTFILE'}-ecc.crt");
		if ($?) {
			$errormessage = "$Lang::tr{'openssl produced an error'}: $?";
			unlink "$cfgdir/cert/$certsettings{'CERTFILE'}-ecc.key";
			unlink "$cfgdir/cert/$certsettings{'CERTFILE'}-ecc.crt";} 
	} else { &General::readhash("$mainconf", \%mainsettings);}
} # end cert create

# cert save and restart
if ($mainsettings{'ACTION'} eq $Lang::tr{'mailgate cert save'}) {
	&Header::getcgihash(\%certsettings);
	&General::readhash("$mainconf", \%mainsettings);

	&validate_cert_input;

	if ($certsettings{'TYPE'} eq '1' && $certsettings{'LEDOMAIN'} eq '' ) {
		$errormessage = "$Lang::tr{'mailgate invalid ledomain'}"; 
	} elsif ("$certsettings{'TYPE'}" eq "1" && $certsettings{'LEDOMAIN'} !~ /^[a-zA-Z0-9 ,\.\-_]*$/) {
		$errormessage = "$Lang::tr{'mailgate invalid ledomain'}: $certsettings{'LEDOMAIN'}";
	} elsif ("$certsettings{'TYPE'}" eq "1" && ! -d "$dehydir" ) {
		$errormessage = "$Lang::tr{'mailgate dehydrated missing'}";
	} elsif ("$certsettings{'TYPE'}" eq "1" && ! -d "$dehydir/certs/$certsettings{'LEDOMAIN'}") {
		$errormessage = "$Lang::tr{'mailgate ledomain not found'}";
	} elsif ( !-f "$cfgdir/cert/$certsettings{'DHFILE'}") {
		$errormessage = "$Lang::tr{'mailgate dhfile not found'}";
	} elsif (( !-f "$cfgdir/cert/$certsettings{'CERTFILE'}-rsa.crt" || !-f "$cfgdir/cert/$certsettings{'CERTFILE'}-rsa.key" ||
		   !-f "$cfgdir/cert/$certsettings{'CERTFILE'}-ecc.crt" || !-f "$cfgdir/cert/$certsettings{'CERTFILE'}-ecc.key" ||
		   !-f "$cfgdir/cert/$certsettings{'DHFILE'}") && $certsettings{'TYPE'} eq '0') {
		$errormessage="$Lang::tr{'mailgate cert missing'}";
	}

	# update postfix configuration an reload if running
	if ( ! $errormessage && $certsettings{'TYPE'} eq '0') { 
		&General::writehash("$certconf", \%certsettings);
		&General::system("/usr/local/bin/postfixctrl", "postconf", "smtpd_tls_cert_file=$cfgdir/cert/$certsettings{'CERTFILE'}-rsa.crt", "smtpd_tls_key_file=$cfgdir/cert/$certsettings{'CERTFILE'}-rsa.key");
		&General::system("/usr/local/bin/postfixctrl", "postconf", "smtpd_tls_eccert_file=$cfgdir/cert/$certsettings{'CERTFILE'}-ecc.crt", "smtpd_tls_eckey_file=$cfgdir/cert/$certsettings{'CERTFILE'}-ecc.key");
		&General::system("/usr/local/bin/postfixctrl", "postconf", "smtp_tls_cert_file=$cfgdir/cert/$certsettings{'CERTFILE'}-rsa.crt", "smtp_tls_key_file=$cfgdir/cert/$certsettings{'CERTFILE'}-rsa.key");
		&General::system("/usr/local/bin/postfixctrl", "postconf", "smtp_tls_eccert_file=$cfgdir/cert/$certsettings{'CERTFILE'}-ecc.crt", "smtp_tls_eckey_file=$cfgdir/cert/$certsettings{'CERTFILE'}-ecc.key");
		&General::system("/usr/local/bin/postfixctrl", "postconf", "smtpd_tls_dh1024_param_file=$cfgdir/cert/$certsettings{'DHFILE'}", "smtpd_tls_dh512_param_file=");
		@daemondata[0] = &daemonstats('postfix');
		if (($daemondata[0][0] ne '') && ($daemondata[0][1] ne '0')) { &General::system("/usr/local/bin/postfixctrl", "reload"); }
	}

	if ( ! $errormessage && $certsettings{'TYPE'} eq '1') {
		&General::writehash("$certconf", \%certsettings);
		&General::system("/usr/local/bin/postfixctrl", "postconf", "smtpd_tls_dh1024_param_file=$cfgdir/cert/$certsettings{'DHFILE'}", "smtpd_tls_dh512_param_file=");
		&General::system("/usr/local/bin/postfixctrl", "postconf", "smtpd_tls_cert_file=", "smtpd_tls_key_file=");
		&General::system("/usr/local/bin/postfixctrl", "postconf", "smtp_tls_cert_file=", "smtp_tls_key_file=");
		&General::system("/usr/local/bin/postfixctrl", "postconf", "smtpd_tls_eccert_file=$dehydir/certs/$certsettings{'LEDOMAIN'}/fullchain.pem", "smtpd_tls_eckey_file=$dehydir/certs/$certsettings{'LEDOMAIN'}/privkey.pem");
		&General::system("/usr/local/bin/postfixctrl", "postconf", "smtp_tls_eccert_file=$dehydir/certs/$certsettings{'LEDOMAIN'}/fullchain.pem", "smtp_tls_eckey_file=$dehydir/certs/$certsettings{'LEDOMAIN'}/privkey.pem");
		@daemondata[0] = &daemonstats('postfix');
		if (($daemondata[0][0] ne '') && ($daemondata[0][1] ne '0')) { &General::system("/usr/local/bin/postfixctrl", "reload"); }
	}

} # end cert save and restart

# create dh param file
if ($mainsettings{'ACTION'} eq $Lang::tr{'mailgate cert dhgen'}) {
	&Header::getcgihash(\%certsettings);

	# Delete if old key exists
	if (-f "$cfgdir/cert/$certsettings{'DHFILE'}") {unlink "$cfgdir/cert/$certsettings{'DHFILE'}";}
	# Create Diffie Hellmann Parameter
	# The system call is safe, because all arguments are passed as an array.
	system("/usr/bin/openssl", "dhparam", "-out", "$cfgdir/cert/$certsettings{'DHFILE'}", "-2", "$certsettings{'DHLE'}");
	if ($?) {
		$errormessage = "$Lang::tr{'openssl produced an error'}: $?";
		unlink ("$cfgdir/cert/$certsettings{'DHFILE'}");
	}
}

# manual deamon stop
# sending stop is ever possible
if ($mainsettings{'ACTION'} eq $Lang::tr{'stop'} && $certsettings{'TYPE'} eq "0") {
	&General::system("/usr/local/bin/postfixctrl", "stop");
	&General::system("/usr/local/bin/amavisdctrl", "stop");}

# manual dameon start
if ($mainsettings{'ACTION'} eq $Lang::tr{'start'}) {

	&General::readhash("$certconf", \%certsettings);

	if ($certsettings{'TYPE'} eq "0") {
		if ( !-f "$cfgdir/cert/$certsettings{'CERTFILE'}-rsa.crt" || !-f "$cfgdir/cert/$certsettings{'CERTFILE'}-rsa.key" ||
		     !-f "$cfgdir/cert/$certsettings{'CERTFILE'}-ecc.crt" || !-f "$cfgdir/cert/$certsettings{'CERTFILE'}-ecc.key") {
			$errormessage="$Lang::tr{'mailgate cert missing'}";
		} elsif ( !-f "$cfgdir/cert/$certsettings{'DHFILE'}") {
			$errormessage = "$Lang::tr{'mailgate dhfile not found'}";
		} else {
			&General::system("/usr/local/bin/postfixctrl", "start");
			&General::system("/usr/local/bin/amavisdctrl", "start");
		}
	}

	if ($certsettings{'TYPE'} eq '1') {
		if ($certsettings{'LEDOMAIN'} eq '') {
			$errormessage = "$Lang::tr{'mailgate invalid ledomain'}";
		} elsif ($certsettings{'LEDOMAIN'} !~ /^[a-zA-Z0-9 ,\.\-_]*$/) {
			$errormessage = "$Lang::tr{'mailgate invalid ledomain'}: $certsettings{'LEDOMAIN'}";
		} elsif ( !-d "$dehydir" ) {
			$errormessage = "$Lang::tr{'mailgate dehydrated missing'}";
		} elsif ( !-d "$dehydir/certs/$certsettings{'LEDOMAIN'}") {
			$errormessage = "$Lang::tr{'mailgate ledomain not found'}";
		} elsif ( !-f "$cfgdir/cert/$certsettings{'DHFILE'}") {
			$errormessage = "$Lang::tr{'mailgate dhfile not found'}";
		} else {
			&General::system("/usr/local/bin/postfixctrl", "start");
			&General::system("/usr/local/bin/amavisdctrl", "start");
		}
	}
}

# Get current daemon status
@daemondata[0]=&daemonstats('postfix');
@daemondata[1]=&daemonstats('amavisd');
if ( -f "/usr/local/bin/rspamdctrl" ) { @daemondata[2]=&daemonstats('rspamd'); }

if ($errormessage && $mainsettings{'ACTION'} eq $Lang::tr{'mailgate cert save'}) {
	&General::readhash("$mainconf", \%mainsettings);}


# read config data
if (!$errormessage) {
	&General::readhash("$mainconf", \%mainsettings);
	&General::readhash("$certconf", \%certsettings);}

$checked{'RELAYON'}{'off'} = '';
$checked{'RELAYON'}{'on'} = '';
$checked{'RELAYON'}{$mainsettings{'RELAYON'}} = "checked='checked'";

# DPC move error message to top so it is seen!
if ($errormessage) {
	&Header::openbox('100%', 'left', $Lang::tr{'error messages'});
	print "<font class='base'>$errormessage&nbsp;</font>\n";
	&Header::closebox();}

&Header::openbox('100%', 'left', "$Lang::tr{'service'} $Lang::tr{'status'}");

# debug
#print "-$daemondata[0][0]- -$daemondata[0][1]-<br>";
#print "-$daemondata[1][0]- -$daemondata[1][1]-<br>";
#print "-$daemondata[2][0]- -$daemondata[2][1]-<br>";

# Display some useful information related, if daemons are running.
print <<END;
<table width='100%' cellspacing='0' class='tbl' border='0'><tr>
<th class='base' width='2%'></th>
<th class='base' width='46%' colspan='2' bgcolor='$color{'color20'}' align='left'><strong>&nbsp$Lang::tr{'mailgate postfix daemon'}</strong></th>
<th class='base' width='46%' colspan='2' bgcolor='$color{'color20'}' align='left'><strong>&nbsp$Lang::tr{'mailgate amavis daemon'}</strong></th>
<th class='base' width='6%'></th>
</tr>
<tr>
<td class='base'></td>
END

if (($daemondata[0][0] ne '') && ($daemondata[0][1] ne '0')) {
	print "<td class='base' colspan='2' bgcolor='${Header::colourgreen}' align='center'><font color='white'><strong>$Lang::tr{'running'}</strong></font></td>"; 
	} else { print "<td align='center' colspan='2' bgcolor='${Header::colourred}'><font color='white'><strong>$Lang::tr{'stopped'}</strong></font></td>"; }

if (($daemondata[1][0] ne '') && ($daemondata[1][1] ne '0')) {
	print "<td class='base' colspan='2' bgcolor='${Header::colourgreen}' align='center'><font color='white'><strong>$Lang::tr{'running'}</strong></font></td>";
	} else { print "<td align='center' colspan='2' bgcolor='${Header::colourred}'><font color='white'><strong>$Lang::tr{'stopped'}</strong></font></td>"; }
print "<td class='base' width='2%'></td></tr><tr><td></td>";

if (($daemondata[0][0] ne '') && ($daemondata[0][1] ne '0')) {
print <<END;
<td bgcolor='$color{'color22'}' align='center'><strong>PID</strong>&nbsp$daemondata[0][0]</td>
<td bgcolor='$color{'color22'}' align='center'><strong>$Lang::tr{'memory'}</strong>&nbsp$daemondata[0][1] KB</td>
END
} else { print "<td colspan='2'></td>"; }

if ( ($daemondata[1][0] ne '') && ($daemondata[1][1] ne '0')) {
print <<END;
<td bgcolor='$color{'color22'}'  align='center'><strong>PID</strong>&nbsp$daemondata[1][0]</td>
<td bgcolor='$color{'color22'}'  align='center'><strong>$Lang::tr{'memory'}</strong>&nbsp$daemondata[1][1] KB</td>
END
} else { print "<td colspan='2'></td>"; }

print "<td></td></tr></table>";
# daemon table end

&Header::closebox();
&Header::openbox('100%', 'left', "$Lang::tr{'mailgate configuration caption'}:");

# main configuration
print <<END;
<form method='post' action='$ENV{'SCRIPT_NAME'}'>
<table width='100%' border='0' cellspacing='0'>
<tr>
<td width='2%'></td>
<td width='23%' class='base' align='left'>&nbsp;$Lang::tr{'mailgate mydomain'}:&nbsp;<img src='/blob.gif' alt='*' /></td>
<td width='25%' class='base' align='left'><input type='text' name='MYDOMAIN' value='$mainsettings{'MYDOMAIN'}' size='30' /></td>
<td width='20%' class='base' align='left'>&nbsp;$Lang::tr{'mailgate myhostname'}:&nbsp;<img src='/blob.gif' alt='*' /></td>
<td width='30%' class='base' align='left'><input type='text' name='MYHOSTNAME' value='$mainsettings{'MYHOSTNAME'}' size='30' /></td>
</tr><tr><td></td>
<td class='base' align='left'>&nbsp;$Lang::tr{'mailgate msip'}:&nbsp;<img src='/blob.gif' alt='*' /></td>
<td class='base'><input type='text' name='MSIP' value='$mainsettings{'MSIP'}' size='30' /></td>
<td class='base' align='left'>&nbsp;$Lang::tr{'mailgate msport'}:&nbsp;</td>
<td class='base'><input type='text' name='MSPORT' value='$mainsettings{'MSPORT'}' size='30' /></td>
</tr></table>
<table width='100%' border='0' cellspacing='0'><tr>
<td width='2%'></td>
<td width='23%' class='base' align='left'>&nbsp;$Lang::tr{'mailgate domainlist'}:&nbsp;</td>
<td width='75%' class='base'><input type='text' name='DOMAINLIST' value='$mainsettings{'DOMAINLIST'}' size='97' /></td>
</tr><tr><td></td>
<td class='base' align='left'>&nbsp;$Lang::tr{'mailgate hostlist'}:&nbsp;</td>
<td class='base'><input type='text' name='HOSTLIST' value='$mainsettings{'HOSTLIST'}' size='97' /></td>
</tr></table>
END
&Header::closebox();

# relay configuration 
&Header::openbox('100%', 'left', "$Lang::tr{'mailgate extrelay caption'}:");
print <<END;
<table width='100%' border='0' cellspacing='0'><tr>
<td width='2%'></td>
<td width='23%' class='base'>&nbsp;$Lang::tr{'mailgate extrelay enable'}</td>
<td width='25%' class='base'><input type='checkbox' name='RELAYON' $checked{'RELAYON'}{'on'} /></td>
<td width='20%' class='base'></td>
<td width='30%' class='base'></td>
</tr><tr><td></td>
<td class='base' align='left'>&nbsp;$Lang::tr{'mailgate extrelay host'}:&nbsp;</td>
<td class='base'><input type='text' name='RELAYHOST' value='$mainsettings{'RELAYHOST'}' size='30' /></td>
<td class='base' align='left'>&nbsp;$Lang::tr{'mailgate extrelay port'}:&nbsp;</td>
<td class='base'><input type='text' name='RELAYPORT' value='$mainsettings{'RELAYPORT'}' size='30' /></td>
</tr><tr><td></td>
<td class='base' align='left'>&nbsp;$Lang::tr{'mailgate extrelay user'}:&nbsp;</td>
<td class='base'><input type='text' name='RELAYUSER' value='$mainsettings{'RELAYUSER'}' size='30' /></td>
<td class='base' align='left'>&nbsp;$Lang::tr{'mailgate extrelay pass'}:&nbsp;</td>
<td class='base'><input type='password' name='RELAYPASS' value='$mainsettings{'RELAYPASS'}' size='30' /></td>
</tr></table><br>
<table width='100%' border='0' cellspacing='0'>
<tr><td width='2%'></td>
<td width='23%'>&nbsp;$Lang::tr{'mailgate daemons'}:&nbsp;</td>
<td width='10%' class='base' align='left'><input type='submit' name='ACTION' value='$Lang::tr{'stop'}' style="width:80px;" /></td>
<td width='10%' class='base' align='left'><input type='submit' name='ACTION' value='$Lang::tr{'start'}' style="width:80px;" /></td>
<td width='40%'></td>
<td width='9%' class='base' align='center'><input type='submit' name='ACTION' value='$Lang::tr{'save'}' style="width:80px;" /></td>
<td width='6%' class='base' align='center'></td>
</tr></table></form>
END

&Header::closebox();

# cert configuration 
&Header::openbox('100%', 'left', "$Lang::tr{'mailgate cert settings caption'}:");

# debug
# print "$mainsettings{'ACTION'} -$certsettings{'CRTY'}- -$certsettings{'STAT'}- -$certsettings{'HOST'}- -$certsettings{'MAIL'}-";
# print "$mainsettings{'ACTION'} -$certsettings{'TYPE'}- -$certsettings{'HASH'}- -$certsettings{'CURV'}- -$certsettings{'DHLE'}-";

print <<END;
<form method='post' action='$ENV{'SCRIPT_NAME'}' />
<!-- Line 1 -->
<table width='100%' border='0' cellspacing='0'>
<tr>
<td width='2%'></td>
<td width='23%'>&nbsp;$Lang::tr{'mailgate cert type'}:&nbsp;</td>
<td width='17%' class='base'>
<select name='TYPE' id="TYPE" style="width: 130px;">
END

# cert type select
if ($certsettings{'TYPE'} eq "0") { 
	print "<option value=0 selected='selected'>&nbsp;$Lang::tr{'mailgate cert selfsinged'}</option>";
} else { print "<option value=0>&nbsp;$Lang::tr{'mailgate cert selfsinged'}</option>";}
if ($certsettings{'TYPE'} eq "1") {
	print "<option value=1 selected='selected'>&nbsp;$Lang::tr{'mailgate cert letsencrypt'}</option>";
} else { print "<option value=1>&nbsp;$Lang::tr{'mailgate cert letsencrypt'}</option>";}

print <<END;
</select>
</td>
<td width='20%'class='base'>&nbsp;$Lang::tr{'mailgate cert dhlength'}:&nbsp;</td>
<td width='12%'class='base'>
<select name='DHLE' id="DHLE" style="width: 85px;">
END
# Diffie-Hellman parameters length select
foreach my $param (@dhlength) {
	print "<option value=$param";
	if ( $param eq $certsettings{'DHLE'} ) {print " selected='selected'";}
	print ">&nbsp;$param $Lang::tr{'bit'}</option>";}

print <<END;
</select>
</td>
<td width='20%' class='base' align='center'><input type='submit' name='ACTION' value="$Lang::tr{'mailgate cert dhgen'}" style="width:165px;" /></td>
<td width='5%' class='base' align='center'></td>
</tr>
<!-- Line 2 -->
<tr>
<td></td>
<td class='base'>&nbsp;$Lang::tr{'mailgate cert curve'}:&nbsp;</td>
<td class='base'>
<select name='CURV' id="CURV" style="width: 130px;">
END
# Curves Type select
foreach my $param (@certcurves) {
	print "<option value=$param";
	if ( $param eq $certsettings{'CURV'} ) {print " selected='selected'";}
	print ">&nbsp;$param</option>";}

print <<END;
</select>
</td>
<td class='base'>&nbsp;$Lang::tr{'mailgate cert hash'}:&nbsp;</td>
<td class='base'>
<select name='HASH' id="HASH" style="width: 85px;">
END
# Certiticate hash type select
foreach my $param (@certhashes) {
	print "<option value=$param";
	if ( $param eq $certsettings{'HASH'} ) {print " selected='selected'";}
	$param=uc $param;
	print ">&nbsp;$param</option>";}

print <<END;
</select></td>
<td class='base' align='center'><input type='submit' name='ACTION' value="$Lang::tr{'mailgate cert create'}" style="width:165px;" /></td>
<td class='base' align='center'></td>
</tr>
<tr><td></td>
<td class='base'>&nbsp;$Lang::tr{'mailgate cert ledomain'}:</td>
<td class='base' colspan='3'><input type='text' name='LEDOMAIN' value="$certsettings{'LEDOMAIN'}" size='50'/></td>
<td class='base' align='center'><input type='submit' name='ACTION' value="$Lang::tr{'mailgate cert save'}" style="width:165px;" /></td>
<td></td></tr>
</table><br>
<table width='100%' border='0' cellspacing='0'> <tr><td width='2%'></td>
<td width='23%' class='base'>&nbsp;$Lang::tr{'mailgate cert contry code'}:&nbsp;<img src='/blob.gif' alt='*' /></td>
END

if ($certsettings{'TYPE'} eq '0') {
	print "<td width='40%' class='base'>&nbsp;<select name='CRTY'>";
	foreach my $country (sort keys %{Countries::countries}) {
		print "<option value='$Countries::countries{$country}'";
		if ( $Countries::countries{$country} eq $certsettings{'CRTY'} ) {
			print " selected='selected'";	}
		print ">$country</option>";}

} else { print "<td width='40%' class='base'><input type='text' name='CRTY' value='$certsettings{'CRTY'}'  disabled='disabled' size='30' />";
	 print "<input type='hidden' name='CRTY' value='$certsettings{'CRTY'}'/>"; }

print <<END;
</select></td>
<td width='17%' class='base'></td>
<td width='12%' class='base'></td>
<td width='6%' class='base'></td>
</tr><tr><td></td>
<td class='base' align='left'>&nbsp;$Lang::tr{'mailgate cert contry'}:&nbsp;</td>
END
if ($certsettings{'TYPE'} eq '0') {
	 print "<td class='base' nowrap='nowrap'><input type='text' name='STAT' value='$certsettings{'STAT'}' size='50' /></td>";
} else { print "<td class='base' nowrap='nowrap'><input type='text' name='STAT' value='$certsettings{'STAT'}'  disabled='disabled' size='50' /></td>";
	 print "<input type='hidden' name='STAT' value='$certsettings{'STAT'}'/>"; }

print "<td class='base' bgcolor='$color{'color20'}' align='left'><strong>&nbsp;$Lang::tr{'mailgate cert rsa-cert'}</strong></td>";
if ( -f "$cfgdir/cert/$certsettings{'CERTFILE'}-rsa.crt") {
	 print "<td bgcolor='${Header::colourgreen}'><font color='white'><strong>&nbsp;$Lang::tr{'present'}</strong></font></td>";
} else { print "<td bgcolor='${Header::colourred}'><font color='white'><strong>&nbsp;$Lang::tr{'not present'}</strong></font></td>";}

print <<END;
<td></td></tr><tr><td></td>
<td class='base' align='left'>&nbsp;$Lang::tr{'mailgate cert city'}:&nbsp;</td>
END

if ($certsettings{'TYPE'} eq '0') {
	 print "<td class='base' nowrap='nowrap'><input type='text' name='CITY' value='$certsettings{'CITY'}' size='50' /></td>";
} else { print "<td class='base' nowrap='nowrap'><input type='text' name='CITY' value='$certsettings{'CITY'}' disabled='disabled' size='50' /></td>";
	 print "<input type='hidden' name='CITY' value='$certsettings{'CITY'}'/>"; }

print "<td class='base' bgcolor='$color{'color22'}' align='left'><strong>&nbsp;$Lang::tr{'mailgate cert rsa-key'}</strong></td>";
if ( -f "$cfgdir/cert/$certsettings{'CERTFILE'}-rsa.key") {
	 print "<td bgcolor='${Header::colourgreen}'><font color='white'><strong>&nbsp;$Lang::tr{'present'}</strong></font></td>";
} else { print "<td bgcolor='${Header::colourred}'><font color='white'><strong>&nbsp;$Lang::tr{'not present'}</strong></font></td>";}

print <<END;
<td></td></tr><tr><td></td>
<td class='base' align='left'>&nbsp;$Lang::tr{'mailgate cert orga'}:&nbsp;<img src='/blob.gif' alt='*' /></td>
END

if ($certsettings{'TYPE'} eq '0') {
	 print "<td class='base' nowrap='nowrap'><input type='text' name='ORGA' value='$certsettings{'ORGA'}' size='50' /></td>";
} else { print "<td class='base' nowrap='nowrap'><input type='text' name='ORGA' value='$certsettings{'ORGA'}' disabled='disabled' size='50' /></td>";
	 print "<input type='hidden' name='ORGA' value='$certsettings{'ORGA'}'/>"; } 

print "<td class='base' bgcolor='$color{'color20'}' align='left'><strong>&nbsp;$Lang::tr{'mailgate cert ecc-cert'}</strong></td>";
if ( -f "$cfgdir/cert/$certsettings{'CERTFILE'}-ecc.crt") {
	 print "<td bgcolor='${Header::colourgreen}'><font color='white'><strong>&nbsp;$Lang::tr{'present'}</strong></font></td>";
} else { print "<td bgcolor='${Header::colourred}'><font color='white'><strong>&nbsp;$Lang::tr{'not present'}</strong></font></td>";}

print <<END;
<td></td></tr><tr><td></td>
<td class='base' align='left'>&nbsp;$Lang::tr{'mailgate cert unit'}:&nbsp;</td>
END

if ($certsettings{'TYPE'} eq '0') {
	 print "<td class='base' nowrap='nowrap'><input type='text' name='UNIT' value='$certsettings{'UNIT'}' size='50' /></td>"; 
} else { print "<td class='base' nowrap='nowrap'><input type='text' name='UNIT' value='$certsettings{'UNIT'}' disabled='disabled' size='50' /></td>"; 
	 print "<input type='hidden' name='UNIT' value='$certsettings{'UNIT'}'/>"; } 

print "<td class='base' bgcolor='$color{'color22'}' align='left'><strong>&nbsp;$Lang::tr{'mailgate cert ecc-key'}</strong></td>";
if ( -f "$cfgdir/cert/$certsettings{'CERTFILE'}-ecc.key") {
	 print "<td bgcolor='${Header::colourgreen}'><font color='white'><strong>&nbsp;$Lang::tr{'present'}</strong></font></td>";
} else { print "<td bgcolor='${Header::colourred}'><font color='white'><strong>&nbsp;$Lang::tr{'not present'}</strong></font></td>";}

print <<END;
<td></td></tr><tr><td></td>
<td class='base' align='left' >&nbsp;$Lang::tr{'mailgate cert host'}:&nbsp;<img src='/blob.gif' alt='*' /></td>
END

if ($certsettings{'TYPE'} eq '0') {
	 print "<td class='base' nowrap='nowrap'><input type='text' name='HOST' value='$certsettings{'HOST'}' size='50' /></td>";
} else { print "<td class='base' nowrap='nowrap'><input type='text' name='HOST' value='$certsettings{'HOST'}' disabled='disabled' size='50' /></td>";
	 print "<input type='hidden' name='HOST' value='$certsettings{'HOST'}'/>"; } 

print "<td class='base' bgcolor='$color{'color20'}' align='left'><strong>&nbsp;$Lang::tr{'mailgate cert dhfile'}</strong></td>";
if ( -f "$cfgdir/cert/$certsettings{'DHFILE'}") {
	 print "<td bgcolor='${Header::colourgreen}'><font color='white'><strong>&nbsp;$Lang::tr{'present'}</strong></font></td>";
} else { print "<td bgcolor='${Header::colourred}'><font color='white'><strong>&nbsp;$Lang::tr{'not present'}</strong></font></td>";}

print <<END;
<td></td></tr><tr><td></td>
<td class='base' align='left'>&nbsp;$Lang::tr{'mailgate cert mail'}:&nbsp;</td>
END

if ($certsettings{'TYPE'} eq '0') {
	 print "<td class='base' nowrap='nowrap'><input type='text' name='MAIL' value='$certsettings{'MAIL'}' size='50' /></td>";
} else { print "<td class='base' nowrap='nowrap'><input type='text' name='MAIL' value='$certsettings{'MAIL'}' disabled='disabled' size='50' /></td>";
	 print "<input type='hidden' name='MAIL' value='$certsettings{'MAIL'}'/>"; }

print <<END;
<td colspan='2'></td><td></td></tr>
<tr><td></td><td> <img src='/blob.gif' valign='top' alt='*' />&nbsp;$Lang::tr{'required field'}</td>
<td colspan='3'></td><td></td></tr></table>
</form>
END


&Header::closebox();
&Header::closebigbox();
&Header::closepage();
# html site end
# -------------------------------------------------------------------

# Function to check if postfix daemon has been started.
# Grab process id and consumed memory if the daemon is running.
sub daemonstats() {

	my $name = shift;
	$name="/usr/local/bin/${name}ctrl";
	my @data = "";
	my $string = "";
        my $memory = 0;

        open(FILE, "$name status | ");
        @daemon = <FILE>;
        close(FILE);
        $string = join("", @daemon);
	$string =~ s|^.*ID(s)||g;
        $string =~ s/[a-z_]//gi;
        $string =~ s/\[[0-1]\;[0-9]+//gi;
        $string =~ s/[\(\)\.]//gi;
        $string =~ s/\e//gi;
	$string =~ s|/||g;
	$string =~ s/^\s+|\s+$//g;

	#print "-$string-<br>";

	if (open(FILE, "/proc/${string}/status")) {
		while (<FILE>) {
			my ($key, $val) = split(":", $_, 2);
			if ($key eq 'VmRSS') {
				$memory = $val;
				last;
			}
		}
		close(FILE);
	}
	@data[0]=$string;
	@data[1]=$memory;
	return \@data;
}

# -------------------------------------------------------------------

# Function to save server and pool list
sub write_maps_file {

	my $name = shift;
	my $data = shift;
	$name="$cfgdir/maps/${name}";

	open(FILE, ">$name");
	flock(FILE, 2);
	print FILE $data;
	close(FILE);
}

# -------------------------------------------------------------------

sub validdomain {
	my $part;

	# Checks a domain name against RFC1035 and RFC2181
        my $domainname = shift;
	my @parts = split (/\./, $domainname);	# Split domain name at the '.'

	foreach $part (@parts) {
		# Each part should be at least one character in length
		# but no more than 63 characters
		# Only valid characters are a-z, A-Z, 0-9, _ and -
		if ($part !~ /^[a-zA-Z0-9_-]*$/ || length ($part) < 1 || length ($part) > 63) {
			print "$part <br>";
			return 0;}
	}
	return 1;
}

# -------------------------------------------------------------------

sub validate_cert_input {

	# Validate input since the form was submitted
	if ($certsettings{'ORGA'} eq ''){
		$errormessage = $Lang::tr{'organization cant be empty'};}
	if (length($certsettings{'ORGA'}) >60) {
		$errormessage = $Lang::tr{'organization too long'};}
	if ($certsettings{'ORGA'} !~ /^[a-zA-Z0-9 ,\.\-_]*$/) {
		$errormessage = $Lang::tr{'invalid input for organization'};}
	if ($certsettings{'HOST'} eq ''){
		$errormessage = $Lang::tr{'hostname cant be empty'};}
	unless (&General::validfqdn($certsettings{'HOST'}) || &General::validip($certsettings{'HOST'})) {
		$errormessage = $Lang::tr{'invalid input for hostname'};}
	if ($certsettings{'MAIL'} ne '' && (! &General::validemail($certsettings{'MAIL'}))) {
		$errormessage = $Lang::tr{'invalid input for e-mail address'};}
	if (length($certsettings{'MAIL'}) > 40) {
		$errormessage = $Lang::tr{'e-mail address too long'};}
	if ($certsettings{'UNIT'} ne '' && $certsettings{'UNIT'} !~ /^[a-zA-Z0-9 ,\.\-_]*$/) {
		$errormessage = $Lang::tr{'invalid input for department'};}
	if ($certsettings{'CITY'} ne '' && $certsettings{'CITY'} !~ /^[a-zA-Z0-9 ,\.\-_]*$/) {
		$errormessage = $Lang::tr{'invalid input for city'};}
	if ($certsettings{'STAT'} ne '' && $certsettings{'STAT'} !~ /^[a-zA-Z0-9 ,\.\-_]*$/) {
		$errormessage = $Lang::tr{'invalid input for state or province'};}
	if ($certsettings{'CRTY'} !~ /^[A-Z]*$/) {
		$errormessage = $Lang::tr{'invalid input for country'};}
	if ( ! $errormessage) { 
		&General::writehash("$certconf", \%certsettings);}
}
