#!/usr/bin/perl
###############################################################################
#                                                                             #
# IPFire.org - A linux based firewall                                         #
# Copyright (C) 2005-2022  IPFire Team  <info@ipfire.org>                     #
#                                                                             #
# This program is free software: you can redistribute it and/or modify        #
# it under the terms of the GNU General Public License as published by        #
# the Free Software Foundation, either version 3 of the License, or           #
# (at your option) any later version.                                         #
#                                                                             #
# This program is distributed in the hope that it will be useful,             #
# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
# GNU General Public License for more details.                                #
#                                                                             #
# You should have received a copy of the GNU General Public License           #
# along with this program.  If not, see <http://www.gnu.org/licenses/>.       #
#                                                                             #
###############################################################################
use strict;

# enable only the following on debugging purpose
use warnings;
use CGI::Carp 'fatalsToBrowser';
use File::Copy;
use File::Basename;
use Date::Parse;
use Tie::File;
use Fcntl;
use POSIX();

require '/var/ipfire/general-functions.pl';
require "${General::swroot}/lang.pl";
require "${General::swroot}/header.pl";

#workaround to suppress a warning when a variable is used only once
my @dummy = ( ${Header::table2colour} );
undef (@dummy);

my %cgiparams=();
my $message = "";
my $errormessage = "";
my $qtfolder="/var/virusmails";
my $file="";
my @filesbanned="";
my @filesbannedheader="";
my @filesbadh="";
my @filesbadhheader="";
my @filesspam="";
my @filesspamheader="";

$cgiparams{'ACTION'} = '';
$cgiparams{'FILE'} = '';

&Header::getcgihash(\%cgiparams);

# Filenames cannot contain any slashes
if ($cgiparams{'FILE'} =~ /\//) { undef $cgiparams{'FILE'}; }

if ($cgiparams{'ACTION'} eq "download") {
	$file = "$qtfolder/$cgiparams{'FILE'}";
	if (-e $file) {
		&deliver_file($file);
		exit(0);
	} else {
		exit(1);
	}
}

# delete mail from disk
if ($cgiparams{'ACTION'} eq "delete") {
	if (-e "$qtfolder/$cgiparams{'FILE'}") { &General::system("/usr/local/bin/amavisdctrl", "delete", $cgiparams{'FILE'}); }
}

# release mail from quarantine and delete from disk
if ($cgiparams{'ACTION'} eq "release") {
	&General::system("/usr/local/bin/amavisdctrl", "release", $cgiparams{'FILE'});
	if (-e "$qtfolder/$cgiparams{'FILE'}") { &General::system("/usr/local/bin/amavisdctrl", "delete", $cgiparams{'FILE'}); }
}

&Header::showhttpheaders();
&Header::openpage($Lang::tr{'mailgate quarantine'}, 1, '');
&Header::openbigbox('100%', 'left', '', $errormessage);

# Debug
#print "$cgiparams{'ACTION'}  $cgiparams{'FILE'}";


if ($errormessage) {
	&Header::openbox('100%', 'left', $Lang::tr{'error messages'});
	print "<font class='base'>$errormessage&nbsp;</font>\n";
	&Header::closebox();
}


if ( $message ne "" ){
	&Header::openbox('100%','left',$Lang::tr{'error messages'});
	print "<font color='red'>$message</font>\n";
	&Header::closebox();
}

# query files on disk
if ( -e "$qtfolder" ){
	@filesbadh   =`cd /var/virusmails/ && ls -t badh-* 2>/dev/null`;
	@filesbanned =`cd /var/virusmails/ && ls -t banned-* 2>/dev/null`;
	@filesspam   =`cd /var/virusmails/ && ls -t spam-* 2>/dev/null`;
}

my $Index=0;
foreach (@filesbanned){
	chomp($_);
	$file = "$qtfolder/".$_;
	@filesbannedheader[$Index]= &read_header($file);
	$Index++;
}
$Index=0;
foreach (@filesbadh){
	chomp($_);
	$file = "$qtfolder/".$_;
	@filesbadhheader[$Index]= &read_header($file);
	$Index++;
}
# currently disabled
#$Index=0;
#foreach (@filesspam){
#	chomp($_);
#	$file = "$qtfolder/".$_;
#	@filesspamheader[$Index]= &read_header_spam($file);
#	$Index++;
#}

# print amavisd banned content mails table
&Header::openbox('100%', 'left', "$Lang::tr{'mailgate files banned'}:");
print "<table width='100%' border='0' cellspacing='1'>";
print "<tr><td width='16%' align='center'>$Lang::tr{'filename'}</td><td width='13%' align='center'> $Lang::tr{'date'}</td><td width='8%' align='center'> $Lang::tr{'size'}<td width='27%' align='center'>$Lang::tr{'mailgate sender'}</td> <td width='26%' align='center'>$Lang::tr{'mailgate recipient'}</td><td width='3%'></td><td width='3%'></td><td width='3%'></td>";
$Index=0;
foreach (@filesbanned){
	chomp($_);
	my $Datei = "$qtfolder/".$_;
	my @Info = stat($Datei);
	my $Size = $Info[7] / 1024;
	$Size = sprintf("%0.2f", $Size);
	my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst) = localtime($Info[9]);
	$mon += 1;
	$year += 1900;
	$mday = sprintf("%02s", $mday);
	$mon = sprintf("%02s", $mon);
	$hour = sprintf("%02s", $hour);
	$min = sprintf("%02s", $min);
	$sec = sprintf("%02s", $sec);
	print "<tr><td align='left'>$_ </td><td align='center'>$mday.$mon.$year $hour:$min:$sec</td><td align='center'>$Size KB</td>";
	print "<td align='left'>$filesbannedheader[$Index][0]</td><td align='left'>$filesbannedheader[$Index][1]</td>";
	print "<td align='center'><form method='post' action='$ENV{'SCRIPT_NAME'}'><input type='hidden' name='ACTION' value='download' /><input type='hidden' name='FILE' value='$_' /><input type='image' alt='$Lang::tr{'download'}' title='$Lang::tr{'download'}' src='/images/package-x-generic.png' /></form></td>";
	print "<td align='center'><form method='post' action='$ENV{'SCRIPT_NAME'}'><input type='hidden' name='ACTION' value='delete' /><input type='hidden' name='FILE' value='$_' /><input type='image' alt='$Lang::tr{'delete'}' title='$Lang::tr{'delete'}' src='/images/user-trash.png' /></form></td>";
	print "<td align='center'><form method='post' action='$ENV{'SCRIPT_NAME'}'><input type='hidden' name='ACTION' value='release' /><input type='hidden' name='FILE' value='$_' /><input type='image' alt='$Lang::tr{'mailgate quarantine release'}' title='$Lang::tr{'mailgate quarantine release'}' src='/images/edit-redo.png' /></form></td></tr>";
	$Index++;
}
print "</table>";
&Header::closebox();

# print amavisd bad header mails table
&Header::openbox('100%', 'left', "$Lang::tr{'mailgate files badh'}:");
print "<table width='100%' border='0' cellspacing='1'>";
print "<tr><td width='16%' align='center'>$Lang::tr{'filename'}</td><td width='13%' align='center'> $Lang::tr{'date'}</td><td width='8%' align='center'> $Lang::tr{'size'}<td width='27%' align='center'>$Lang::tr{'mailgate sender'}</td> <td width='26%' align='center'>$Lang::tr{'mailgate recipient'}</td><td width='3%'></td><td width='3%'></td><td width='3%'></td>";
$Index=0;
foreach (@filesbadh){
	chomp($_);
	my $Datei = "$qtfolder/".$_;
	my @Info = stat($Datei);
	my $Size = $Info[7] / 1024 / 1024;
	$Size = sprintf("%0.2f", $Size);
	my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst) = localtime($Info[9]);
	$mon += 1;
	$year += 1900;
	$mday = sprintf("%02s", $mday);
	$mon = sprintf("%02s", $mon);
	$hour = sprintf("%02s", $hour);
	$min = sprintf("%02s", $min);
	$sec = sprintf("%02s", $sec);

	print "<tr><td align='left'>$_ </td><td align='center'>$mday.$mon.$year $hour:$min:$sec</td><td align='center'>$Size KB</td>";
	print "<td align='left'>$filesbadhheader[$Index][0]</td><td align='left'>$filesbadhheader[$Index][1]</td>";
	print "<td align='center'><form method='post' action='$ENV{'SCRIPT_NAME'}'><input type='hidden' name='ACTION' value='download' /><input type='hidden' name='FILE' value='$_' /><input type='image' alt='$Lang::tr{'download'}' title='$Lang::tr{'download'}' src='/images/package-x-generic.png' /></form></td>";
	print "<td align='center'><form method='post' action='$ENV{'SCRIPT_NAME'}'><input type='hidden' name='ACTION' value='delete' /><input type='hidden' name='FILE' value='$_' /><input type='image' alt='$Lang::tr{'delete'}' title='$Lang::tr{'delete'}' src='/images/user-trash.png' /></form></td>";
	print "<td align='center'><form method='post' action='$ENV{'SCRIPT_NAME'}'><input type='hidden' name='ACTION' value='release' /><input type='hidden' name='FILE' value='$_' /><input type='image' alt='$Lang::tr{'mailgate quarantine release'}' title='$Lang::tr{'mailgate quarantine release'}' src='/images/edit-redo.png' /></form></td></tr>";
	$Index++;
}
print "</table>";
&Header::closebox();

# print amavisd spam mails table
&Header::openbox('100%', 'left', "$Lang::tr{'mailgate files spam'}:");
print "<table width='100%' border='0' cellspacing='0'>";
print "<tr><td width='16%' align='center'>$Lang::tr{'filename'}</td><td width='13%' align='center'> $Lang::tr{'date'}</td><td width='8%' align='center'> $Lang::tr{'size'}<td width='27%' align='center'>$Lang::tr{'mailgate sender'}</td> <td width='26%' align='center'>$Lang::tr{'mailgate recipient'}</td><td width='3%'></td><td width='3%'></td><td width='3%'></td>";
$Index=0;
foreach (@filesspam){
	chomp($_);
	my $Datei = "$qtfolder/".$_;
	my @Info = stat($Datei);
	my $Size = $Info[7] / 1024 / 1024;
	$Size = sprintf("%0.2f", $Size);
	my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst) = localtime($Info[9]);
	$mon += 1;
	$year += 1900;
	$mday = sprintf("%02s", $mday);
	$mon = sprintf("%02s", $mon);
	$hour = sprintf("%02s", $hour);
	$min = sprintf("%02s", $min);
	$sec = sprintf("%02s", $sec);
	print "<tr><td align='center'>$_ </td><td align='center'>$mday.$mon.$year $hour:$min:$sec</td><td align='center'>$Size KB</td>";
	print "<td align='left'></td><td align='left'</td>";

	print "<td align='center'><form method='post' action='$ENV{'SCRIPT_NAME'}'><input type='hidden' name='ACTION' value='download' /><input type='hidden' name='FILE' value='$_' /><input type='image' alt='$Lang::tr{'download'}' title='$Lang::tr{'download'}' src='/images/package-x-generic.png' /></form></td>";
	print "<td align='center'><form method='post' action='$ENV{'SCRIPT_NAME'}'><input type='hidden' name='ACTION' value='delete' /><input type='hidden' name='FILE' value='$_' /><input type='image' alt='$Lang::tr{'delete'}' title='$Lang::tr{'delete'}' src='/images/user-trash.png' /></form></td>";
	print "<td align='center'><form method='post' action='$ENV{'SCRIPT_NAME'}'><input type='hidden' name='ACTION' value='release' /><input type='hidden' name='FILE' value='$_' /><input type='image' alt='$Lang::tr{'mailgate quarantine release'}' title='$Lang::tr{'mailgate quarantine release'}' src='/images/edit-redo.png' /></form></td></tr>";
	$Index++;
}
print "</table>";
&Header::closebox();

# html site end
&Header::closebigbox();
&Header::closepage();

sub read_header() {
	my $file = shift;
	my @headers="";
	my @lines=();
	tie @lines, 'Tie::File', $file, mode => O_RDONLY or die "Can't open $file for reading: $!\n";
	if (@lines < 4) { die "Bad file: $file\n"; }

	$headers[0] = $lines[2];
	$headers[1] = $lines[3];
	$headers[0] =~ s/[<,>,	]//g;
	$headers[0] =~ s/X-Envelope-From://gi;
	$headers[1] =~ s/[<,>,	]//g;
	$headers[1] =~ s/X-Envelope-To://gi;

	if ( $headers[0] eq "" ) { 
		$headers[0] = $lines[3];
		$headers[0] =~ s/[<,>,	]//g;
		$headers[1] = $lines[4];
		$headers[1] =~ s/[<,>,	]//g;
		$headers[1] =~ s/X-Envelope-To://gi;
	}
	$headers[0] =~ s/^\s+|\s+$//g;
	$headers[1] =~ s/^\s+|\s+$//g;

	#debug 
	#print "$headers[0] -> $headers[1]\n";
	return \@headers;
}

sub read_header_spam() {
	my $file = shift;
	my @headers="";
	my @lines=();
	tie @lines, 'Tie::File', $file, mode => O_RDONLY or die "Can't open $file for reading: $!\n";
	if (@lines < 4) { die "Bad file: $file\n"; }
	$headers[0] = $lines[2];
	$headers[0] =~ s/<//g;
	$headers[0] =~ s/>//g;
	$headers[0] =~ s/X-Envelope-From: //gi;
	$headers[1] = $lines[3];
	$headers[1] =~ s/<//g;
	$headers[1] =~ s/>//g;
	$headers[1] =~ s/X-Envelope-To: //gi;

	#debug 
	#print "$headers[0] -> $headers[1]\n";
	return \@headers;
}

sub deliver_file() {
	my $file = shift;
	my @stat = stat($file);

	# Print headers
	print "Content-Disposition: attachment; filename=" . &File::Basename::basename($file) . ".txt\n";
	print "Content-Type: application/octet-stream\n";
	print "Content-Length: $stat[7]\n";
	print "\n";

	# Deliver content
	open(FILE, "<$file") or die "Unable to open $file: $!";
	print <FILE>;
	close(FILE);
}
