#!/bin/bash
#set -x
#############################################################
#                                                           #
# File: mpcerts.sh                                          #
#                                                           #
# This script installs the needed self signed certificates  #
# for a mail gateway on IPFire                              #
#                                                           #
#############################################################

CFGDIR="/var/ipfire/mailgateway";
CONFFILE="${CFGDIR}/certs.conf"
CERTDIR="${CFGDIR}/cert";
DHFILE="dh2048.pem";
CURV="";

# move certs to new dir
if [ -f /etc/ssl/postfix-ecc.crt  ]; then mv -f postfix-rsa.crt ${CERTDIR}/; fi;
if [ -f /etc/ssl/postfix-rsa.crt  ]; then mv -f postfix-ecc.crt ${CERTDIR}/; fi;
if [ -f /etc/ssl/private/postfix-ecc.crt  ]; then mv -f postfix-rsa.crt ${CERTDIR}/; fi;
if [ -f /etc/ssl/private/postfix-rsa.crt  ]; then mv -f postfix-ecc.key ${CERTDIR}/; fi;

if [ -f "${CERTDIR}/postfix-rsa.crt" ]; then
	chown nobody:nobody ${CERTDIR}/postfix-*;
fi

# create config dir if not exist
mkdir -p /var/ipfire/mailgateway/cert;

if [ -e ${CONFFILE} ]; then
     eval $(/usr/local/bin/readhash ${CONFFILE});

else
     CRTY=""; STAT=""; CITY=""; ORGA=""; HOST=""; MAIL="";
fi;

# reads in variables from a config file
readhashint() {
	local VARNAME VARCHARS VARVAL;
	VARNAME='[A-Za-z_][A-Za-z0-9_]*';
	VARCHARS='A-Za-z0-9=/,.:%_@#+-';
	VARVAL="[${VARCHARS}]*";
	sed -ne "s/\(${VARNAME}\)=\(${VARVAL}\)$/\1=\2/p" ${1};
	# Accept space only if it's quoted
	sed -ne "s/\(${VARNAME}\)=\('[ ${VARCHARS}]*'\)$/\1=\2/p" ${1};
	return 0;}

check_certs_data() {
  if [ ! -e ${CONFFILE} ]; then
    echo -e "\033[32m Please provide your individual data... \033[0m ";

    echo -en "\033[s";
    while read -e -p "  County 'DE'        : " -i "${CRTY}" CRTY; do
      if [ -z ${CRTY} ]; then
          echo -en "\033[u";
      else 
          break;
      fi;
    done;

    echo -en "\033[s";
    while read -e -p "  State or province  : " -i "${STAT}" STAT; do
      if [ -z "${STAT}" ]; then
          echo -en "\033[u";
      else 
          break;
      fi;
    done;

    echo -en "\033[s";
    while read -e -p "  City               : " -i "${CITY}" CITY; do
      if [ -z "${CITY}" ]; then
          echo -en "\033[u";
      else 
          break;
      fi;
    done;

    echo -en "\033[s";
    while read -e -p "  Orgnaisation       : " -i "${ORGA}" ORGA; do
      if [ -z "${ORGA}" ]; then
          echo -en "\033[u";
      else 
          break;
      fi;
    done;

    echo -en "\033[s";
    while read -e -p "  Orgnaisation unit  : " -i "${UNIT}" UNIT; do
      if [ -z "${UNIT}" ]; then
          echo -en "\033[u";
      else 
          break;
      fi;
    done;

    echo -en "\033[s";
    while read -e -p "  Extertnal hostname : " -i "${HOST}" HOST; do
      if [ -z "${HOST}" ]; then
          echo -en "\033[u";
      else 
          break;
      fi;
    done;

    echo -en "\033[s";
    while read -e -p "  Mail address       : " -i "${MAIL}" MAIL; do
      if [ -z "${MAIL}" ]; then
          echo -en "\033[u";
      else 
          break;
      fi;
    done;

echo -e "CRTY='${CRTY}'\n\
STAT='${STAT}'\n\
CITY='${CITY}'\n\
ORGA='${ORGA}'\n\
UNIT='${UNIT}'\n\
HOST='${HOST}'\n\
MAIL='${MAIL}'" > ${CONFFILE};

  else
   eval $(readhashint ${CONFFILE});
    echo -e "\033[32m Subject file found. Your current data: \033[0m ";
    echo "  County code 2 char : ${CRTY}";
    echo "  State or provinece : ${STAT}";
    echo "  City               : ${CITY}";
    echo "  Orgnaisation       : ${ORGA}";
    echo "  Orgnaisation unit  : ${UNIT}";
    echo "  Extertnal hostname : ${HOST}";
    echo "  Mail address       : ${MAIL}";
  fi;
}

write_2048bit_dh-group() {
if [[ "$ANSWER" = "3" || ! -f  ${CERTDIR}/${DH2048FILE} ]]; then
  echo -en "\033[32mWrite 2048bit Diffie-Hellman group file for ECDHE support: \033[0m";
  cat > ${CERTDIR}/${DH2048FILE} << "EOF"
-----BEGIN DH PARAMETERS-----
MIIBCAKCAQEA2jfXlIzj969a3RAH+AASay5ep84NFpkMUKjR4bnznVBS8C6a2f2M
wg8vCF5K5HavsqhkAzVMfUGRgtjqp5gYSjZMOzB5jQC/XRiaPL37yiAhYGu6fHaX
ITbJbxSO145n+b3l5jqT0Xl67s8FkkbeyxtSJG9JXuP1hMCZ0WMBxGpIV4Hbbz/f
XdIKjK7lbJ8mdCIuyHVRF1WnNdAP3itOdLlyxJYaDrLZtjK9+K/+wUEFCtUKs7ld
6ljZvSFrFoYBwfCbcM6mE5nuvd8FuKR6c9qbPG2+SNiMT1X38YuBSeNJUctJ6P1+
RbNF7w/8D0Lj/rhKkXHmWZq0jj2urDHDgwIBAg==
-----END DH PARAMETERS-----
EOF
  chmod 644 ${CERTDIR}/${DHFILE};
  echo -e "\033[92mdone...\033[0m";
fi;
}

generate_2048_dh_file () {
	echo " ";
	rm -f ${CERTDIR}/${DHFILE}
	echo -e "\033[32mGenerate 2048bit Diffie-Hellman parameter for ECDHE support: \033[0m";
	echo -n "Please Wait... (on slow machines a long long time...)";
	openssl dhparam -out ${CERTDIR}/${DHFILE} -2 2048 > /dev/null 2>&1;
	chmod 644 ${CERTDIR}/${DHFILE};
	echo -e "\033[92mdone...\033[0m";
}

generate_3072_dh_file () {
	echo " ";
	rm -f ${CERTDIR}/${DHFILE}
	echo -e "\033[32mGenerate 3072bit Diffie-Hellman parameter for ECDHE support: \033[0m";
	echo -n "Please Wait...";
	openssl dhparam -out ${CERTDIR}/${DHFILE} -2 3072 > /dev/null 2>&1;
	chmod 644 ${CERTDIR}/${DHFILE};
	echo -e "\033[92mdone...\033[0m";
}

check_certificates() {
# Create certificate, key, csr and DH parameter
  local CRTY STAT CITY ORGA UNIT HOST MAIL ANSWER;
  mkdir -p ${POST}/certs;
  cd ${POST}/certs;
  while true
  do
    clear;
    echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
    echo -e "\033[1;36m-                  Create postfix RSA and ECC certificates                     -\033[0m";
    echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
    echo " ";
    if [ -f ${CERTDIR}/postfix-rsa.crt ]; then
       echo -e "\033[32m TLS RSA Certificate is already present...\033[0m";
    else
      echo -e "\033[33m TLS RSA Certificate is not present...\033[0m";
    fi;
    if [ -f ${CERTDIR}/postfix-ecc.crt ]; then
      echo -e "\033[32m TLS ECC Certificate is already present...\033[0m";
    else
      echo -e "\033[33m TLS ECC Certificate is not present...\033[0m";
    fi;
    echo " ";
    if [ ! -z ${CURV} ]; then
      echo -e "\033[92m Enhanced configuration found. Please use web interface for changes.\033[0m";
      echo -e "\033[91m Changing certificate settings are disabled!\033[0m";
    else
      echo -e "\033[33m Mailgate certificate are unconfigured.\033[0m";
    fi;

    echo " ";
    check_certs_data;
    echo " ";
    echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
    echo -n "Is this correct? [y/n]";
    read -n1 ANSWER;
      case $ANSWER in
	y)
	break;
	;;
	n)
	if [ -z ${CURV} ]; then
		rm -f ${CONFFILE} ${CERTDIR}/postfix-*.crt$ {CERTDIR}/postfix-*.key;
		echo " ";
		check_certs_data;
	fi;
	;;
    esac
  done;
  echo " ";

  if [ ! -f ${CERTDIR}/postfix-rsa.crt ]; then
    echo -en "\033[32mGenerate RSA certificate... : \033[0m";
    openssl genrsa -out ${CERTDIR}/postfix-rsa.key 4096  > /dev/null 2>&1;
    openssl req -new -x509 -sha256 -extensions v3_req -days 730 \
	-subj "/C=${CRTY}/ST=${STAT}/L=${CITY}/O=${ORGA}/OU=${UNIT}/CN=${HOST}/emailAddress=${MAIL}" \
	-key ${CERTDIR}/postfix-rsa.key -out ${CERTDIR}/postfix-rsa.crt > /dev/null 2>&1;
    echo -e "\033[92mdone...\033[0m";
  fi;

  if [ ! -f ${CERTDIR}/postfix-ecc.crt ]; then
    echo -en "\033[32mGenerate ECC certificate... : \033[0m";
    openssl req -new -newkey ec -pkeyopt ec_paramgen_curve:secp384r1 -days 720 -sha256 -nodes -x509 -extensions v3_req \
	-subj "/C=${CRTY}/ST=${STAT}/L=${CITY}/O=${ORGA}/OU=${UNIT}/CN=${HOST}/emailAddress=${MAIL}" \
	-keyout ${CERTDIR}/postfix-ecc.key -out ${CERTDIR}/postfix-ecc.crt > /dev/null 2>&1;
    echo -e "\033[92mdone...\033[0m"
  fi;

  #set keyfile rights
  chown nobody:nobody ${CERTDIR}/postfix-*.crt;
  chown nobody:nobody ${CERTDIR}/postfix-*.key;
  chmod 644 ${CERTDIR}/postfix-*.crt;
  chmod 400 ${CERTDIR}/postfix-*.key;

ANSWER="0";
while true
 do
    clear;
    echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
    echo -e "\033[1;36m-                      Postfix TLS DH parameter creation                       -\033[0m";
    echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
    echo " ";
    if [ -f ${CERTDIR}/${DHFILE} ]; then
	echo -e "\033[32m The ${DHFILE} file is present.\033[0m";
    else
	echo " The ${DHFILE} file not found.";
    fi;
    echo " ";
    echo -e "\033[32mAll non-existent DH-files are recreated after quit this menu!\033[0m";
    echo " Press '1' to generate 2048 Bit DH group";
    echo " Press '2' to generate 3072 Bit DH group";
    echo " Press '3' to write 2048bit DH-group file from package (only testing)";
    echo " Press 'q' to quit this menu";
    echo " ";
    echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
    echo -n "Please select: ";
    read -n 1 ANSWER;
    case $ANSWER in
    1)
    generate_2048_dh_file;
    ;;
    2)
    generate_3072_dh_file;
    ;;
    3)
    write_2048bit_dh-group;
    ;;
    q)
    break;
    ;;
  esac
done

}

check_certificates;

if [ ! -f ${CERTDIR}/${DHFILE} ]; then 
	generate_2048_dh_file;
	chown nobody:nobody ${CERTDIR}/${DHFILE};
fi;

chown nobody:nobody ${CFGDIR};
chown nobody:nobody ${CERTDIR};
chown nobody:nobody ${CONFFILE};
chown nobody:nobody ${CFGDIR}/main.conf;

# remove old dh files
if [ -f /etc/ssl/dh_512.pem ]; then rm -f /etc/ssl/dh_512.pem; fi;
if [ -f /etc/ssl/dh_1024.pem ]; then rm -f /etc/ssl/dh_1024.pem; fi;
unset CERTDIR CONFFILE DHFILE;
echo " ";
#end mpcerts.sh
