#!/bin/bash
############################################################
#                                                          #
# File: mpconfig.sh                                        #
#                                                          #
# This script installing Mail Gateway templates on IPFire  #
#                                                          #
############################################################

# Set paths
POSTDIR="/etc/postfix";
CONFDIR="/var/ipfire/mailgateway"
if [ ! -d "${CONFDIR}" ]; then mkdir -p ${CONFDIR}/maps; fi;
CFGMAIN="${CONFDIR}/main.conf"

ACONF="/etc/amavisd.conf";
MAIN="${POSTDIR}/main.cf";
VIRT="${POSTDIR}/maps/virtual";

TCONF="${CONFDIR}/maps/transport";
RCONF="${CONFDIR}/maps/relay_domains";
NCONF="${CONFDIR}/maps/network_table";
SCONF="${CONFDIR}/maps/sasl_passwd";

LOG="/tmp/installer.log";
TRANSPORT_OLD="";

# Command line args test
NOMENU="0";
QUIET="0";
ONLYPF="0";
for arg; do
  if [ $arg = "-nomenu" ]; then NOMENU="1"; fi;
  if [ $arg = "-quiet" ]; then QUIET="1"; NOMENU="1"; fi;
  if [ $arg = "-opf" ]; then ONLYPF="1"; echo "Starting postfix only configuration"; fi;
done

# Clear vars
MYDOMAIN="";
MSIP="";
MSPORT="";
DOMAINLIST="";
HOSTLIST="";
RELAYON="off";
RELAYHOST="";
RELAYPORT="";
RELAYUSER="name@domain.com";
RELAYPASS="pass";
array=();

# reads in variables from a config file
readhashint() {
	local VARNAME VARCHARS VARVAL;
	VARNAME='[A-Za-z_][A-Za-z0-9_]*';
	VARCHARS='A-Za-z0-9=/,.:%_@#+-';
	VARVAL="[${VARCHARS}]*";
	sed -ne "s/\(${VARNAME}\)=\(${VARVAL}\)$/\1=\2/p" ${1};
	# Accept space only if it's quoted
	sed -ne "s/\(${VARNAME}\)=\('[ ${VARCHARS}]*'\)$/\1=\2/p" ${1};
	return 0;}

# read current transport config
if [ -f ${CFGMAIN} ]; then 
	eval $(readhashint ${CFGMAIN});
	RELAYPASS=$(cat "${CFGMAIN}" |grep RELAYPASS| sed "s|RELAYPASS=||;s|'||g")
fi;

change_relay_config() {
while true
 do
   tput clear;
printf "\033[1;36m--------------------------------------------------------------------------------
                    Postfix outbound relay configuration                   
--------------------------------------------------------------------------------\033[0m\n
Outbound relay is current enabled: \033[32m${RELAYON}\033[0m\n
Press '1' to enable or disable outbound relay
Press '2' to change outbound relay configuration
Press 'q' to quit this menu and go back\n
\033[32m Current configuration: \033[0m
  Relay host     : ${RELAYHOST}
  Relay host port: ${RELAYPORT}
  Relay user     : ${RELAYUSER}
  Relay password : "; echo "${RELAYPASS}";
printf "\033[1;36m--------------------------------------------------------------------------------\033[0m
Please select: ";
   read -n 1 answer;
   echo " ";
   case "$answer" in
	1)
	  if [ "${RELAYON}" = "no" ]; then RELAYON="yes"; FF=1; else FF=0; fi;
	  if [[ "${FF}" = "0" && "${RELAYON}" = "yes" ]]; then RELAYON="no"; fi;
	  uset FF;
	;;

	2)
	if [ -z "${RELAYHOST}" ]; then
	  read -ep "Please enter outbound relay host      : " RELAYHOST;
	else
	  read -ep "Please enter outbound relay host      : " -i ${RELAYHOST} RELAYHOST;
	fi;
	if [ -z "${RELAYPORT}" ]; then
	  read -ep "Please enter outbound relay host port : " RELAYPORT;
	else
	  read -ep "Please enter outbound relay host port : " -i ${RELAYPORT} RELAYPORT;
	fi;
	if [ -z "${RELAYUSER}" ]; then
	  read -ep "Please enter outbound relay user      : " RELAYUSER;
	else
	  read -ep "Please enter outbound relay user      : " -i ${RELAYUSER} RELAYUSER;
	fi;
	if [ -z "${RELAYPASS}" ]; then
	  read -ep "Please enter outbound relay paswword  : " RELAYPASS;
	else
	  read -ep "Please enter outbound relay paswword  : " -i ${RELAYPASS} RELAYPASS;
	fi;
	;;

	q)
	  if [ "${RELAYON}" = "yes" ]; then
            if [[ -z "${RELAYHOST}" || -z "${RELAYUSER}" || -z "${RELAYPASS}" ]]; then
		echo " Required settings are empty!";
		sleep 1
	     else
		break;
	    fi;
  	  else   
            break;
	  fi;
	;;
   esac
 done;
 echo " ";
 if [[ ${answer} == 1 ]]; then install_fetchmail; fi;
 echo " ";
}

main_menu() {
# Menu
	while true
	do
		clear;
		printf "\033[1;36m
--------------------------------------------------------------------------------
-                 Mail Gateway domain and server configuration                 -
--------------------------------------------------------------------------------\033[0m\n
Press '1' to set mail domain, external hostname and server IP
Press '2' to change mail server TCP/IP port (if needed)
Press '3' to change additional relay domains
Press '4' to change additional internal hosts for sending outbound mail
Press '5' to change outbound relay configuration (if needed)
Press 'q' to quit this menu and go back to main menu\n
\033[32m Current configuration: \033[0m
  Primary mail domain : ${MYDOMAIN}
  External hostanme   : ${MYHOSTNAME}
  Mail server IP      : ${MSIP}
  Mail server port    : ${MSPORT}\n
\033[32m Additional domains and hosts: \033[0m
  Domains : ${DOMAINLIST}
  Hosts   : ${HOSTLIST}\n
 Using outbound relay server: \033[32m${RELAYON}\033[0m
\033[1;36m--------------------------------------------------------------------------------\033[0m
Please select: ";
		read -n 1 menu;
		printf "\n"
		case "${menu}" in
		1)
		# Modify main.cf and amavisd.conf for public maildomain
		if [ -z "${MYDOMAIN}" ]; then
			read -ep "Please enter your public maildomain : " MYDOMAIN;
		else
			read -ep "Please enter your public maildomain : " -i ${MYDOMAIN} MYDOMAIN;
		fi;
		if [ -z "${MYHOSTNAME}" ]; then
			read -ep "Please enter your external Hostname : " MYHOSTNAME;
		else
			read -ep "Please enter your external Hostname : " -i ${MYHOSTNAME} MYHOSTNAME;
		fi;
		if [ -z "${MSIP}" ]; then
		read -ep "Please enter the IP address of your mail server: " MSIP;
		else
			read -ep "Please enter the IP address of your mail server: " -i ${MSIP} MSIP;
		fi;
		;;

		2)
		echo "Please enter the TCP/IP port of your mail server."
		if [ -z "${MSPORT}" ]; then
			read -ep "Port: " MSPORT;
		else
			read -ep "Port: " -i ${MSPORT} MSPORT;
		fi;
		;;

		3)
		echo "Please change or add extra domains comma separated."
		if [ -z "${DOMAINLIST}" ]; then
			read -ep "Domains: " DOMAINLIST;
		else
			read -ep "Domains: " -i ${DOMAINLIST} DOMAINLIST;
		fi;
		;;


		4)
		echo "The IP list must be comma separated and with network definition (eg. /32)."
		if [ -z "${HOSTLIST}" ]; then
			read -ep "Hosts: " HOSTLIST;
		else
			read -ep "Hosts: " -i ${HOSTLIST} HOSTLIST;
		fi;
		;;


		5)
		change_relay_config;
		;;

		q)
		if [[ -z "${MYDOMAIN}" || -z "${MYHOSTNAME}" || -z "${MSIP}" || "${MYDOMAIN}" == "domain.abcd" ]]; then
			echo "Some required settings are empty or not configured!";
		sleep 1
		else   
			break;
		fi;
		;;
	esac
	done;
}

if [ "${NOMENU}" = "0" ]; then main_menu; fi;

# genereate transtport string
if [ -z "${MSPORT}" ]; then 
	TRANSPORT="${MYDOMAIN} smtp:${MSIP}"; 
else
	TRANSPORT="${MYDOMAIN} smtp:${MSIP}:${MSPORT}"
fi;


if [ "${QUIET}" = "0" ]; then printf "\033[32mWriting domain configuration: \033[0m"; fi;
# main.cf
postconf "mydomain = ${MYDOMAIN}";
postconf "myhostname = ${MYHOSTNAME}";

# amavisd.conf
if [ "${ONLYPF}" = "0" ]; then
	sed -i "s/${MYDOMAIN}/${MYDOMAIN}/" ${ACONF};
	sed -i "s/${MYHOSTNAME}/${MYHOSTNAME}/" ${ACONF};
	sed -i "s/$mydomain   = 'mydomain.com'/$mydomain   = '${MYDOMAIN}'/" ${ACONF};
	sed -i "s/$myhostname = 'mail.mydomain.com'/$myhostname = '${MYHOSTNAME}'/" ${ACONF};
fi;

# virtual
sed -i '/^$/d' ${VIRT}; #remove empty lines
sed -i '/^postmaster/d' ${VIRT}; #delete old
sed -i '/^abuse/d' ${VIRT}; #delete old
sed -i "$ a postmaster postmaster@${MYDOMAIN}" ${VIRT};
sed -i "$ a abuse abuse@${MYDOMAIN}" ${VIRT};

if [ "${QUIET}" = "0" ]; then printf "\033[92mDone...\033[0m\n"; fi;
if [ "${QUIET}" = "0" ]; then printf "\033[32mWriting transport configuration: \033[0m"; fi;

# postfix transport file
printf "# ${TCONF} file
# Do not change this file manually, use mpconfig.sh\n" > ${TCONF};

if [ -z "${MSPORT}" ]; then
	printf "${MYDOMAIN} smtp:${MSIP}\n" >> ${TCONF};
else
	printf "${MYDOMAIN} smtp:${MSIP}:${MSPORT}\n" >> ${TCONF};
fi;
if [ ! -z "${DOMAINLIST}" ]; then 
	IFS=$',' read -ra array <<< ${DOMAINLIST};
	for i in "${array[@]}"
	do
		if [ -z "${MSPORT}" ]; then
			echo "${i} smtp:${MSIP}" >> ${TCONF};
		else
			echo "${i} smtp:${MSIP}:${MSPORT}" >> ${TCONF};
		fi;
	done;
fi;

# network table
echo "# ${NCONF} file" > ${NCONF};
echo "# Do not change this file manually, use mpconfig.sh" >> ${NCONF};
echo "127.0.0.0/8 OK" >> ${NCONF};
echo "${MSIP}/32 OK" >> ${NCONF};
if [ ! -z "${HOSTLIST}" ]; then 
	IFS=$',' read -ra array <<< ${HOSTLIST};
	for i in "${array[@]}"
	do
		echo "${i} OK" >> ${NCONF};
	done;
fi;

# relay domains
echo "# ${RCONF} file" > ${RCONF};
echo "# Do not change this file manually, use mpconfig.sh" >> ${RCONF};
echo "${MYDOMAIN} 1" >> ${RCONF};
if [ ! -z "${DOMAINLIST}" ]; then 
	IFS=$',' read -ra array <<< ${DOMAINLIST};
	for i in "${array[@]}"
	do
		echo "${i} 1" >> ${RCONF};
	done;
fi;

# update transport config file
printf "# IPfire mailproxy main configuration file
# do not edit this file manually, use mpconfig.sh
MYDOMAIN='${MYDOMAIN}'
MYHOSTNAME='${MYHOSTNAME}'
MSIP='${MSIP}'
MSPORT='${MSPORT}'
DOMAINLIST='${DOMAINLIST}'
HOSTLIST='${HOSTLIST}'
RELAYON='${RELAYON}'
RELAYHOST='${RELAYHOST}'
RELAYPORT='${RELAYPORT}'
RELAYUSER='${RELAYUSER}'\n" > ${CFGMAIN};
echo "RELAYPASS='${RELAYPASS}'" >> ${CFGMAIN};

# remove old relay config file
rm -f ${CONFDIR}/relay.conf;

if [ "${QUIET}" = "0" ]; then echo -e "\033[92mDone...\033[0m"; fi;

# check relay configuration changes
if [ "${QUIET}" = "0" ]; then  echo -en "\033[32mWriting relay configuration: \033[0m"; fi;
if [ "${RELAYON}" = "on" ]; then
	# main.cf
	postconf "smtp_sasl_auth_enable = yes";
	postconf "smtp_sasl_security_options = noanonymous";
	postconf "smtp_sasl_password_maps = lmdb:${SCONF}";
	postconf "relayhost = ${RELAYHOST}";
	# sasl_passwd
	if [ ! -f ${SCONF} ]; then touch ${SCONF}; chmod 640 ${SCONF}; fi;
	sed -i "/^${RELAYHOST_OLD}/d" ${SCONF}; #delete old
	sed -i "/^${RELAYHOST}/d" ${SCONF}; #delete duplicates
	echo "${RELAYHOST} ${RELAYUSER}:${RELAYPASS}" >> ${SCONF};
	postmap lmdb:${SCONF} > /dev/null;
else
	postconf "smtp_sasl_auth_enable = no";
	postconf "smtp_sasl_password_maps =";
	postconf "relayhost =";
fi;
if [ "${QUIET}" = "0" ]; then  echo -e "\033[92mDone...\033[0m"; fi;

# check if rspamd installed and running
if [ -f /etc/rc.d/init.d/rspamd ]; then
	pidof -x "rspamd" > /dev/null;
	if [ "${?}" = "0" ]; then
		if [ "${QUIET}" = "0" ]; then  echo -en "\033[32mRspamd daemon found. Enable milter configuration: \033[0m"; fi;
		postconf "smtpd_milters = unix:/var/run/rspamd-proxy.sock";
		postconf "non_smtpd_milters = \${smtpd_milters}";
		postconf "milter_mail_macros = i {mail_addr} {client_addr} {client_name} {auth_type} {auth_authen}";
		postconf "milter_protocol = 6";
		if [ "${QUIET}" = "0" ]; then echo -e "\033[92mDone...\033[0m"; fi;
   	else
		if [ "${QUIET}" = "0" ]; then echo -n "Rspamd daemon not found. Disable milter configuration: "; fi
		postconf "smtpd_milters =";
		postconf "non_smtpd_milters =";
		if [ "${QUIET}" = "0" ]; then echo -e "\033[92mDone...\033[0m"; fi;
	fi;
fi

if [ "${QUIET}" = "0" ]; then  echo -en "\033[32mGererating database files: \033[0m"; fi
postmap lmdb:${VIRT} > /dev/null;
postmap lmdb:${RCONF} > /dev/null;
postmap lmdb:${TCONF} > /dev/null;
if [ -f "${SCONF}" ]; then postmap lmdb:${SCONF}; fi > /dev/null;
chown -R nobody:nobody ${CONFDIR}/maps/;

if [ "${QUIET}" = "0" ]; then echo -e "\033[92mDone...\033[0m"; fi;

# disable backwards-compatible settings
postconf "compatibility_level = 3.6"
# set transport file
postconf "transport_maps = lmdb:${TCONF}"

# reload postfix configuration if running
pidof -x /usr/lib/postfix/master > /dev/null
if [ "${?}" = "0" ]; then
	if [ "${QUIET}" = "0" ]; then
		postfix reload;
	else
		postfix reload 2&> /dev/null;
	fi;
fi;

# clear vars
unset POSTDIR VIRT TCONF ACONF NCONF RCONF MYDOMAIN MYHOSTNAME CONFDIR CFGMAIN;
unset RELAYON RELAYHOST RELAYUSER RELAYPASS DOMAINLIST i array;

# end of msconfig.sh
