#!/bin/bash
#set -x

############################################################
#                                                          #
# File: mpfilter.sh                                        #
#                                                          #
# This script installs the postfix filter templates        #
# for the IPFire mailserver package                        #
#                                                          #
# Build time: Mon Apr 22 09:59:32 AM CEST 2024
#                                                          #
############################################################

# Vars
CONFIGDIR="/etc/postfix";
MAPSDIR="${CONFIGDIR}/maps";
mkdir -p ${MAPSDIR};

echo -e "\033[32mInstalling postfix filter: \033[0m";

#### sender_access ####
echo -en "Install sender_access template now: ";
if [ ! -f ${MAPSDIR}/sender_access ]; then
cat > ${MAPSDIR}/sender_access << "EOF"
#
# IPFire Mail Gateway Project 
# sender_access file
#
# Use the postmap command whenever you change this file
#
# Commands:
# OK  
# REJECT optional Text
# REDIRECT user@domain  # redirect to another Address 
# BCC user@domain       # send to additional address
# DISCARD optional Text
#
# Address example
# 
# user@domain  # Consistent with the address match
# user@        # Agrees only with the names match
# domain.tld   # whole Mail-Domain

# Sender address verification whitelist
account.microsoft.com OK
cws-boco.de OK
cws-boco.com OK
dak.de OK
drk.de OK
etl.de OK
eurodata.de OK
ikk-nord.de OK
leg-thueringen.de OK
itsg.de OK
vemags.de OK 
bund-verlag.de OK
ksp-online.info OK
salzag.de OK
staatsanzeiger-eservices.de OK
staatsanzeiger-eservices.eu OK
t-ddm.com OK
tof.de OK
toringi.net OK
vodafone.de OK
volkswagen.de OK

# Name blacklist
newsletter@ REJECT unwanted content
news@ REJECT unwanted content
mailing@ REJECT unwanted content
mailings@ REJECT unwanted content
toner-express@ REJECT unwanted content

# Complete adresses blacklist
postmaster@mailer-service.de REJECT unwanted content
auto-confirm@amazon.com REJECT
EOF
  echo -e "\033[92mdone...\033[0m";
else
  echo -e "\033[92mexisting...\033[0m";
fi;

#### sld_access ####

echo -en "Install sld_access template now: ";
if [ ! -f ${MAPSDIR}/sld_access ]; then
  cat > ${MAPSDIR}/sld_access << "EOF"
#
# IPFire Mail Gateway Project 
# sld_access file
#
# Use the postmap command whenever you change this file
#
# Second level domain access control file (ACL)
# Last update 03.03.2017
# Commands:
# OK  
# REJECT optional Text
# REDIRECT user@domain  # redirect an other address 
# BCC user@domain       # send to additional address
# DISCARD optional Text
# 550 optional Text
#
# Address example 
# 
# domain.tld   # whole Mail-Domain
#
4infomaxx.com REJECT SLDBL
addresscheck.eu REJECT SLDBL
allglobalcircle.com REJECT SLDBL
anfrage-freundschaft.com REJECT SLDBL
Apotheke-Online.com REJECT SLDBL
arimailing.eu REJECT SLDBL
avdatdesign.de REJECT SLDBL
badoo.com REJECT SLDBL
ba-klick.com REJECT SLDBL
berola-film.de REJECT SLDBL
bildfreigabe.com REJECT SLDBL
bildplus-und-lottogutschein.com REJECT SLDBL
bluehornet.com REJECT SLDBL
branchen-info.net REJECT SLDBL
bsi-global-email.com REJECT SLDBL
business-wissen.de REJECT SLDBL
cashpro.com REJECT SLDBL
charter.com REJECT SLDBL
cloud-elite.com REJECT SLDBL
cmail20.com REJECT SLDBL
constantcontact.com REJECT SLDBL
consultmailing.com REJECT SLDBL
contactlab.it REJECT SLDBL
coolesterol.com REJECT SLDBL
crsend.com REJECT SLDBL
dcimail.de REJECT SLDBL
debranchen.net REJECT SLDBL
delta-com.de REJECT SLDBL
deria-com.de REJECT SLDBL
deriacom.de REJECT SLDBL
deutschedomain.com REJECT SLDBL
deutscher-infoservice.com REJECT SLDBL
drivinghost.biz REJECT SLDBL
dynect-mailer.net REJECT SLDBL
eigbox.net REJECT SLDBL
einheits-tarif.net REJECT SLDBL
emarsys.net REJECT SLDBL
emsmtp.com REJECT SLDBL
excomed.com REJECT SLDBL
facebook.com REJECT SLDBL
facebook-mittelstand.ch REJECT SLDBL
finanz-institut.com REJECT SLDBL
flotte-mail.de REJECT SLDBL
foxmail.com REJECT SLDBL
generate-contacts.org REJECT SLDBL
groupon.com REJECT SLDBL
habcommunity.com REJECT SLDBL
hcscommunity.com REJECT SLDBL
heritagemails.com REJECT SLDBL
hinet.net REJECT service not available SLDBL
ihr-angebot.org REJECT SLDBL
imaxxi.com REJECT SLDBL
instagram.com REJECT SLDBL
intelleroptional.com REJECT SLDBL
ip-pool.com REJECT service not available SLDBL
komm-auf-kreuzfahrt.net REJECT SLDBL
kundenmailing.net REJECT SLDBL
line-of-biz.de REJECT SLDBL
linkedin.com REJECT SLDBL
mailing.wortmann.de REJECT SLDBL
mailminion.net REJECT SLDBL
mailsuche.net REJECT SLDBL
mandrillapp.com REJECT SLDBL
mcc-kongresse.de REJECT SLDBL
mcsv.net REJECT SLDBL
medallia.eu REJECT SLDBL
messe-muenchen.de REJECT SLDBL
muenchner-cyber-dialog.de REJECT SLDBL
nachrichten-anzeige.com REJECT SLDBL
newsbestonly.com REJECT SLDBL
news-contacts.info SLDBL
newsletter-empfehlung.de REJECT SLDBL
newsletter.hotel.de REJECT SLDBL
newsletter-hub.com REJECT SLDBL
newsletterverwaltung.de REJECT SLDBL
nl2go.com REJECT SLDBL
omrglobus.com REJECT SLDBL
otto-office.com REJECT SLDBL
owknet.de REJECT SLDBL
perfora.net REJECT SLDBL
potenz.de REJECT SLDBL
potenzmittel.de REJECT SLDBL
povsz.ru REJECT SLDBL
proconnect-mail.com REJECT SLDBL
profiler24.de REJECT SLDBL
proyos.de REJECT SLDBL
pusten.net REJECT SLDBL
rapidmail.de REJECT SLDBL
routmail.biz REJECT SLDBL
rsgsv.net REJECT SLDBL
rtomail.com REJECT SLDBL
rtomail.net REJECT SLDBL
schneller-vergleich.net REJECT SLDBL
sendgrid.me REJECT SLDBL
sendgrid.net REJECT SLDBL
sendnode.com REJECT SLDBL
smarttools.de REJECT SLDBL
softlayer.com REJECT SLDBL
solidbroadcasting.com REJECT SLDBL
spb.komus.net REJECT SLDBL
speedsending.org REJECT SLDBL
sponsortraffic.net REJECT SLDBL
springerfachmedien-muenchen.de REJECT SLDBL
srv3.de REJECT SLDBL 
stage-entertainment.de REJECT SLDBL
stayfriends.de REJECT SLDBL
stepnet.de REJECT SLDBL
subscribermail.com REJECT SLDBL
systemausfall-hilfe.eu REJECT SLDBL
tele.net REJECT SLDBL
time-4-change.de REJECT SLDBL
transferbroadcast.org REJECT SLDBL
transfermailing.biz REJECT SLDBL
travel-vip.de REJECT SLDBL
truxchange.de REJECT SLDBL
umgebungssuche.com REJECT SLDBL
umsatzwunder.de REJECT SLDBL
versandapotheke-allgaeu.de REJECT SLDBL
weka-businessmedien.de REJECT SLDBL
weltbild.de REJECT SLDBL
weltbild-it.de REJECT SLDBL
wirtschaftsverlag-gesundheit.de REJECT SLDBL
wocheninformationen.com REJECT SLDBL
xante.com REJECT SLDBL
xqueue.com REJECT SLDBL
xrite.com REJECT SLDBL
ymlpsrv.com REJECT SLDBL
ziftsolutions.com REJECT SLDBL
zmd0.com REJECT SLDBL
romenion.eu REJECT SLDBL
vnorbert.com REJECT scan not allowed SLDBL
googleusercontent.com REJECT SLDBL
#
# Whitelist 
#

EOF
  echo -e "\033[92mdone...\033[0m";
else
  echo -e "\033[92mexisting...\033[0m";
fi;

echo -en "Install tld_access template now: ";
if [ ! -f ${MAPSDIR}/tld_access ]; then
 cat > ${MAPSDIR}/tld_access << "EOF"
#
# IPFire Mail Gateway Project 
# tld_access file
#
# Use the postmap command whenever you change this file
#
# This file is only for Top level Domains
#
# Saint Helena, Ascension and Tristan da Cunha
ac 550 service not available TLDBL
# Andorra
ad 550 service not available TLDBL
# United Arab Emirates
ae 550 service not available TLDBL
# Afghanistan
af 550 service not available TLDBL
########## Antigua and Barbuda and german Aktiengesellschaft
#ag 550 service not available TLDBL
# Anguilla
ai 550 service not available TLDBL
# Albania
al 550 service not available TLDBL
# Nagorno-Karabakh Republic
am 550 service not available TLDBL
# Angola
ao 550 service not available TLDBL
# Antarctica
aq 550 service not available TLDBL
# Argentina
ar 550 service not available TLDBL
# American Samoa
as 550 service not available TLDBL
########## Austria
#at 550 service not available TLDBL
# Australia
au 550 service not available TLDBL
# Aruba
aw 550 service not available TLDBL
# Ãƒâ€¦land Islands
ax 550 service not available TLDBL
# Azerbaijan
az 550 service not available TLDBL
# Bosnia and Herzegovina
ba 550 service not available TLDBL
# Barbados
bb 550 service not available TLDBL
# Bangladesh
bd 550 service not available TLDBL
########## Belgium
#be 550 service not available TLDBL
# Burkina Faso
bf 550 service not available TLDBL
# Bulgaria
bg 550 service not available TLDBL
# Bahrain
bh 550 service not available TLDBL
# Burundi
bi 550 service not available TLDBL
# Benin
bj 550 service not available TLDBL
# Bermuda
bm 550 service not available TLDBL
# Brunei Darussalam
bn 550 service not available TLDBL
# Bolivia
bo 550 service not available TLDBL
# Brazil
br 550 service not available TLDBL
# Bahamas
bs 550 service not available TLDBL
# Bhutan
bt 550 service not available TLDBL
# Botswana
bw 550 service not available TLDBL
# Belarus
by 550 service not available TLDBL
# Belize
bz 550 service not available TLDBL
# Canada
ca 550 service not available TLDBL 
# Cocos (Keeling) Islands
cc 550 service not available TLDBL
# Democratic Republic of Congo
cd 550 service not available TLDBL
# Central African Republic   
cf 550 service not available TLDBL
# Republic of the Congo
cg 550 service not available TLDBL
########## Switzerland  
#ch 550 service not available TLDBL
# Cote´te d'Ivoire 
ci 550 service not available TLDBL
# Cook Islands
ck 550 service not available TLDBL
# Chile
cl 550 service not available TLDBL
# Cameroon
cm 550 service not available TLDBL
# People's Republic of China
cn 550 service not available TLDBL
# Colombia
co 550 service not available TLDBL
# Costa Rica
cr 550 service not available TLDBL
# Cuba
cu 550 service not available TLDBL
# Cape Verde
cv 550 service not available TLDBL
# Curassao
cw 550 service not available TLDBL
# Christmas Island
cx 550 service not available TLDBL
# Cyprus
cy 550 service not available TLDBL
########## Czech Republic
#cz 550 service not available TLDBL
########## Germany
#de 550 service not available TLDBL
# Djibouti
dj 550 service not available TLDBL
########## Denmark
# dk 550 service not available TLDBL
# Dominica
dm 550 service not available TLDBL
# Dominican Republic
do 550 service not available TLDBL
# Algeria
dz 550 service not available TLDBL
# Ecuador
ec 550 service not available TLDBL
# Estonia
ee 550 service not available TLDBL
# Egypt
eg 550 service not available TLDBL
# Eritrea
er 550 service not available TLDBL
# Spain
es 550 service not available TLDBL
# Ethiopia
et 550 service not available TLDBL
########## Europe
#eu 550 service not available TLDBL
# Finnland
fi 550 service not available TLDBL
# Fidschi
fj 550 service not available TLDBL
# Falkland Islands
fk 550 service not available TLDBL
# Federated States of Micronesia
fm 550 service not available TLDBL
# Faroe Islands
fo 550 service not available TLDBL
########## France
#fr 550 service not available TLDBL
# Gabon Telecom
ga 550 service not available TLDBL
# Grenada
gd 550 service not available TLDBL
# Georgia
ge 550 service not available TLDBL
# French Guiana
gf 550 service not available TLDBL
# Bailiwick of Guernsey
gg 550 service not available TLDBL
# Ghana
gh 550 service not available TLDBL
# Gibraltar
gi 550 service not available TLDBL
# Greenland
gl 550 service not available TLDBL
# Gambia
gm 550 service not available TLDBL
# Guinea
gn 550 service not available TLDBL
# Guadeloupe
gp 550 service not available TLDBL
# Equatorial Guinea
gq 550 service not available TLDBL
# Greece
gr 550 service not available TLDBL
# South Georgia and the South Sandwich Islands
gs 550 service not available TLDBL
# Guatemala
gt 550 service not available TLDBL
# Guam
gu 550 service not available TLDBL
# Guinea-Bissau
gw 550 service not available TLDBL
# Guyana
gy 550 service not available TLDBL
# Honkong
hk 550 service not available TLDBL
# Heard and McDonald Islands
hm 550 service not available TLDBL
# Honduras
hn 550 service not available TLDBL
# Croatia
hr 550 service not available TLDBL
# Haiti 
ht 550 service not available TLDBL
# Hungary
hu 550 service not available TLDBL
# Indonesia
id 550 service not available TLDBL
# Ireland
ie 550 service not available TLDBL
# Israel
il 550 service not available TLDBL
# Isle of Man
im 550 service not available TLDBL
# India
in 550 service not available TLDBL
# British Indian Ocean Territory
io 550 service not available TLDBL
# Iraq
iq 550 service not available TLDBL
# Iran
ir 550 service not available TLDBL
# Iceland
is 550 service not available TLDBL
########### Italy
# it 550 service not available TLDBL
# Jersey
je 550 service not available TLDBL
# Jamaica
jm 550 service not available TLDBL
# Jordan
jo 550 service not available TLDBL
# Japan
jp 550 service not available TLDBL
# Kenya
ke 550 service not available TLDBL
# Kyrgyzstan
kg 550 service not available TLDBL
# Cambodia
kh 550 service not available TLDBL
# Kiribati
ki 550 service not available TLDBL
# Comoros
km 550 service not available TLDBL
# Saint Kitts and Nevis
kn 550 service not available TLDBL
# North Korea
kp 550 service not available TLDBL
# South Korea
kr 550 service not available TLDBL
# Kuwait
kw 550 service not available TLDBL
# Cayman Islands
ky 550 service not available TLDBL
# Kazakhstan
kz 550 service not available TLDBL
# Laos
la 550 service not available TLDBL
# Lebanon
lb 550 service not available TLDBL
# Saint Lucia
lc 550 service not available TLDBL
########### Lichtenstein
# li 550 service not available TLDBL
# Sri Lanka
lk 550 service not available TLDBL
# Liberia
lr 550 service not available TLDBL
# Lesotho
ls 550 service not available TLDBL
# Lithuania
lt 550 service not available TLDBL
# Luxembourg
lu 550 service not available TLDBL
# Latvia
lv 550 service not available TLDBL
# Libya
ly 550 service not available TLDBL
# Morocco
ma 550 service not available TLDBL
# Monaco 
mc 550 service not available TLDBL
# Moldova
md 550 service not available TLDBL
# Montenegro or other services 
#me 550 service not available TLDBL
# Madagascar
mg 550 service not available TLDBL
# Marshall Islands
mh 550 service not available TLDBL
# Macedonia
mk 550 service not available TLDBL
# Mali
ml 550 service not available TLDBL
# Myanmar / Burma
mm 550 service not available TLDBL
# Mongolia
mn 550 service not available TLDBL
# Macau
mo 550 service not available TLDBL
# Northern Mariana Islands
mp 550 service not available TLDBL
# Martinique
mq 550 service not available TLDBL
# Mauritania
mr 550 service not available TLDBL
# Montserrat
ms 550 service not available TLDBL
# Malta
mt 550 service not available TLDBL
# Mauritius
mu 550 service not available TLDBL
# Republic of Maldives
mv 550 service not available TLDBL
# Malawi
mw 550 service not available TLDBL
# Mexico
mx 550 service not available TLDBL
# Malaysia
my 550 service not available TLDBL
# Mozambique
mz 550 service not available TLDBL
# Namibia
na 550 service not available TLDBL
# New Caledonia
nc 550 service not available TLDBL
# Niger
ne 550 service not available TLDBL
# Norfolk Island
nf 550 service not available TLDBL
# Nigeria
ng 550 service not available TLDBL
# Nicaragua
ni 550 service not available TLDBL
####### Netherlands
#nl 550 service not available TLDBL
# Norway
no 550 service not available TLDBL
# Nepal
np 550 service not available TLDBL
# Nauru
nr 550 service not available TLDBL
# Niue
nu 550 service not available TLDBL
# New Zealand
nz 550 service not available TLDBL
# Oman
om 550 service not available TLDBL
# Panama
pa 550 service not available TLDBL
# Peru
pe 550 service not available TLDBL
# French Polynesia
pf 550 service not available TLDBL
# Papua New Guinea
pg 550 service not available TLDBL
# Philippines
ph 550 service not available TLDBL
# Pakistan
pk 550 service not available TLDBL
###### Poland
# pl 550 service not available TLDBL
# Saint Pierre and Miquelon
pm 550 service not available TLDBL
# Pitcairn Islands
pn 550 service not available TLDBL
# Puerto Rico
pr 550 service not available TLDBL
# State of Palestine
ps 550 service not available TLDBL
# Portugal
pt 550 service not available TLDBL
# Palau
pw 550 service not available TLDBL
# Paraguay
py 550 service not available TLDBL
# Qatar
qa 550 service not available TLDBL
# Reunion
re 550 service not available TLDBL
# Romania
ro 550 service not available TLDBL
# Serbia
rs 550 service not available TLDBL
####### Russia
# ru 550 service not available TLDBL
# Rwanda
rw 550 service not available TLDBL
# Saudi Arabia
sa 550 service not available TLDBL
# Solomon Islands
sb 550 service not available TLDBL
# Seychelles
sc 550 service not available TLDBL
# Sudan
sd 550 service not available TLDBL
####### Sweden
# se 550 service not available TLDBL
# Singapore
sg 550 service not available TLDBL
# Saint Helena
sh 550 service not available TLDBL
# Slovenia
si 550 service not available TLDBL
# Slovakia
sk 550 service not available TLDBL
# Sierra Leone
sl 550 service not available TLDBL
# San Marino
sm 550 service not available TLDBL
# Senegal
sn 550 service not available TLDBL
# Somalia
so 550 service not available TLDBL
# Suriname
sr 550 service not available TLDBL
# South Sudan
ss 550 service not available TLDBL
# SÃ£o TomÃ© and PrÃ­ncipe
st 550 service not available TLDBL
# Soviet Union
su 550 service not available TLDBL
# El Salvador
sv 550 service not available TLDBL
# Sint Maarten
sx 550 service not available TLDBL
# Syria
sy 550 service not available TLDBL
# Swaziland
sz 550 service not available TLDBL
# Turks and Caicos Islands
tc 550 service not available TLDBL
# Chad
td 550 service not available TLDBL
# French Southern and Antarctic Lands / Team Fortress 
tf 550 service not available TLDBL
# Togo
tg 550 service not available TLDBL
# Thailand
th 550 service not available TLDBL
# Tajikistan
tj 550 service not available TLDBL
# Tokelau
tk 550 service not available TLDBL
# East Timor
tl 550 service not available TLDBL
# Turkmenistan
tm 550 service not available TLDBL
# Tunisia
tn 550 service not available TLDBL
# Tonga
to 550 service not available TLDBL
# Turkey
tr 550 service not available TLDBL
# University of the West Indies / Trinidad and Tobago
tt 550 service not available TLDBL
# Tuvalu / television or video-related sites
tv 550 service not available TLDBL
# Taiwan
tw 550 service not available TLDBL
# Tanzania
tz 550 service not available TLDBL
# Ukraine
ua 550 service not available TLDBL
# Uganda
ug 550 service not available TLDBL
# United Kingdom of Great Britain and Northern Ireland
uk 550 service not available TLDBL
# United States
us 550 service not available TLDBL
# Uruguay
uy 550 service not available TLDBL
# Uzbekistan
uz 550 service not available TLDBL
# State of the Vatican City
va 550 service not available TLDBL
# Saint Vincent and the Grenadines
vc 550 service not available TLDBL
# Venezuela
ve 550 service not available TLDBL
# British Virgin Islands
vg 550 service not available TLDBL
# U.S. Virgin Islands
vi 550 service not available TLDBL
# Vietnam
vn 550 service not available TLDBL
# Vanuatu
vu 550 service not available TLDBL
# Wallis and Futuna Islands
wf 550 service not available TLDBL
# Samoa
ws 550 service not available TLDBL
# Yemen
ye 550 service not available TLDBL
# Mayotte
yt 550 service not available TLDBL
# South Africa
za 550 service not available TLDBL
# Zambia
zm 550 service not available TLDBL
# Zimbabwe
zw 550 service not available TLDBL
##############
# Common TLDs
#com 550 service unavailable TLDBL
#net 550 service unavailable TLDBL
#org 550 service unavailable TLDBL
#biz 550 service unavailable TLDBL
#me 550 service unavailable TLDBL 
edu 550 service unavailable TLDBL
#info 550 service unavailable TLDBL
EOF
  echo -e "\033[92mdone...\033[0m";
else
  echo -e "\033[92mexisting...\033[0m";
fi;


echo -en "Install tld_new_access template now: ";
if [ ! -f ${MAPSDIR}/tld_new_access ]; then 
  cat > ${MAPSDIR}/tld_new_access << "EOF"
#
# IPFire Mail Gateway Project 
# tld_new_access file
#
# Use the postmap command whenever you change this file
#
# This file is only for new top level domains
#
#### A
abogado 550 service not available TLDBL
academy 550 service not available TLDBL
accountant 550 service not available TLDBL
accountants 550 service not available TLDBL
actor 550 service not available TLDBL
ads 550 service not available TLDBL
adult 550 service not available TLDBL
africa 550 service not available TLDBL
agency 550 service not available TLDBL
airforce 550 service not available TLDBL
alsace 550 service not available TLDBL
amsterdam 550 service not available TLDBL
analytics 550 service not available TLDBL
apartments 550 service not available TLDBL
app 550 service not available TLDBL
arab 550 service not available TLDBL
archi 550 service not available TLDBL
army 550 service not available TLDBL
art 550 service not available TLDBL
asia 550 service not available TLDBL
associates 550 service not available TLDBL
attorney 550 service not available TLDBL
auction 550 service not available TLDBL
audio 550 service not available TLDBL
author 550 service not available TLDBL
auto 550 service not available TLDBL
autos 550 service not available TLDBL
#### B
baby 550 service not available TLDBL
band 550 service not available TLDBL
bank 550 service not available TLDBL
bar 550 service not available TLDBL
barcelona 550 service not available TLDBL
bargains 550 service not available TLDBL
baseball 550 service not available TLDBL
basketball 550 service not available TLDBL
bayern 550 service not available TLDBL
bcn 550 service not available TLDBL
beauty 550 service not available TLDBL
beer 550 service not available TLDBL
berlin 550 service not available TLDBL
best 550 service not available TLDBL
bet 550 service not available TLDBL
bible 550 service not available TLDBL
bid 550 service not available TLDBL
bike 550 service not available TLDBL
bingo 550 service not available TLDBL
bio 550 service not available TLDBL
black 550 service not available TLDBL
blackfriday 550 service not available TLDBL
blog 550 service not available TLDBL
blue 550 service not available TLDBL
boats 550 service not available TLDBL
boo 550 service not available TLDBL
book 550 service not available TLDBL
boston 550 service not available TLDBL
bot 550 service not available TLDBL
boutique 550 service not available TLDBL
box 550 service not available TLDBL
broadway 550 service not available TLDBL
broker 550 service not available TLDBL
brussels 550 service not available TLDBL
budapest 550 service not available TLDBL
build 550 service not available TLDBL
builders 550 service not available TLDBL
business 550 service not available TLDBL
buy 550 service not available TLDBL
buzz 550 service not available TLDBL
bzh 550 service not available TLDBL
#### C
cab 550 service not available TLDBL
cafe 550 service not available TLDBL
call 550 service not available TLDBL
cam 550 service not available TLDBL
camera 550 service not available TLDBL
camp 550 service not available TLDBL
cancerresearch 550 service not available TLDBL
capetown 550 service not available TLDBL
capital 550 service not available TLDBL
car 550 service not available TLDBL
cards 550 service not available TLDBL
care 550 service not available TLDBL
career 550 service not available TLDBL
careers 550 service not available TLDBL
cars 550 service not available TLDBL
casa 550 service not available TLDBL
cash 550 service not available TLDBL
casino 550 service not available TLDBL
catering 550 service not available TLDBL
catholic 550 service not available TLDBL
center 550 service not available TLDBL
ceo 550 service not available TLDBL
channel 550 service not available TLDBL
charity 550 service not available TLDBL
chat 550 service not available TLDBL
cheap 550 service not available TLDBL
christmas 550 service not available TLDBL
church 550 service not available TLDBL
city 550 service not available TLDBL
claims 550 service not available TLDBL
cleaning 550 service not available TLDBL
click 550 service not available TLDBL
clinic 550 service not available TLDBL
clothing 550 service not available TLDBL
cloud 550 service not available TLDBL
club 550 service not available TLDBL
coach 550 service not available TLDBL
codes 550 service not available TLDBL
coffee 550 service not available TLDBL
college 550 service not available TLDBL
cologne 550 service not available TLDBL
community 550 service not available TLDBL
company 550 service not available TLDBL
computer 550 service not available TLDBL
comsec 550 service not available TLDBL
condos 550 service not available TLDBL
construction 550 service not available TLDBL
consulting 550 service not available TLDBL
contact 550 service not available TLDBL
contractors 550 service not available TLDBL
cooking 550 service not available TLDBL
cool 550 service not available TLDBL
corp 550 service not available TLDBL
country 550 service not available TLDBL
coupon 550 service not available TLDBL
coupons 550 service not available TLDBL
courses 550 service not available TLDBL
cpa 550 service not available TLDBL
credit 550 service not available TLDBL
creditcard 550 service not available TLDBL
creditunion 550 service not available TLDBL
cricket 550 service not available TLDBL
cruise 550 service not available TLDBL
cruises 550 service not available TLDBL
cymru 550 service not available TLDBL
#### D
dad 550 service not available TLDBL
dance 550 service not available TLDBL
data 550 service not available TLDBL
date 550 service not available TLDBL
dating 550 service not available TLDBL
day 550 service not available TLDBL
dds 550 service not available TLDBL
deal 550 service not available TLDBL
deals 550 service not available TLDBL
degree 550 service not available TLDBL
delivery 550 service not available TLDBL
democrat 550 service not available TLDBL
dental 550 service not available TLDBL
dentist 550 service not available TLDBL
desi 550 service not available TLDBL
design 550 service not available TLDBL
dev 550 service not available TLDBL
diamonds 550 service not available TLDBL
diet 550 service not available TLDBL
digital 550 service not available TLDBL
direct 550 service not available TLDBL
directory 550 service not available TLDBL
discount 550 service not available TLDBL
diy 550 service not available TLDBL
docs 550 service not available TLDBL
doctor 550 service not available TLDBL
dog 550 service not available TLDBL
domains 550 service not available TLDBL
dot 550 service not available TLDBL
download 550 service not available TLDBL
dubai 550 service not available TLDBL
dvr 550 service not available TLDBL
#### E
earth 550 service not available TLDBL
eat 550 service not available TLDBL
eco 550 service not available TLDBL
ecom 550 service not available TLDBL
education 550 service not available TLDBL
#email 550 service not available TLDBL
energy 550 service not available TLDBL
engineer 550 service not available TLDBL
engineering 550 service not available TLDBL
enterprises 550 service not available TLDBL
equipment 550 service not available TLDBL
esq 550 service not available TLDBL
estate 550 service not available TLDBL
eus 550 service not available TLDBL
events 550 service not available TLDBL
exchange 550 service not available TLDBL
expert 550 service not available TLDBL
exposed 550 service not available TLDBL
express 550 service not available TLDBL
##### F
fail 550 service not available TLDBL
faith 550 service not available TLDBL
family 550 service not available TLDBL
fan 550 service not available TLDBL
fans 550 service not available TLDBL
farm 550 service not available TLDBL
fashion 550 service not available TLDBL
feedback 550 service not available TLDBL
film 550 service not available TLDBL
final 550 service not available TLDBL
finance 550 service not available TLDBL
financial 550 service not available TLDBL
finish 550 service not available TLDBL
fish 550 service not available TLDBL
fishing 550 service not available TLDBL
fit 550 service not available TLDBL
fitness 550 service not available TLDBL
flights 550 service not available TLDBL
florist 550 service not available TLDBL
flowers 550 service not available TLDBL
fly 550 service not available TLDBL
foo 550 service not available TLDBL
food 550 service not available TLDBL
football 550 service not available TLDBL
forsale 550 service not available TLDBL
forum 550 service not available TLDBL
foundation 550 service not available TLDBL
frl 550 service not available TLDBL
fun 550 service not available TLDBL
fund 550 service not available TLDBL
furniture 550 service not available TLDBL
futbol 550 service not available TLDBL
fyi 550 service not available TLDBL
#### G
gal 550 service not available TLDBL
gallery 550 service not available TLDBL
game 550 service not available TLDBL
games 550 service not available TLDBL
garden 550 service not available TLDBL
gay 550 service not available TLDBL
ged 550 service not available TLDBL
gent 550 service not available TLDBL
gift 550 service not available TLDBL
gifts 550 service not available TLDBL
gives 550 service not available TLDBL
giving 550 service not available TLDBL
glass 550 service not available TLDBL
global 550 service not available TLDBL
gmbh 550 service not available TLDBL
gold 550 service not available TLDBL
golf 550 service not available TLDBL
got 550 service not available TLDBL
graphics 550 service not available TLDBL
gratis 550 service not available TLDBL
green 550 service not available TLDBL
gripe 550 service not available TLDBL
grocery 550 service not available TLDBL
# group 550 service not available TLDBL
guide 550 service not available TLDBL
guitars 550 service not available TLDBL
guru 550 service not available TLDBL
hair 550 service not available TLDBL
halal 550 service not available TLDBL
hamburg 550 service not available TLDBL
haus 550 service not available TLDBL
health 550 service not available TLDBL
healthcare 550 service not available TLDBL
help 550 service not available TLDBL
helsinki 550 service not available TLDBL
here 550 service not available TLDBL
hiphop 550 service not available TLDBL
hiv 550 service not available TLDBL
hockey 550 service not available TLDBL
holdings 550 service not available TLDBL
holiday 550 service not available TLDBL
home 550 service not available TLDBL
homes 550 service not available TLDBL
horse 550 service not available TLDBL
host 550 service not available TLDBL
hosting 550 service not available TLDBL
hot 550 service not available TLDBL
hoteis 550 service not available TLDBL
hotel 550 service not available TLDBL
hotels 550 service not available TLDBL
house 550 service not available TLDBL
how 550 service not available TLDBL
#### I
idn 550 service not available TLDBL
immo 550 service not available TLDBL
immobilien 550 service not available TLDBL
inc 550 service not available TLDBL
industries 550 service not available TLDBL
ing 550 service not available TLDBL
ink 550 service not available TLDBL
institute 550 service not available TLDBL
insurance 550 service not available TLDBL
insure 550 service not available TLDBL
international 550 service not available TLDBL
investments 550 service not available TLDBL
irish 550 service not available TLDBL
islam 550 service not available TLDBL
ismaili 550 service not available TLDBL
ist 550 service not available TLDBL
istanbul 550 service not available TLDBL
#### J
jetzt 550 service not available TLDBL
jewelry 550 service not available TLDBL
jobs 550 service not available TLDBL
joburg 550 service not available TLDBL
jot 550 service not available TLDBL
joy 550 service not available TLDBL
juegos 550 service not available TLDBL
#### K
kaufen 550 service not available TLDBL
kid 550 service not available TLDBL
kids 550 service not available TLDBL
kim 550 service not available TLDBL
kitchen 550 service not available TLDBL
kiwi 550 service not available TLDBL
koeln 550 service not available TLDBL
kosher 550 service not available TLDBL
kyoto 550 service not available TLDBL
#### L
land 550 service not available TLDBL
lat 550 service not available TLDBL
latino 550 service not available TLDBL
law 550 service not available TLDBL
lawyer 550 service not available TLDBL
lease 550 service not available TLDBL
legal 550 service not available TLDBL
lgbt 550 service not available TLDBL
life 550 service not available TLDBL
lifeinsurance 550 service not available TLDBL
lifestyle 550 service not available TLDBL
lighting 550 service not available TLDBL
like 550 service not available TLDBL
limited 550 service not available TLDBL
limo 550 service not available TLDBL
link 550 service not available TLDBL
live 550 service not available TLDBL
living 550 service not available TLDBL
llc 550 service not available TLDBL
llp 550 service not available TLDBL
loan 550 service not available TLDBL
loans 550 service not available TLDBL
lol 550 service not available TLDBL
london 550 service not available TLDBL
lotto 550 service not available TLDBL
love 550 service not available TLDBL
ltd 550 service not available TLDBL
ltda 550 service not available TLDBL
luxe 550 service not available TLDBL
luxury 550 service not available TLDBL
#### M
madrid 550 service not available TLDBL
mail 550 service not available TLDBL
maison 550 service not available TLDBL
makeup 550 service not available TLDBL
management 550 service not available TLDBL
map 550 service not available TLDBL
market 550 service not available TLDBL
marketing 550 service not available TLDBL
mba 550 service not available TLDBL
med 550 service not available TLDBL
media 550 service not available TLDBL
medical 550 service not available TLDBL
meet 550 service not available TLDBL
melbourne 550 service not available TLDBL
meme 550 service not available TLDBL
memorial 550 service not available TLDBL
men 550 service not available TLDBL
menu 550 service not available TLDBL
miami 550 service not available TLDBL
mls 550 service not available TLDBL
mobi 550 service not available TLDBL
mobile 550 service not available TLDBL
moda 550 service not available TLDBL
moe 550 service not available TLDBL
mom 550 service not available TLDBL
money 550 service not available TLDBL
mortgage 550 service not available TLDBL
moscow 550 service not available TLDBL
moto 550 service not available TLDBL
motorcycles 550 service not available TLDBL
mov 550 service not available TLDBL
movie 550 service not available TLDBL
music 550 service not available TLDBL
mutualfunds 550 service not available TLDBL
#### N
nagoya 550 service not available TLDBL
name 550 service not available TLDBL
navy 550 service not available TLDBL
network 550 service not available TLDBL
new 550 service not available TLDBL
news 550 service not available TLDBL
ngo 550 service not available TLDBL
ninja 550 service not available TLDBL
now 550 service not available TLDBL
nrw 550 service not available TLDBL
nyc 550 service not available TLDBL
#### O
okinawa 550 service not available TLDBL
one 550 service not available TLDBL
ong 550 service not available TLDBL
onl 550 service not available TLDBL
online 550 service not available TLDBL
ooo 550 service not available TLDBL
organic 550 service not available TLDBL
osaka 550 service not available TLDBL
ott 550 service not available TLDBL
#### P
paris 550 service not available TLDBL
pars 550 service not available TLDBL
partners 550 service not available TLDBL
parts 550 service not available TLDBL
party 550 service not available TLDBL
pay 550 service not available TLDBL
pet 550 service not available TLDBL
pets 550 service not available TLDBL
phd 550 service not available TLDBL
phone 550 service not available TLDBL
photo 550 service not available TLDBL
photography 550 service not available TLDBL
photos 550 service not available TLDBL
physio 550 service not available TLDBL
pics 550 service not available TLDBL
pictures 550 service not available TLDBL
pid 550 service not available TLDBL
ping 550 service not available TLDBL
pink 550 service not available TLDBL
pizza 550 service not available TLDBL
place 550 service not available TLDBL
play 550 service not available TLDBL
plumbing 550 service not available TLDBL
plus 550 service not available TLDBL
poker 550 service not available TLDBL
politie 550 service not available TLDBL
porn 550 service not available TLDBL
press 550 service not available TLDBL
pro 550 service not available TLDBL
productions 550 service not available TLDBL
prof 550 service not available TLDBL
promo 550 service not available TLDBL
properties 550 service not available TLDBL
property 550 service not available TLDBL
protection 550 service not available TLDBL
pub 550 service not available TLDBL
#### Q
qpon 550 service not available TLDBL
quebec 550 service not available TLDBL
#### R
racing 550 service not available TLDBL
radio 550 service not available TLDBL
read 550 service not available TLDBL
realestate 550 service not available TLDBL
realtor 550 service not available TLDBL
realty 550 service not available TLDBL
recipes 550 service not available TLDBL
red 550 service not available TLDBL
rehab 550 service not available TLDBL
reise 550 service not available TLDBL
reisen 550 service not available TLDBL
rent 550 service not available TLDBL
rentals 550 service not available TLDBL
repair 550 service not available TLDBL
report 550 service not available TLDBL
republican 550 service not available TLDBL
rest 550 service not available TLDBL
restaurant 550 service not available TLDBL
retirement 550 service not available TLDBL
review 550 service not available TLDBL
reviews 550 service not available TLDBL
rich 550 service not available TLDBL
rip 550 service not available TLDBL
rocks 550 service not available TLDBL
rodeo 550 service not available TLDBL
roma 550 service not available TLDBL
room 550 service not available TLDBL
rsvp 550 service not available TLDBL
rugby 550 service not available TLDBL
ruhr 550 service not available TLDBL
run 550 service not available TLDBL
ryukyu 550 service not available TLDBL
#### S
saarland 550 service not available TLDBL
safe 550 service not available TLDBL
safety 550 service not available TLDBL
sale 550 service not available TLDBL
salon 550 service not available TLDBL
sari 550 service not available TLDBL
sarl 550 service not available TLDBL
save 550 service not available TLDBL
sb 550 service not available TLDBL
sc 550 service not available TLDBL
scholarships 550 service not available TLDBL
school 550 service not available TLDBL
schule 550 service not available TLDBL
science 550 service not available TLDBL
scot 550 service not available TLDBL
search 550 service not available TLDBL
secure 550 service not available TLDBL
security 550 service not available TLDBL
services 550 service not available TLDBL
sex 550 service not available TLDBL
sexy 550 service not available TLDBL
sh 550 service not available TLDBL
shabaka 550 service not available TLDBL
shabaka-arabic 550 service not available TLDBL
shia 550 service not available TLDBL
shiksha 550 service not available TLDBL
shoes 550 service not available TLDBL
shop 550 service not available TLDBL
shopping 550 service not available TLDBL
show 550 service not available TLDBL
singles 550 service not available TLDBL
site 550 service not available TLDBL
ski 550 service not available TLDBL
smile 550 service not available TLDBL
soccer 550 service not available TLDBL
social 550 service not available TLDBL
software 550 service not available TLDBL
solar 550 service not available TLDBL
solutions 550 service not available TLDBL
song 550 service not available TLDBL
soy 550 service not available TLDBL
spa 550 service not available TLDBL
space 550 service not available TLDBL
sport 550 service not available TLDBL
sports 550 service not available TLDBL
spot 550 service not available TLDBL
srl 550 service not available TLDBL
stockholm 550 service not available TLDBL
storage 550 service not available TLDBL
store 550 service not available TLDBL
stream 550 service not available TLDBL
studio 550 service not available TLDBL
study 550 service not available TLDBL
style 550 service not available TLDBL
sucks 550 service not available TLDBL
supplies 550 service not available TLDBL
supply 550 service not available TLDBL
support 550 service not available TLDBL
surf 550 service not available TLDBL
surgery 550 service not available TLDBL
swiss 550 service not available TLDBL
sydney 550 service not available TLDBL
systems 550 service not available TLDBL
#### T
taipei 550 service not available TLDBL
talk 550 service not available TLDBL
tatar 550 service not available TLDBL
tattoo 550 service not available TLDBL
tax 550 service not available TLDBL
taxi 550 service not available TLDBL
team 550 service not available TLDBL
tech 550 service not available TLDBL
technology 550 service not available TLDBL
tel 550 service not available TLDBL
tennis 550 service not available TLDBL
thai 550 service not available TLDBL
theater 550 service not available TLDBL
theatre 550 service not available TLDBL
tickets 550 service not available TLDBL
tienda 550 service not available TLDBL
tips 550 service not available TLDBL
tires 550 service not available TLDBL
tirol 550 service not available TLDBL
today 550 service not available TLDBL
tokyo 550 service not available TLDBL
tools 550 service not available TLDBL
top 550 service not available TLDBL
tours 550 service not available TLDBL
town 550 service not available TLDBL
toys 550 service not available TLDBL
trade 550 service not available TLDBL
trading 550 service not available TLDBL
training 550 service not available TLDBL
travel 550 service not available TLDBL
tube 550 service not available TLDBL
#### U
university 550 service not available TLDBL
uno 550 service not available TLDBL
#### V
vacations 550 service not available TLDBL
vegas 550 service not available TLDBL
ventures 550 service not available TLDBL
versicherung 550 service not available TLDBL
vet 550 service not available TLDBL
viajes 550 service not available TLDBL
video 550 service not available TLDBL
villas 550 service not available TLDBL
vin 550 service not available TLDBL
vip 550 service not available TLDBL
vision 550 service not available TLDBL
vlaanderen 550 service not available TLDBL
vodka 550 service not available TLDBL
vote 550 service not available TLDBL
voting 550 service not available TLDBL
voto 550 service not available TLDBL
voyage 550 service not available TLDBL
#### W
wales 550 service not available TLDBL
wang 550 service not available TLDBL
watch 550 service not available TLDBL
watches 550 service not available TLDBL
weather 550 service not available TLDBL
web 550 service not available TLDBL
webcam 550 service not available TLDBL
webs 550 service not available TLDBL
website 550 service not available TLDBL
wedding 550 service not available TLDBL
wiki 550 service not available TLDBL
win 550 service not available TLDBL
wine 550 service not available TLDBL
winners 550 service not available TLDBL
work 550 service not available TLDBL
works 550 service not available TLDBL
world 550 service not available TLDBL
wow 550 service not available TLDBL
wtf 550 service not available TLDBL
#### X
xxx 550 service not available TLDBL
xyz 550 service not available TLDBL
#### Y
yachts 550 service not available TLDBL
yoga 550 service not available TLDBL
yokohama 550 service not available TLDBL
you 550 service not available TLDBL
#### Z
zero 550 service not available TLDBL
zip 550 service not available TLDBL
zone 550 service not available TLDBL
EOF
  echo -e "\033[92mdone...\033[0m";
else
  echo -e "\033[92mexisting...\033[0m";
fi;

echo -en "Install helo_access template now: ";
if [ ! -f ${MAPSDIR}/helo_access ]; then
  cat > ${MAPSDIR}/helo_access << "EOF"
#
# IPFire Mail Gateway project 
# helo_access
#
# Use the postmap command whenever you change this file
#
# Block and whitelist helo domains / strings
#
# Useful options REJECT / DISCARD / OK
# read the access file for more options

EOF
  echo -e "\033[92mdone...\033[0m";
else
  echo -e "\033[92mexisting...\033[0m";
fi;

echo -en "Install smtpd_access template now: ";
if [ ! -f ${MAPSDIR}/smtpd_access ]; then
  cat > ${MAPSDIR}/smtpd_access << "EOF"
# IPFire Mail Gateway Project 
# smtpd_access file
#
# Use the postmap command whenever you change this file
#
# Black and Whitelist for MTA Second Level Domains and IP's
# Blocking here does not need DNS-Blacklist requests
#
# Useful options REJECT / DISCARD / OK
# read the access file for more options
 
# Black or whitelist IP OK/REJECT
# 1.2.3.4 REJECT   # signle IP Blacklited
# 1.2.3   REJECT   # Network Blacklisted

# Whitelist
mout.kundenserver.de OK   # 1und1 mostly DNS blacklisted
mout-xforward.kundenserver.de OK # 1und1 mostly DNS blacklisted
t-online.de OK            # T-online some MTA DNS blacklisted
mout.gmx.net OK           # GMX Freemail sometimes DNS blacklisted
mout.web.de OK            # WEB.de Freemail sometimes DNS blacklisted
mout0.freenet.de OK       # Freenet Freemail sometimes DNS blacklisted
rzone.de OK               # Strato Sorbs DNS blacklisted

# Aquatix IT-Services SPAM Network
46.35.33     550 service not available IPBL
46.167.20    550 service not available IPBL
46.167.39    550 service not available IPBL
89.191.66    550 service not available IPBL
109.75.108   550 service not available IPBL
109.75.104   550 service not available IPBL
109.75.110   550 service not available IPBL

# Mailer-Service.de
217.115.132  550 service not available IPBL
176.28.29    550 service not available IPBL

# Russian Spammers
62.173       550 service not available IPBL
46.173       550 service not available IPBL
85.93        550 service not available IPBL
77.40        550 service not available IPBL
77.46        550 service not available IPBL

# blackisted ip ranges
89.136       550 service not available IPBL
94.98        550 service not available IPBL
95.168       550 service not available IPBL
122.133      550 service not available IPBL
211.222      550 service not available IPBL
203.115      550 service not available IPBL
67.238       550 service not available IPBL
209.126      550 service not available IPBL
69.163       550 service not available IPBL
37.143.51    550 service not available IPBL
43.241.47    550 service not available IPBL
62.146.156   550 service not available IPBL
89.163.225   550 service not available IPBL
81.19.215    550 service not available IPBL
62.75.206    550 service not available IPBL
103.40.10    550 service not available IPBL
109.70.242   550 service not available IPBL
123.215      550 service not available IPBL
125.7        550 service not available IPBL
128.14.209   550 service not available IPBL
142.93.136   550 service not available IPBL
158.69       550 service not available IPBL
168.187      550 service not available IPBL
181.168      550 service not available IPBL
182.118      550 service not available IPBL
185.59.103   550 service not available IPBL
185.145.131  550 service not available IPBL
185.253.217  550 service not available IPBL
188.245      550 service not available IPBL
192.148      550 service not available IPBL
94.177.240   550 service not available IPBL
45.132       550 service not available IPBL
93.189       550 service not available IPBL
5.104.107    550 service not available IPBL
5.187.51     550 service not available IPBL
79.167       550 service not available IPBL
81.17.16     550 service not available IPBL
EOF
  echo -e "\033[92mdone...\033[0m";
else
  echo -e "\033[92mexisting...\033[0m";
fi;

# add spamphrases-white file
echo -en "Install spamphrases-white.pcre template now: ";
if [ ! -f ${CONFIGDIR}/spamphrases-white.pcre ]; then
 cat > ${CONFIGDIR}/spamphrases-white.pcre << "EOF"
#
# IPFire Mail Gateway project 
# spamphrases-white.pcre
#
# This file is only for regex whitelisting phrases
# postmap is not needed for this file
#
# some regex examples
# abc         "abc"(the exact character sequence, but anywhere in the string).
# ^abc        "abc"at the beginning of the string.
# abc$        "abc"at the end of the string. ##
# a|b         Either "a" or "b".
# ^abc|abc$   The string "abc" at the beginning or at the end of the string. 
# [Aa]bc      Either of "Abc"and "abc". 
# /i          Makes the pattern case insensitive
# abc\b       "abc" when followed by a word boundary (for example, in "abc!" but not in "abcd"). 
#
# Example: /phrase/ OK
#
/amazonses.com/ OK
/unitedinternet/ OK
/abo-bmvi.de/ OK
/abo.bmfsfj/ OK
/arbeitsagentur/ OK
/stepstone/ OK
/indeed.com/ OK
/noreply.bund.de/ OK
/evergabe.de/ OK
/wuerttemberg/ OK
/ticketservice/i OK
/informatik/ OK
/bestellung/i OK
/bestellservice/i OK
/redaktion/i OK
/personalrat/i OK
/sparkasse/i OK
/mailcontrol/i  OK
/innovas/ OK
/anima-/ OK
/enterosan/ OK
/katholische/ OK
/intersana/ OK
/foodoase/ OK
/stoff-institut/ OK
/kathpflegeverband/ OK
/agep-/ OK
/funkemedien/ OK
/deppner/ OK
/meusburger/ OK
EOF
 echo -e "\033[92mdone...\033[0m";
else
 echo -e "\033[92mexisting...\033[0m";
fi;

# add spamphrases-block file
echo -en "Install spamphrases-block.pcre template now: ";
if [ ! -f ${CONFIGDIR}/spamphrases-block.pcre ]; then
 cat > ${CONFIGDIR}/spamphrases-block.pcre << "EOF"
# spamphrases-block.pcre
# This file is only for regex blacklisting phrases
# postmap is not needed for this file
#
# some regex examples
# abc 		“abc” (the exact character sequence, but anywhere in the string).
# ^abc	 	“abc” at the beginning of the string.
# abc$ 	“abc” at the end of the string. ##
# a|b 		Either “a” or “b”.
# ^abc|abc$ 	The string “abc” at the beginning or at the end of the string. 
# [Aa]bc 	Either of “Abc” and “abc”. 
# /i 		Makes the pattern case insensitive
# abc\b 	“abc” when followed by a word boundary (for example, in “abc!” but not in “abcd”). 
#
# Example: /phrase/ REJECT unwanted content SPBL
#
#/bounce/i REJECT SPBL
# reject untrustet "security scanner"
/scan/i REJECT SPBL
#
#/2020/ REJECT SPBL 0002
#/2021/ REJECT SPBL 0003
/akademie/i REJECT SPBL 0004
/aktion/i REJECT SPBL 0005 
/aktuell/i REJECT SPBL 0006
/angebot/i REJECT SPBL 0007
/auktion/i REJECT SPBL 0008
/beitrag/i REJECT SPBL 0009
/beitraege/i REJECT SPBL 0010
/beste/i REJECT SPBL 0011
/betriebshaft/i REJECT SPBL 0012
/bhv/i REJECT SPBL 0013
/businessreview/i REJECT SPBL 0014
/control/i REJECT SPBL 0015
/docguide/ REJECT SPBL 0016
/einladung/i REJECT SPBL 0017
/empfehl/i REJECT SPBL 0018
/eurocamp/i REJECT SPBL 0019
/feedback/i REJECT SPBL 0020
/geunstig/i REJECT SPBL 0021
/gutschein/i REJECT SPBL 0022
/haftpflicht/i REJECT SPBL 0023
/individuell/ REJECT SPBL 0014
/inform/i REJECT SPBL 0024
/intim/i REJECT SPBL 0024
/institut/i REJECT SPBL 0025
/intensiv/ REJECT SPBL 0026
/jackpot/i REJECT SPBL 0027
/kalkulieren/i REJECT SPBL 0028
/kundenfeedback/i REJECT SPBL 0029
/kredit/i REJECT SPBL 0030
/marketing/i REJECT SPBL 0031
/messe/i REJECT SPBL 0032
/million/i REJECT SPBL 0033
/neue/ REJECT SPBL 0034
/neuheit/i REJECT SPBL 0035
/newscpt/ REJECT SPBL 0036
/optimal/i REJECT SPBL 0037
/optimier/i REJECT SPBL 0038
/perfekt/i REJECT SPBL 0039
/pflege/i REJECT SPBL 0040
/pkv/i REJECT SPBL 0041
/potenz/i REJECT SPBL 0042
/privat/i REJECT SPBL 0043
/prima/i REJECT SPBL 0044
/pruefen/ REJECT SPBL 0045
/pzv/i REJECT SPBL 0046
/rmtr/ REJECT SPBL 0047
/schnell/i REJECT SPBL 0048
/senkung/i REJECT SPBL 0049
/sieger/i REJECT SPBL 0050
/sonder/i REJECT SPBL 0051
/super/i REJECT SPBL 0052
/tarif/i REJECT SPBL 0053
/tickets/i REJECT SPBL 0054
/ueberblick/i REJECT SPBL 0055
/unverbindlich/ REJECT SPBL 0056
/vergleich/ REJECT SPBL 0057
/versicherung/ REJECT SPBL 0058
/vertrag/ REJECT SPBL 0059
/vip/i REJECT SPBL 0060
/vorsorge/ REJECT SPBL 0061
/wissensbrief/ REJECT SPBL 0062
/wunder/i REJECT SPBL 0063
/zahnzusatz/i REJECT SPBL 0064
/checker/i REJECT SPBL 0065
/kofferset/i REJECT SPBL 0067
/wholesale/i REJECT SPBL 0068
/homeautomation/i REJECT SPBL 0069
/caraudio/i REJECT SPBL 0070
/globalsolution/i REJECT SPBL 0071
/verizon/i REJECT SPBL 0072
/hismag/i REJECT SPBL 0073
/lisamo/i REJECT SPBL 0074
/jominsta/i REJECT SPBL 0075
/alfredse/i REJECT SPBL 0076
/kanmarotu/i REJECT SPBL 0077
/rmh2/i REJECT SPBL 0078
/kundenmeister/i REJECT SPBL 0079
/revouns/i REJECT SPBL 0080
/monetry/i REJECT SPBL 0081
/nivios/i REJECT SPBL 0082
/vertrieb.biz/i REJECT SPBL 0083
/performance/i REJECT SPBL 0085
/polaris/i REJECT SPBL 0086
/ciudad/i REJECT SPBL 0087
/jobiniton/i REJECT SPBL 0088
/rmh1/i REJECT SPBL 0089
/pdfarchitect/i REJECT SPBL 0090
/deals/i REJECT SPBL 0091
/gruene-fraktion/i REJECT SPBL 0092
/spillar/i REJECT SPBL 0093
/clockit/i REJECT SPBL 0094
/fastmail/i REJECT SPBL 0095
/juno.com/i REJECT SPBL 0096
/gooi/i REJECT SPBL 0097
/megamsten/i REJECT SPBL 0098
/magnum/i REJECT SPBL 0099
/aim.com/i REJECT SPBL 0100
/ximers/i REJECT SPBL 0101
/onderar/i REJECT SPBL 0102
/vigator/i REJECT SPBL 0103
/biznet/i REJECT SPBL 0104
/fastmail/i REJECT SPBL 0105
/bookisem/i REJECT SPBL 0106
/fazaren/i REJECT SPBL 0107
/wordofmouth/i REJECT SPBL 0108
/jeannesbakery/i REJECT SPBL 0109
/opolsy/i REJECT SPBL 0110
/mazames/i REJECT SPBL 0111
/appliance/i REJECT SPBL 0112
/electric/i REJECT SPBL 0113
/circuit/i REJECT SPBL 0114
/cycling.com/ REJECT SPBL 0115
/maxiroll/i REJECT SPBL 0116
/mazaret/i REJECT SPBL 0117
/research.com/i REJECT SPBL 0118
/basalt/i REJECT SPBL 0119
/greenbook/i REJECT SPBL 0120
/armory/i REJECT SPBL 0121
/bookcity/i REJECT SPBL 0122
/ighting/i REJECT SPBL 0123
/fixit/i REJECT SPBL 0124
/xerox/i REJECT SPBL 0125
/baziliks/i REJECT SPBL 0126
/verizon/i REJECT SPBL 0127
/rmh1.net/i REJECT SPBL 0128
/jolomas/i REJECT SPBL 0129
/nokolsy/i REJECT SPBL 0130
#/yandex/i REJECT SPBL 0131
/fick/i REJECT SPBL 0132
/fuck/i REJECT SPBL 0133
/elitcon/i REJECT SPBL 0134
/samage/i REJECT SPBL 0136
/bizones/i REJECT SPBL 0137
/bizarty/i REJECT SPBL 0138
/axesrtym/i REJECT SPBL 0139
/hubspotstarter/i REJECT SPBL 0140
/doc-market/i REJECT SPBL 0141
/tiosale/i REJECT SPBL 0142
/maxolo/i REJECT SPBL 0143
/farenseri/i REJECT SPBL 0144
/baransely/i REJECT SPBL 0145
/cox.net/i REJECT SPBL 0146
/anaselinty/ REJECT SPBL 0147
/golinska/ REJECT SPBL 0148
/dezinoke/ REJECT SPBL 0149
/happy-promo/ REJECT SPBL 0150
/taylormade/ REJECT SPBL 0151
/durmakas/ REJECT SPBL 0152
/willins/ REJECT SPBL 0153
/anastiones/ REJECT SPBL 0154
/maksalati/i REJECT SPBL 0155
/blotsisop/i REJECT SPBL 0156
/basalamat/i REJECT SPBL 0154
/bmglondon/i REJECT SPBL 0158
/assambler/i REJECT SPBL 0159
/rekrutierung/i REJECT SPBL 0160
/med-congress/i REJECT SPBL 0161
/beauty/i REJECT SPBL 0162
/censys/i REJECT SPBL 0163
/scanner/i REJECT SPBL 0164
/internetemails/i REJECT SPBL 0165
/fastmailbox/i REJECT SPBL 0167
/centriconline/ REJECT SPBL 0168
/vanciity/i REJECT SPBL 0167
/shchinoff/i REJECT SPBL 0168
/iberagree/i REJECT SPBL 0169
/memoplata/i REJECT SPBL 0170
/ecijoven/i REJECT SPBL 0171
/atlantfin/i REJECT SPBL 0172
/taraheto/i REJECT SPBL 0173
/ppobbris/i REJECT SPBL 0174
/pishrobar/i REJECT SPBL 0175
/ppobbris/i REJECT SPBL 0176
/fixedclix/i REJECT SPBL 0177
/iphstore/i REJECT SPBL 0178
/ecomtyoon/i REJECT SPBL 0179
/tititeam/i REJECT SPBL 0180
/xindesom/i REJECT SPBL 0181
/thisoldtoy/i REJECT SPBL 0182
/herzog-august/i REJECT SPBL 0183
/bizarios/i REJECT SPBL 0184
/akzent-mitte/ REJECT SPBL 0186
/power/i REJECT SPBL 0187
/wheels/i REJECT SPBL 0188
/psaudio/i REJECT SPBL 0189
/nhkt/i REJECT SPBL 0190
/yamaha/i REJECT SPBL 0191
/gokolaset/i REJECT SPBL 0192
/roachtreatment/i REJECT SPBL 0193
/rizerfireworks/i REJECT SPBL 0194
/gerilons/i REJECT SPBL 0195
/rockcoo/i REJECT SPBL 0196
/rodovens/i REJECT SPBL 0197
/rockgeist/i REJECT SPBL 0198
/ripleyandrue/i REJECT SPBL 0199
/rinton/i REJECT SPBL 0200
/ripcity/i REJECT SPBL 0201
/ritmic/i REJECT SPBL 0202
/riversidet/i REJECT SPBL 0203
/scottsimper/i REJECT SPBL 0204
/lexolino/i REJECT SPBL 0205
/leuchtstark/ REJECT SPBL 0206
/lens-filter/i REJECT SPBL 0207
/lincolnmums/i REJECT SPBL 0208
/leatherpunk/i REJECT SPBL 0209
/riceeis/i REJECT SPBL 0210
/bitionser/i REJECT SPBL 0211
/infosilo/i REJECT SPBL 0212
/dreamhost/i REJECT SPBL 0213
/masken/i REJECT SPBL 0214
/getresponse/i REJECT SPBL 0215
/clients/i REJECT SPBL 0216
/officesupplies/i REJECT SPBL 0217
/serious/i REJECT SPBL 0218
/financier/i REJECT SPBL 0219
/linode/i REJECT SPBL 0220
/llmeta/i REJECT SPBL 0221
/transip/i REJECT SPBL 0222
/firemail/i REJECT SPBL 0223
/find-stores/i REJECT SPBL 0224
/rote-sonne/i REJECT SPBL 0224
/arteonem/i REJECT SPBL 0226
/electric/i REJECT SPBL 0227
/dynamfactory/ REJECT SPBL 0228
/canserti/i REJECT SPBL 0229
/hostel/i REJECT SPBL 0230
/forstallesa/i REJECT SPBL 0231
/sparkpostmail/i REJECT SPBL 0232
/mailchannel/i REJECT SPBL 0233
EOF
	echo -e "\033[92mdone...\033[0m";
else
	echo -e "\033[92mexisting...\033[0m";
fi;

# Generate DB
echo -n "Generate Postfix DBs now: ";
postmap lmdb:${MAPSDIR}/{sender_access,sld_access,tld_access,tld_new_access,smtpd_access,helo_access,virtual,transport,relay_domains}
postalias lmdb:${MAPSDIR}/aliases;
echo -e "\033[92mdone...\033[0m";
echo " ";
echo -e "\033[93mMail Gateway filters installation done...\033[0m";
echo " ";

unset MAPSDIR CONFIGDIR;
echo " ";
# End of msfilter.sh
