#!/bin/bash
#set -x
############################################################
#                                                          #
# File: mpinstall.sh                                       #
#                                                          #
# This script installing Mail Gateway packages on IPFire   #
#                                                          #
############################################################
# Build time: Mon Apr 22 09:59:32 AM CEST 2024

# Package infos
PAKx64="mp-packages_78_x64.tar"
SUMx64="9e960ae7780174a2b677ec86592319b644ddeb56482d2271428d15a082eb42d3"

# Detect platform type 
PLATFORM=$(uname -m);

if [[ "${ARCH}" == armv5tel || "${ARCH}" == armv5tejl || "${ARCH}" == armv6l || "${ARCH}" == armv7l || "${ARCH}" == i686 ]]; then
  echo -e "\033[91mInstallation only on Intel x86_64 platforms.\033[0m";
  unset ARCH;
  exit 1;
fi;

if [ "${PLATFORM}" == "x86_64" ]; then
  LIBPACK="ipfire-libs_x64.tar.xz";
  PACKAGE=${PAKx64};
  SUM=${SUMx64};
fi

# Set variables
TAR="tar xvf";
DIR="/opt/pakfire/tmp";
LOGLINE="--------------------------------------------------------------------------------";
PERLVER=$(perl -v |grep "This is perl"|awk '{printf("%s \n",$9)}'| sed 's|[<v() >,]||g');
workdir=${PWD};
configdir="/etc/postfix";
MAPSDIR="${configdir}/maps";
MANDIR="${configdir}/man"
mkdir -p ${MAPSDIR};

# init files logfile
printf "%s
-           This is the filelist log file from Mail Gateway installer          -
%s
Installation started at: $(date)\n\n" "${LOGLINE}" "${LOGLINE}" > ${workdir}/files.log;

# include old initscripts
. ${workdir}/initsripts.sh

PERL=(
 'libtirpc-1.3.4-6.ipfire'
 'libnsl-2.0.1-4.ipfire'
 'perl-5.38.2-17.ipfire'
 'perl-buildtools-2023.08-26.ipfire'
 'perl-modules-2023.08-26.ipfire'
 'freetype-2.13.2-11.ipfire'
 'fontconfig-2.15.0-6.ipfire'
 'brotli-1.1.0-2.ipfire'
 'rrdtool-1.8.0-5.ipfire'
 'guardian-2.0.2-27.ipfire'
 'wio-1.3.2-17.ipfire'
 'libloc-0.9.17-2.ipfire'
);

PFIX3ONLY=(
 'libtirpc-1.3.4-6.ipfire'
 'libnsl-2.0.0-3.ipfire'
 'icu-74_1-16.ipfire'
 'pcre-8.45-4.ipfire'
 'pcre2-10.42-9.ipfire'
 'libidn-1.42-3.ipfire'
 'libidn2-2.3.7-4.ipfire'
 'libgd-2.3.3-6.ipfire'
 'libpng-1.6.42-9.ipfire'
 'libjpeg-3.0.0-9.ipfire'
 'libwebp-1.3.2-5.ipfire'
 'libtiff-4.6.0-9.ipfire'
 'htop-3.3.0-21.ipfire'
 'mailutils-3.14-4.ipfire'
 'sharutils-4.15.2-1.ipfire'
 'postfix-3.9.0-44.ipfire'
);

MPROXY=(
 '7zip-17.05-10.ipfire'
 'icu-74_1-16.ipfire'
 'pcre-8.45-4.ipfire'
 'pcre2-10.42-9.ipfire'
 'libidn-1.42-3.ipfire'
 'libidn2-2.3.7-4.ipfire'
 'libgd-2.3.3-6.ipfire'
 'libpng-1.6.42-9.ipfire'
 'libjpeg-3.0.1-10.ipfire'
 'libsodium-1.0.19-6.ipfire'
 'libtiff-4.6.0-9.ipfire'
 'libwebp-1.3.2-5.ipfire'
 'zeromq-4.3.5-5.ipfire'
 'sharutils-4.15.2-1.ipfire'
 'mailutils-3.14-4.ipfire'
 'htop-3.3.0-21.ipfire'
 'clamav-1.3.1-72.ipfire'
 'postfix-3.9.0-44.ipfire'
 'amavisd-2.11.1-9.ipfire'
 'spamassassin-4.0.1-13.ipfire'
 'spamassassin-addons-2021.04-9.ipfire'
);

PERL4CS="perl-compat-scripts.tar.xz";
FETCHMAIL="fetchmail-6.4.37-16.ipfire";

mapsfiles=(
 'aliases'
 'generic'
 'sasl_password'
 'sender_access'
 'sld_access'
 'tld_access'
 'tld_new_access'
 'transport'
 'virtual'
)

configfiles=(
 'master.cf'
 'main.cf'
 'helo.cf'
 'ptr.cf'
 'bounce.cf'
 'network_table'
 'relay_domains'
 'spamphrases-white.pcre'
 'spamphrases-block.pcre'
 'batv.regexp'
 'body_checks.pcre'
 'header_checks.pcre'
 'mime_header_checks.pcre'
 'esmtp_access'
)

#### Dwonload and check SHA256 sum of installer package ####
check_package() {
    if [ ! -e ${workdir}/${PACKAGE} ]; then
	printf "\033[32mDownloading file...\033[0m\n";
	curl -sS --connect-timeout 30 -O https://people.ipfire.org/~mlorenz/mp/${PACKAGE};
	printf "\033[32mFile download success...\033[0m\n";
    else 
	printf "${PACKAGE} found...\n";
    fi;

    CHECK=$(sha256sum "${workdir}/${PACKAGE}" |awk '{print $1}');
    if [[ "${SUM}" = "${CHECK}" ]]; then
	printf "Check SHA256SUM sum of file: ${PACKAGE}
SHA256SUM sum is \033[32m${CHECK}\033[0m  \033[92mOK\033[0m
SHA256SUM sum is correct! Continuing installer...\n";
    else
	printf "SHA256SUM sum should be \033[92m${CHECK}
\033[0mSHA256SUM sum is        \033[91m${SUM}\033[0m and is not correct!\033[0m
\033[1;127mShit happens :-( the SHA256SUM sum is incorrect, please download again.\033[0m\n";
	exit 1;
    fi;
    printf "\033[32mUnpack files now...\033[0m "
    tar xf $workdir/${PACKAGE};
    rm -f $workdir/${PACKAGE};
    unset SUM PACKAGE CHECK;
    printf "\033[92mdone...\033[0m\n"
}

#### clean_up function for pakfire folder ####
clean_up() {
    cd /opt/pakfire/tmp;
    rm -rf install.sh ROOTFILES files.tar.xz uninstall.sh update.sh *.ipfire;
    cd $workdir;
}

create_configfile() {

 local TCONF MAIN MGCONFDIR MGCONFFILE MGRELAYFILE MYDOMAIN MYHOSTNAME MSIP MSPORT SASLFILE RELAYUSER RELAYPASS SECOPTIONS;
 MGCONFDIR="/var/ipfire/mailgateway"
 MGCONFFILE="${MGCONFDIR}/main.conf"
 MGRELAYFILE="${MGCONFDIR}/relay.conf";
 MAIN="${configdir}/main.cf";
 mkdir -p ${MGCONFDIR};

 # locate transport file
 if [ -f ${configdir}/maps/transport ]; then 
   TCONF="${configdir}/maps/transport";
 else
   TCONF="${configdir}/transport";
 fi;

 if [ ! -f ${MGCONFFILE} ]; then
   # Search current parameters
   MYDOMAIN=$(awk -F= '/^mydomain/ {print $2}' ${MAIN}| cut -d" " -f2);

   if [ ! ${MYDOMAIN} = "" ]; then 
     MYHOSTNAME=$(awk -F= '/^myhostname/ {print $2}' ${MAIN}| cut -d" " -f2);
     MSIP=$(  grep ${MYDOMAIN} ${TCONF} |grep -v "#"|awk '{print $2}'| sed 's/smtp//;s/:/ /g'|awk '{print $1}');
     MSPORT=$(grep ${MYDOMAIN} ${TCONF} |grep -v "#"|awk '{print $2}'| sed 's/smtp//;s/:/ /g'|awk '{print $2}');

     # create main.conf file
     echo "MYDOMAIN=${MYDOMAIN}" > ${MGCONFFILE};
     echo "MYHOSTNAME=${MYHOSTNAME}" >> ${MGCONFFILE};
     echo "MSIP=${MSIP}" >> ${MGCONFFILE};
     echo "MSPORT='${MSPORT}'" >> ${MGCONFFILE};
     echo "RELAYON='off'" >> ${MGCONFFILE};
     echo "RELAYHOST='smtp.1und1.de'" >> ${MGCONFFILE};
     echo "RELAYUSER=''" >> ${MGCONFFILE};
     echo "RELAYPASS=''" >> ${MGCONFFILE};
   fi;
 fi;
}

#### backup postfix and amavisd config function ####
backup_config_files() {
updatemode="0"
# Check if Postfix is already installed
if [[ -e /usr/sbin/postfix ]] ; then
    create_configfile;
    echo -e "\033[36mPostfix is already installed, save configs and updating...\033[0m ";
    updatemode="1"
    mkdir -p $workdir/up
    for i in ${configfiles[@]}; do
      if [ -f ${configdir}/${i} ]; then /bin/cp ${configdir}/${i} $workdir/up; fi;
    done
    for i in ${mapsfiles[@]}; do
      if [ -f ${MAPSDIR}/${i} ]; then /bin/cp ${MAPSDIR}/${i} $workdir/up; fi;
    done
    /bin/cp -f "/etc/amavisd.conf" $workdir/up
fi;
}

restore_config_files() {
if [ "$updatemode" = "1" ]; then
    echo " ";
    echo -e "\033[32mRestore configuration...\033[0m ";
    mkdir -p $workdir/up
    for i in ${configfiles[@]}; do
      if [ -f ${workdir}/up/${i} ]; then /bin/mv -f ${workdir}/up/${i} ${configdir}; fi;
    done
    for i in ${mapsfiles[@]}; do
      if [ -f ${workdir}/up/${i} ]; then /bin/mv -f ${workdir}/up/${i} ${MAPSDIR}; fi;
    done
    /bin/mv -f $workdir/up/amavisd.conf /etc/;
    rm -rf $  ${workdir}/up;
    updatemode="0";
fi;
}

#### install package funtction ####
install_package() {
 echo -en "\033[37m ${1} \033[0m";
 echo " " >> ${workdir}/files.log
 echo "Installing ${1}:" >> ${workdir}/files.log;
 echo $LOGLINE >> ${workdir}/files.log;
 mv $workdir/${1} ${DIR};   
 cd $DIR;
 $TAR $1  >> /dev/null;
 ./install.sh  >> ${workdir}/files.log;
 rm -rf ${DIR}/*;  
 cd ${workdir};
 echo -e "\033[92mdone...\033[0m";
 echo ${LOGLINE} >> ${workdir}/files.log;
}

#### install libs function ####
install_libs() {
 echo -en "\033[37m ${1} \033[0m";
 echo " " >> $workdir/files.log;
 echo "Installing ${1}:" >> ${workdir}/files.log;
 echo $LOGLINE >> $workdir/files.log
 tar axvf $1 -C / >> ${workdir}/files.log;
 rm -f ${workdir}/${1};
 echo -e "\033[92mdone...\033[0m";
 echo ${LOGLINE} >> ${workdir}/files.log;
}

#### install perl4 compat scripts function ####
install_perl4cs() {
 echo -en "\033[37m ${PERL4CS} \033[0m";
 echo " " >> $workdir/files.log;
 echo "Installing ${PERL4CS}:" >> ${workdir}/files.log;
 echo ${LOGLINE} >> ${workdir}/files.log
 tar axvf ${PERL4CS} -C /usr/lib/perl5/core_perl >> ${workdir}/files.log;
 rm -rf ${workdir}/${PERL4CS};
 echo -e "\033[92mdone... \033[0m";
 echo ${LOGLINE} >> ${workdir}/files.log;
}

#### installing mailproxy packages ####
install_mailproxy_components() {

 # first install new init scripts
 echo -e "\033[32mInstall new init scripts now... \033[0m"
 install_package initscripts.ipfire;
 echo " ";

 # stop services
 pidof httpd > /dev/null
 if [ "${?}" = "0" ]; then
   /etc/init.d/apache stop
 fi

 # needed libs
 echo -e "\033[32mInstall libs package now... \033[0m";
 install_libs ${LIBPACK};
 # remove old glibc libs after 2.35 install
 rm -f /lib/lib*-{2.31,2.32,2.33}.so
 rm -f /lib/ld-{2.31,2.32,2.33}.so
 rm -f /usr/lib/libbfd-{2.33.1,2.34,2.35.1,2.36.1,2.37}.so
 rm -f /usr/lib/libopcodes-{2.33.1,2.34,2.35.1,2.36.1,2.37}.so
 # remove old icu libs
 rm -f /usr/lib/libicu*.{70.1,71,71.1,72,72.1,73,73.1}
 printf '\n';

 # postfix only 
 if [[ $ONLYPF = 1 ]]; then
    echo -e "\033[32mInstall postfix only packages now... \033[0m";
   for i in ${PFIX3ONLY[@]}; do
     install_package ${i};
   done
 fi;

 # remove old perl modules and folders
 if [[ $pfver = "1" ]] && [[ $ONLYPF = 0 ]]; then
   echo -en "\033[32mRemove old perl installation: \033[0m"; 
   rm -rdf /usr/lib/perl5/{5.32.0,5.32.1,5.34.0,5.34.1,5.36.0,5.36.1}
   rm -rdf /usr/lib/perl5/site_perl/{5.32.0,5.32.1,5.34.0,5.34.1,5.36.0,5.36.1}
   rm -f /usr/bin/perl{5.32.0,5.32.1,5.34.0,5.34.1,5.36.0,5.36.1}
   # remove obsolete perl crypt RSA module
   rm -rdf /usr/lib/perl5/site_perl/auto/Crypt/OpenSSL/RSA
   rm -f /usr/lib/perl5/site_perl/Crypt/OpenSSL/RSA.pm

   # remove obsolete GeoIP Perl module
   rm -rdf /usr/lib/perl5/site_perl/auto/Geo
   echo -e "\033[92mdone...\033[0m";

   # install perl packages
   echo -e "\033[32mInstall new Perl packages now... \033[0m"; 
   for i in ${PERL[@]}; do
     install_package ${i};
   done

   install_perl4cs;
   echo " ";
   /etc/init.d/apache start
   echo " ";

   # stop ClamAV if running 
   pidof clamd > /dev/null
   if [ "${?}" = "0" ]; then
     /etc/init.d/clamav stop
   fi

   # install Mail Gateway main packages
   echo -e "\033[32mInstall mail gateway packages now... \033[0m"; 
   for i in ${MPROXY[@]}; do
     install_package ${i};
   done

   # create postfix verify folder
   mkdir -p /var/spool/postfix/data;
   chown -R postfix:root /var/spool/postfix/data;
   chmod -R 700 /var/spool/postfix/data;

   # install bounce templates
   /bin/mv -f ${workdir}/bounce.de-DE.cf ${configdir};

   # enable additional spamassassin plugins
   sed -i 's/^# \(.*::TxRep\)/\1/' /etc/mail/spamassassin/v341.pre;
   sed -i 's/^# \(.*::PDFInfo\)/\1/' /etc/mail/spamassassin/v341.pre;
   sed -i 's/^# \(.*::HashBL\)/\1/' /etc/mail/spamassassin/v342.pre;
   sed -i 's/^# \(.*::FromNameSpoof\)/\1/' /etc/mail/spamassassin/v342.pre;
   sed -i 's/^# \(.*::Phishing\)/\1/' /etc/mail/spamassassin/v342.pre;
   sed -i 's/^# \(.*::OLEVBMacro\)/\1/' /etc/mail/spamassassin/v343.pre;
   # disable sa plugins
   sed -i 's/loadplugin Mail::SpamAssassin::Plugin::Pyzor/\# loadplugin Mail::SpamAssassin::Plugin::Pyzor/' /etc/mail/spamassassin/v310.pre;

   # Workaround for the installer does not continue after the end of this script.
   # The clamav initscript causes this effect
   kill -9 $(ps -a | grep clamav |grep -v clamavctrl | awk '{printf("%s \n",$1 )}');

   # remove after openssl 3.0 update not more working Perl DKIM module
   rm -f /usr/lib/perl5/site_perl/Mail/DKIM.pm;
   rm -rdf /usr/lib/perl5/site_perl/Mail/DKIM/;

 fi;
 unset i;

 echo -e "\033[32mAll mail gateway packages has been installed.\033[0m";
 echo " ";
 echo -en "\033[32mUpdate language cache... : \033[0m ";
 perl -e "require '/var/ipfire/lang.pl'; &Lang::BuildCacheLang";
 echo -e "\033[92mdone...\033[0m";

 echo -en "\033[32mCleaning obsolete files in config directory: \033[0m ";

 # Create manuals dir for Postfix if not alread done
 if [ ! -d "${MANDIR}"  ]; then
   mkdir -p ${MANDIR};
 fi

 # move original config files to manual dir 
 mv -f ${configdir}/{bounce.cf.default,access,header_checks,generic,relocated,canonical} ${MANDIR};

 # delete obsolete files
 rm -f  ${configdir}/{mysql-canonical.cf,mysql-mydestination.cf,mysql-virtual.cf,makedefs.out,TLS_LICENSE,LICENSE};
 echo -e "\033[92mdone...\033[0m";
}

#### mailproxy daily cleaning script ####
write_cleaning_script() {
echo -en "\033[32mWrite mpclean.sh file to fcron.daily now: \033[0m";
cat > /etc/fcron.daily/mpclean.sh << "EOF"
#!/bin/bash
#
# IPFire Mail Gateway Project 
# /etc/fcron.daily/mpclean.sh
# 
# small script for update spamassassin signatures
# and deleting old quarantined messages
#
find /var/virusmails/ -type f -mtime +30 -delete;
find /var/amavis/tmp/ -type f -mtime +30 -print | xargs /bin/rm -f
sa-update;
sa-update --nogpg --channel spamassassin.heinlein-support.de &> /dev/null;
# handle unescaped left braces in regex
sed -i 's|]{|]\\{|g' /var/lib/spamassassin/4.000000/spamassassin_heinlein-support_de/*.cf
EOF
chmod +x /etc/fcron.daily/mpclean.sh;
echo -e "\033[92mdone...\033[0m";
}

install_clamav_extra_signatrures_script() {
  echo -en "\033[32mInstall clamav 3rd party signatrures script: \033[0m";
  cat > /etc/fcron.daily/clamav_install_3rdps.sh << "EOF"
#!/bin/bash
# Download (and working) dir is ...
RDPDIR=/tmp/clamav-rdpdir
SANESECURL=http://ftp.swin.edu.au/sanesecurity

#You need < YOUR-SIGNATURE-NUMBER > before use!
#https://www.securiteinfo.com/clients/customers/signup
#SECURITEINFO=http://www.securiteinfo.com/get/signatures/<SET YOUR-SIGNATURE-NUMBER HERE!>

URLHAUS=https://urlhaus.abuse.ch/downloads

DATABASES1=(
 'bofhland_malware_attach.hdb'
 'bofhland_malware_URL.ndb'
 'bofhland_cracked_URL.ndb'
 'bofhland_phishing_URL.ndb'
 'winnow_extended_malware.hdb'
 'winnow_malware.hdb'
 'winnow_malware_links.ndb'
 'winnow_spam_complete.ndb'
 'rogue.hdb'
 'phish.ndb'
 'porcupine.ndb'
 'phishtank.ndb'
 'spamimg.hdb'
 'scam.ndb'
 'blurl.ndb'
 'malware.expert.ndb'
 'junk.ndb'
)

DATABASES3=(
 'urlhaus.ndb'
)

# Prepare dir
if [ -d "${RDPDIR}" ]; then
   rm -rf ${RDPDIR};
   mkdir ${RDPDIR};
else
   mkdir ${RDPDIR};
fi

# Load SANESECU lists and check md5sum
for i in ${DATABASES1[@]}; do
  logger -t ipfire "Download ${i}";
  echo -en "Download \033[32m${i}\033[0m and check MD5 sum: ";
  wget -T 30 -q --directory-prefix=${RDPDIR} ${SANESECURL}/${i} ${SANESECURL}/${i}.md5;
  
  # Check if .md5 file exist
  if [ -e ${RDPDIR}/${i}.md5 ]; then

    # Check md5 sum
    if [ ! $(cat ${RDPDIR}/${i}.md5 |awk '{ print $1 }') = $(md5sum ${RDPDIR}/${i} |awk '{ print $1 }') ]; then
      rm -f ${RDPDIR}/${i} ${RDPDIR}/${i}.md5;
      echo -e "\033[91mfailed, removing db file...\033[0m";
      logger -t ipfire "Update of ${i} failed,  MD5 sum error";
    else
      echo -e "\033[92mOK\033[0m"
      rm -f ${RDPDIR}/${i}.md5;
    fi;

  else
    echo -e "\033[91mNo MD5 file found! removing db file...\033[0m";
    logger -t ipfire "Update of ${i} failed, no MD5 file found";
    rm -f ${RDPDIR}/${i};
  fi;
  sleep 1

done

# Load lists URLHAUS
  echo -en "Download URLHAUS lists: ";
for i in ${DATABASES3[@]}; do
  logger -t ipfire "Download ${i}";
  echo -en "\033[32m${i}\033[0m ";
  wget -T 30 -q --directory-prefix=${RDPDIR} ${URLHAUS}/${i};
  sleep 1;
done

# Set owner
chown clamav:clamav $RDPDIR/*.?db;

# Set rights
chmod 0644 $RDPDIR/*.?db;

# Move files
mv -f $RDPDIR/*.?db /var/lib/clamav/;

# Clean up
rm -rf ${RDPDIR};

# Clean vars
unset RDPDIR DATABASES SANESECURL i
# Before enable SECURITYINFO DBs you neet SIGNATURE-NUMBER in downlaod section!
# unset RDPDIR DATABASES SECURITEINFO i
unset RDPDIR DATABASES URLHAUS i

# Write log entry
logger -t ipfire "ClamAV: 3rd-Party-Sanesecurity lists updated";

clamdscan --reload

# Before enable MalwarePatrol SA you must need a SIGNATURE-NUMBER!
# https://www.malwarepatrol.net/spamassassin-configuration-guide/
# spamassassin malware patrol update
# wget --no-check-certificate -O /var/lib/spamassassin/4.000000/70_malware_patrol_blocklist.cf 'https://lists.malwarepatrol.net/cgi/getfile?receipt= < YOUR-SIGNATURE-NUMBER > &product=32&list=spamassassin'
#	sleep 1
echo " ";
exit 0;
EOF
chmod +x /etc/fcron.daily/clamav_install_3rdps.sh
echo -e "\033[92mdone...\033[0m";
}

cleanup_meta_files() {
	local PFIREDIR="/opt/pakfire/db/installed";
	rm -f ${PFIREDIR}/meta-{amavisd,postfix,clamav,guardian,wio};
	touch ${PFIREDIR}/meta-{amavisd,postfix,clamav,guardian,wio};
}

#### additional files ####
install_additional_files() {
 echo -en "\033[32mInstall additional files: \033[0m";
 # remove old files
 mv -f ${workdir}/mpreport.sh /usr/sbin;
 /bin/cp -f ${workdir}/mpconfig.sh /usr/sbin;
 chmod +x /usr/sbin/{mpreport.sh,mpconfig.sh};
 echo -e "\033[92mdone...\033[0m";
}

check_service_links() {
 echo -en "\033[32mCheck service symlinks: \033[0m";
   AP=$(find /etc/rc.d/rc*.d -name "*apache");
   SA=$(find /etc/rc.d/rc*.d -name "*spamassassin");
   AV=$(find /etc/rc.d/rc*.d -name "*amavisd");
   PF=$(find /etc/rc.d/rc*.d -name "*postfix");
   rm -rf ${AP} ${SA} ${AV} ${PF}; 
   unset AP SA AV PF;

   # no spamassassin symlinks needed, no spamd deamon needed!
   # amavisd loads spamassassin 

   # start sequence rc3.d
   ln -sf  ../init.d/apache      /etc/rc.d/rc3.d/S42apache
   ln -sf  ../init.d/amavisd     /etc/rc.d/rc3.d/S45amavisd
   ln -sf  ../init.d/postfix     /etc/rc.d/rc3.d/S46postfix
   # shutdown sequence rc0.d
   ln -sf  ../init.d/postfix     /etc/rc.d/rc0.d/K23postfix
   ln -sf  ../init.d/amavisd     /etc/rc.d/rc0.d/K24amavisd
   ln -sf  ../init.d/apache      /etc/rc.d/rc0.d/K28apache
   # shutdown sequence rc6.d
   ln -sf  ../init.d/postfix     /etc/rc.d/rc6.d/K23postfix
   ln -sf  ../init.d/amavisd     /etc/rc.d/rc6.d/K24amavisd
   ln -sf  ../init.d/apache      /etc/rc.d/rc6.d/K28apache

 if [[ $ONLYPF = 1 ]]; then
   PF=$(find /etc/rc.d/rc*.d -name "*postfix");
   rm -rf ${PF}; 
   unset PF;

   # start sequence rc3.d
   ln -sf  ../init.d/postfix     /etc/rc.d/rc3.d/S46postfix
   # shutdown sequence rc0.d
   ln -sf  ../init.d/postfix     /etc/rc.d/rc0.d/K23postfix
   # shutdown sequence rc6.d
   ln -sf  ../init.d/postfix     /etc/rc.d/rc6.d/K23postfix
 fi;
 echo -e "\033[92mdone...\033[0m";
}

remove_files() {
echo -en "\033[32mClean up not installed files now: \033[0m";
rm -rf *.ipfire;
echo -e "\033[92mdone...\033[0m";
} 

check_smartmatch_entry() {
 echo -en "\033[32mCheck smartmatch entrys: \033[0m";

 local STRING="no warnings 'experimental::smartmatch';" 
 local TESTVAR="";
 local FILES=(
  '/usr/lib/firewall/rules.pl'
  '/usr/lib/firewall/firewall-lib.pl'
 );

 for i in ${FILES[@]}; do
  TESTVAR=$(grep smartmatch $i);
  if [[ ${TESTVAR} != ${STRING} ]]; then
    LINE=$(grep -n "use strict" ${i} | awk -F: '{ print $1; }');
    sed -i "${LINE}a${STRING}" $i;
  fi;
 done;

 unset FILES TESTVAR STRING LINE i;
 echo -e "\033[92mdone...\033[0m";
}

install_fetchmail() {

  # install package
  install_package ${FETCHMAIL};
  rm -f /root/.fetchmailrc;
  # change config file location in start script
  sed -i "s|/root/.fetchmailrc|/etc/fetchmailrc|" /etc/rc.d/init.d/fetchmail;

  # write template if not exist
  if [[ ! -f /etc/fetchmailrc ]]; then
   echo -en "\033[32mWrite /etc/fetchmailrc template: \033[0m";
   cat > /etc/fetchmailrc << "EOF"
# common settings
set postmaster postmaster@mydomian.com
set no bouncemail
set no spambounce
set syslog
set daemon 300

# for set a higer time interval, add following command to server definition 
# after proto POP3  (3x300sec = 15min)
# interval 3

# server definitions (more than one user per server possible)
# copy this section for more servers
poll pop3.domain.com proto POP3
  localdomains domain.local
  envelope X-Envelope-To
  user user1@domain.com with pass password
  user user2@domain.com with pass password
  ssl
  sslproto tls1
  nokeep
  fetchall
  smtphost 127.0.0.1
  is * here

EOF
   chmod 0700 /etc/fetchmailrc;
   echo -e "\033[92mdone...\033[0m";
 fi;
}

check_fetchmail_package() {
while true
 do
   tput clear;
   echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
   echo -e "\033[1;36m-                     Fetchmail addon for Mail Gateway                         -\033[0m";
   echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
   echo " ";
   echo " Press '1' to install fetchmail addon";
   echo " Press 'q' to quit this menu and continue installation";
   echo " ";
   echo -e "\033[33mThe configuration file is /etc/fetchmailrc \033[0m";
   echo -e "\033[33mplease fill it with your server data and set the postmaster address \033[0m";
   echo " ";
   echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
   echo -n " Please select: ";
   read -n 1 answer;
   case "$answer" in
	1)
	break
	;;

	q)
	break
	;;

	*)
	echo " < Wrong selection! ";
	sleep 1;
	;;
   esac
 done;
 echo " ";
 if [[ ${answer} == 1 ]]; then install_fetchmail; fi;
 echo " ";
}

install_postmap_script() {
cat > /usr/sbin/mpup << "EOF"
#!/bin/bash
# simple postmap update script

CONFIGDIR="/etc/postfix";
MAPSDIR="${CONFIGDIR}/maps";

echo -n "Generating LMDB databases from access files: "
postmap lmdb:${MAPSDIR}/{virtual,transport,sender_access,smtpd_access,tld_access,helo_access,tld_new_access,sld_access,relay_domains,relay_recipients};
if [ -e ${MAPSDIR}/sasl_passwd ]; then postmap lmdb:${MAPSDIR}/sasl_passwd; fi;
if [ -e ${MAPSDIR}/generic ]; then postmap lmdb:${MAPSDIR}/generic; fi;
if [ -e ${MAPSDIR}/relocated ]; then postmap lmdb:${MAPSDIR}/relocated; fi;
postalias lmdb:${MAPSDIR}/aliases;
echo -e "\033[92mdone...\033[0m";
unset CONFIGDIR MAPSDIR;
EOF
chmod +x /usr/sbin/mpup;
rm -f /usr/sbin/mpup.sh
}

install_service_script() {
cat > /usr/sbin/service << "EOF"
#!/bin/sh
###############################################################################
#                                                                             #
# IPFire.org - A linux based firewall                                         #
# Copyright (C) 2007-2020  IPFire Team  <info@ipfire.org>                     #
#                                                                             #
# This program is free software: you can redistribute it and/or modify        #
# it under the terms of the GNU General Public License as published by        #
# the Free Software Foundation, either version 3 of the License, or           #
# (at your option) any later version.                                         #
#                                                                             #
# This program is distributed in the hope that it will be useful,             #
# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
# GNU General Public License for more details.                                #
#                                                                             #
# You should have received a copy of the GNU General Public License           #
# along with this program.  If not, see <http://www.gnu.org/licenses/>.       #
#                                                                             #
###############################################################################

is_ignored_file() {
	case "$1" in
		skeleton | README | *.dpkg-dist | *.dpkg-old | rc | rcS | single | reboot | bootclean.sh)
			return 0
		;;
	esac
	return 1
}

VERSION="`basename $0` ver. ipfire"
USAGE="Usage: `basename $0` < option > | --status-all | \
[ service_name [ command | --full-restart ] ]"
SERVICE=
ACTION=
SERVICEDIR="/etc/init.d"
OPTIONS=

if [ $# -eq 0 ]; then
   echo "${USAGE}" >&2
   exit 1
fi

cd /
while [ $# -gt 0 ]; do
  case "${1}" in
    --help | -h | --h* )
       echo "${USAGE}" >&2
       exit 0
       ;;
    --version | -V )
       echo "${VERSION}" >&2
       exit 0
       ;;
    *)
       if [ -z "${SERVICE}" -a $# -eq 1 -a "${1}" = "--status-all" ]; then
          cd ${SERVICEDIR}
          for SERVICE in * ; do
            case "${SERVICE}" in
              functions | halt | killall | single| linuxconf| kudzu)
                  ;;
              *)
                if ! is_ignored_file "${SERVICE}" \
		    && [ -x "${SERVICEDIR}/${SERVICE}" ]; then
                        if ! grep -qs "\(^\|\W\)status)" "${SERVICE}"; then
                          #printf " %s %-60s %s\n" "[?]" "${SERVICE}:" "unknown" 1>&2
                          echo " [ ? ]  ${SERVICE}" 1>&2
                          continue
                        else
                          out=$(env -i LANG="$LANG" PATH="$PATH" TERM="$TERM" "${SERVICEDIR}/${SERVICE}" status 2>&1)
                          if [ "$?" = "0" -a -n "$out" ]; then
                            #printf " %s %-60s %s\n" "[+]" "${SERVICE}:" "running"
                            echo " [ + ]  ${SERVICE}"
                            continue
                          else
                            #printf " %s %-60s %s\n" "[-]" "${SERVICE}:" "NOT running"
                            echo " [ - ]  ${SERVICE}"
                            continue
                          fi
                        fi
                  #env -i LANG="${LANG}" PATH="${PATH}" TERM="$TERM" "${SERVICEDIR}/${SERVICE}" status
                fi
                ;;
            esac
          done
          exit 0
       elif [ $# -eq 2 -a "${2}" = "--full-restart" ]; then
          SERVICE="${1}"
          if [ -x "${SERVICEDIR}/${SERVICE}" ]; then
            env -i LANG="${LANG}" PATH="${PATH}" TERM="${TERM}" "${SERVICEDIR}/${SERVICE}" stop
            env -i LANG="${LANG}" PATH="${PATH}" TERM="${TERM}" "${SERVICEDIR}/${SERVICE}" start
            exit $?
          fi
       elif [ -z "${SERVICE}" ]; then
         SERVICE="${1}"
       elif [ -z "${ACTION}" ]; then
         ACTION="${1}"
       else
         OPTIONS="${OPTIONS} ${1}"
       fi
       shift
       ;;
   esac
done

# use the traditional sysvinit
if [ -x "${SERVICEDIR}/${SERVICE}" ]; then
   exec env -i LANG="$LANG" PATH="$PATH" TERM="$TERM" "$SERVICEDIR/$SERVICE" ${ACTION} ${OPTIONS}
else
   echo "${SERVICE}: unrecognized service" >&2
   exit 1
fi
EOF
chmod +x /usr/sbin/service;
}

#######################################
#        Main execution start         #
#######################################

# Command line args test
NOMSG="0";
ONLYPF="0";
pfver="0";

for arg; do
  if [ ${arg} = "-quiet" ]; then NOMSG="1"; fi;
  if [ ${arg} = "-opf" ]; then ONLYPF="1"; echo "Starting postfix only installation"; fi;
done

check_package;
backup_config_files;

# set installation variant to install with perl
# without perl 5.26.x is not more supported
pfver=1;

clear;
echo " ";
echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
echo -e "\033[1;36m-               Starting Mail Gateway components installation                  -\033[0m";
echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
echo " ";
if [ "$updatemode" = "0" ]; then echo -e "\033[32m Fresh installation.\033[0m"; fi;
if [ "$updatemode" = "1" ]; then echo -e "\033[32m Update enabled. Configuration saved!\033[0m"; fi;
echo " ";
echo -e "\033[33m Platform: $PLATFORM and Perl: $PERLVER\033[0m";
echo " ";
echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
echo -e "\033[32mStarting installation now...\033[0m";
sleep 2;
echo " ";
cleanup_meta_files;
install_mailproxy_components;
restore_config_files;
install_additional_files;
check_service_links;
check_smartmatch_entry;
install_clamav_extra_signatrures_script;
install_service_script;
install_postmap_script;

# Update SA signatures
if [[ $ONLYPF = 0 ]]; then

  # remove old sa rules dir
  rm -rdf /var/lib/spamassassin/3.00400{1,2,3,4,5};

  # install spamassassin cleaning script 
  write_cleaning_script;

  # check sa key dir 
  if [ ! -d /etc/mail/spamassassin/sa-update-keys/ ]; then
    rm -rdf /etc/mail/spamassassin/sa-update-keys/;
    mkdir /etc/mail/spamassassin/sa-update-keys/;
  fi;
  chmod -R 600 /etc/mail/spamassassin/sa-update-keys/;

  # install spamassassin gpg key
  curl -s --tlsv1.2 https://spamassassin.apache.org/updates/GPG.KEY > ${workdir}/sa-gpg.key;
  sa-update --import ${workdir}/sa-gpg.key;
  rm -f ${workdir}/sa-gpg.key;


  # update spamassassin singnatures
  echo -en "\033[32mUpdating SpamAssassin signatures: \033[0m";
  sa-update;
  sa-update --nogpg --channel spamassassin.heinlein-support.de &> /dev/null

  # handle unescaped left brace in regex in files from heinlein support
  sed -i 's|]{|]\\{|g' /var/lib/spamassassin/4.000000/spamassassin_heinlein-support_de/*.cf;
  echo -e "\033[92mdone...\033[0m";
  echo " ";
fi;

check_fetchmail_package;

#deleting not used modules and files
rm -f  ${workdir}/*.ipfire;
rm -rdf ${workdir}/up
rm -f /var/ipfire/mailgateway/maps/sasl_pss*

unset PERL PERLOLD MPROXY LOGLINE PERLVER PLATFORM workdir FETCHMAIL configfiles configdir mapsfiles;

echo -e "\033[93mMail Gateway packages installation is done... \033[0m";
echo " ";
#End of install.sh
