#!/bin/bash -

#set -x
# mpman.sh
#
# Contains the manuals from the templates.
# gocart 24.05.2015

POST="/etc/postfix"
MAN="/etc/postfix/man"

# Create manuals dir for Postfix if not alread done
if [ ! -d "${MAN}"  ]; then
    mkdir -p ${MAN};
fi

if [ ! -e "${MAN}/virtual.txt" ]; then
echo -e "Install virtual aliasing manual...";
cat > ${MAN}/virtual.txt << "EOF"
# VIRTUAL(5)                                                          VIRTUAL(5)
# 
# NAME
#        virtual - Postfix virtual alias table format
# 
# SYNOPSIS
#        postmap /etc/postfix/virtual
# 
#        postmap -q "string" /etc/postfix/virtual
# 
#        postmap -q - /etc/postfix/virtual <inputfile
# 
# DESCRIPTION
#        The  optional  virtual(5)  alias  table rewrites recipient
#        addresses for all local, all virtual, and all remote  mail
#        destinations.   This  is unlike the aliases(5) table which
#        is used only for local(8) delivery.  Virtual  aliasing  is
#        recursive,  and  is  implemented by the Postfix cleanup(8)
#        daemon before mail is queued.
# 
#        The main applications of virtual aliasing are:
# 
#        o      To redirect mail for one address  to  one  or  more
#               addresses.
# 
#        o      To   implement  virtual  alias  domains  where  all
#               addresses  are  aliased  to  addresses   in   other
#               domains.
# 
#               Virtual  alias  domains are not to be confused with
#               the virtual mailbox domains  that  are  implemented
#               with  the  Postfix  virtual(8) mail delivery agent.
#               With  virtual  mailbox  domains,   each   recipient
#               address can have its own mailbox.
# 
#        Virtual  aliasing  is  applied  only to recipient envelope
#        addresses, and  does  not  affect  message  headers.   Use
#        canonical(5)   mapping  to  rewrite  header  and  envelope
#        addresses in general.
# 
#        Normally, the virtual(5) alias table  is  specified  as  a
#        text  file that serves as input to the postmap(1) command.
#        The result, an indexed file in dbm or db format,  is  used
#        for fast searching by the mail system. Execute the command
#        "postmap /etc/postfix/virtual" to rebuild an indexed  file
#        after changing the corresponding text file.
# 
#        When  the  table  is provided via other means such as NIS,
#        LDAP or SQL, the same lookups are  done  as  for  ordinary
#        indexed files.
# 
#        Alternatively,  the  table  can  be provided as a regular-
#        expression map where patterns are given as regular expres-
#        sions,  or lookups can be directed to TCP-based server. In
#        those case, the lookups are done in a  slightly  different
#        way  as  described below under "REGULAR EXPRESSION TABLES"
#        or "TCP-BASED TABLES".
# 
# CASE FOLDING
#        The search string is folded to lowercase  before  database
#        lookup.  As  of Postfix 2.3, the search string is not case
#        folded with database types such as regexp: or pcre:  whose
#        lookup fields can match both upper and lower case.
# 
# TABLE FORMAT
#        The input format for the postmap(1) command is as follows:
# 
#        pattern result
#               When pattern matches a mail address, replace it  by
#               the corresponding result.
# 
#        blank lines and comments
#               Empty  lines and whitespace-only lines are ignored,
#               as are lines whose first  non-whitespace  character
#               is a `#'.
# 
#        multi-line text
#               A  logical  line starts with non-whitespace text. A
#               line that starts with whitespace continues a  logi-
#               cal line.
# 
# TABLE SEARCH ORDER
#        With lookups from indexed files such as DB or DBM, or from
#        networked tables such as NIS, LDAP or  SQL,  patterns  are
#        tried in the order as listed below:
# 
#        user@domain address, address, ...
#               Redirect  mail  for  user@domain  to address.  This
#               form has the highest precedence.
# 
#        user address, address, ...
#               Redirect mail for user@site to address when site is
#               equal  to $myorigin, when site is listed in $mydes-
#               tination, or when it is listed in  $inet_interfaces
#               or $proxy_interfaces.
# 
#               This  functionality  overlaps with functionality of
#               the local aliases(5) database.  The  difference  is
#               that virtual(5) mapping can be applied to non-local
#               addresses.
# 
#        @domain address, address, ...
#               Redirect mail for other users in domain to address.
#               This form has the lowest precedence.
# 
#               Note:  @domain  is a wild-card. With this form, the
#               Postfix SMTP server accepts mail for any  recipient
#               in  domain,  regardless  of  whether that recipient
#               exists.  This may turn  your  mail  system  into  a
#               backscatter  source: Postfix first accepts mail for
#               non-existent recipients and then  tries  to  return
#               that  mail  as  "undeliverable" to the often forged
#               sender address.
# 
# RESULT ADDRESS REWRITING
#        The lookup result is subject to address rewriting:
# 
#        o      When the result  has  the  form  @otherdomain,  the
#               result  becomes the same user in otherdomain.  This
#               works only for the first address in a multi-address
#               lookup result.
# 
#        o      When  "append_at_myorigin=yes", append "@$myorigin"
#               to addresses without "@domain".
# 
#        o      When "append_dot_mydomain=yes", append ".$mydomain"
#               to addresses without ".domain".
# 
# ADDRESS EXTENSION
#        When a mail address localpart contains the optional recip-
#        ient delimiter (e.g., user+foo@domain), the  lookup  order
#        becomes: user+foo@domain, user@domain, user+foo, user, and
#        @domain.
# 
#        The  propagate_unmatched_extensions   parameter   controls
#        whether  an  unmatched  address extension (+foo) is propa-
#        gated to the result of table lookup.
# 
# VIRTUAL ALIAS DOMAINS
#        Besides virtual aliases, the virtual alias table can  also
#        be used to implement virtual alias domains. With a virtual
#        alias domain,  all  recipient  addresses  are  aliased  to
#        addresses in other domains.
# 
#        Virtual alias domains are not to be confused with the vir-
#        tual mailbox domains that are implemented with the Postfix
#        virtual(8)  mail  delivery  agent.  With  virtual  mailbox
#        domains, each recipient address can have its own  mailbox.
# 
#        With  a  virtual  alias domain, the virtual domain has its
#        own user name space. Local  (i.e.  non-virtual)  usernames
#        are  not visible in a virtual alias domain. In particular,
#        local aliases(5) and local mailing lists are  not  visible
#        as localname@virtual-alias.domain.
# 
#        Support for a virtual alias domain looks like:
# 
#        /etc/postfix/main.cf:
#            virtual_alias_maps = hash:/etc/postfix/virtual
# 
#        Note: some systems use dbm databases instead of hash.  See
#        the output  from  "postconf  -m"  for  available  database
#        types.
# 
#        /etc/postfix/virtual:
#            virtual-alias.domain     anything (right-hand content does not matter)
#            postmaster@virtual-alias.domain  postmaster
#            user1@virtual-alias.domain       address1
#            user2@virtual-alias.domain       address2, address3
# 
#        The  virtual-alias.domain anything entry is required for a
#        virtual alias domain. Without this entry, mail is rejected
#        with  "relay  access  denied", or bounces with "mail loops
#        back to myself".
# 
#        Do not specify virtual alias domain names in  the  main.cf
#        mydestination or relay_domains configuration parameters.
# 
#        With  a  virtual  alias  domain,  the  Postfix SMTP server
#        accepts  mail  for  known-user@virtual-alias.domain,   and
#        rejects   mail  for  unknown-user@virtual-alias.domain  as
#        undeliverable.
# 
#        Instead of specifying the virtual alias  domain  name  via
#        the  virtual_alias_maps table, you may also specify it via
#        the main.cf virtual_alias_domains configuration parameter.
#        This  latter parameter uses the same syntax as the main.cf
#        mydestination configuration parameter.
# 
# REGULAR EXPRESSION TABLES
#        This section describes how the table lookups  change  when
#        the table is given in the form of regular expressions. For
#        a description of regular expression lookup  table  syntax,
#        see regexp_table(5) or pcre_table(5).
# 
#        Each  pattern  is  a regular expression that is applied to
#        the entire address being looked up. Thus, user@domain mail
#        addresses  are  not  broken up into their user and @domain
#        constituent parts, nor is user+foo broken up into user and
#        foo.
# 
#        Patterns  are applied in the order as specified in the ta-
#        ble, until a pattern is  found  that  matches  the  search
#        string.
# 
#        Results  are  the  same as with indexed file lookups, with
#        the additional feature that parenthesized substrings  from
#        the pattern can be interpolated as $1, $2 and so on.
# 
# TCP-BASED TABLES
#        This  section  describes how the table lookups change when
#        lookups are directed to a TCP-based server. For a descrip-
#        tion of the TCP client/server lookup protocol, see tcp_ta-
#        ble(5).  This feature is not available up to and including
#        Postfix version 2.4.
# 
#        Each lookup operation uses the entire address once.  Thus,
#        user@domain mail addresses are not broken  up  into  their
#        user and @domain constituent parts, nor is user+foo broken
#        up into user and foo.
# 
#        Results are the same as with indexed file lookups.
# 
# BUGS
#        The table format does not understand quoting  conventions.
# 
# CONFIGURATION PARAMETERS
#        The  following  main.cf parameters are especially relevant
#        to this topic. See the Postfix  main.cf  file  for  syntax
#        details  and  for default values. Use the "postfix reload"
#        command after a configuration change.
# 
#        virtual_alias_maps
#               List of virtual aliasing tables.
# 
#        virtual_alias_domains
#               List of virtual alias domains. This uses  the  same
#               syntax as the mydestination parameter.
# 
#        propagate_unmatched_extensions
#               A  list  of  address rewriting or forwarding mecha-
#               nisms that propagate an address extension from  the
#               original  address  to  the result.  Specify zero or
#               more  of  canonical,   virtual,   alias,   forward,
#               include, or generic.
# 
#        Other parameters of interest:
# 
#        inet_interfaces
#               The  network  interface  addresses that this system
#               receives mail on.  You need to stop and start Post-
#               fix when this parameter changes.
# 
#        mydestination
#               List  of  domains  that  this mail system considers
#               local.
# 
#        myorigin
#               The domain that is appended  to  any  address  that
#               does not have a domain.
# 
#        owner_request_special
#               Give special treatment to owner-xxx and xxx-request
#               addresses.
# 
#        proxy_interfaces
#               Other interfaces that this machine receives mail on
#               by way of a proxy agent or network address transla-
#               tor.
# 
# SEE ALSO
#        cleanup(8), canonicalize and enqueue mail
#        postmap(1), Postfix lookup table manager
#        postconf(5), configuration parameters
#        canonical(5), canonical address mapping
# 
# README FILES
#        Use "postconf readme_directory" or  "postconf  html_direc-
#        tory" to locate this information.
#        ADDRESS_REWRITING_README, address rewriting guide
#        DATABASE_README, Postfix lookup table overview
#        VIRTUAL_README, domain hosting guide
# 
# LICENSE
#        The  Secure  Mailer  license must be distributed with this
#        software.
# 
# AUTHOR(S)
#        Wietse Venema
#        IBM T.J. Watson Research
#        P.O. Box 704
#        Yorktown Heights, NY 10598, USA
# 
#                                                                     VIRTUAL(5)
EOF
fi;

# Install header_checks manual
if [[ ! -e "${MAN}/header_checks.txt"  ]]; then
echo -e "Install header_checks manual...";
cat > ${MAN}/header_checks.txt << "EOF"
#HEADER_CHECKS(5)                                              HEADER_CHECKS(5)
#
#NAME
#       header_checks - Postfix built-in content inspection
#
#SYNOPSIS
#       header_checks = pcre:/etc/postfix/header_checks
#       mime_header_checks = pcre:/etc/postfix/mime_header_checks
#       nested_header_checks = pcre:/etc/postfix/nested_header_checks
#       body_checks = pcre:/etc/postfix/body_checks
#
#       milter_header_checks = pcre:/etc/postfix/milter_header_checks
#
#       smtp_header_checks = pcre:/etc/postfix/smtp_header_checks
#       smtp_mime_header_checks = pcre:/etc/postfix/smtp_mime_header_checks
#       smtp_nested_header_checks = pcre:/etc/postfix/smtp_nested_header_checks
#       smtp_body_checks = pcre:/etc/postfix/smtp_body_checks
#
#       postmap -q "string" pcre:/etc/postfix/filename
#       postmap -q - pcre:/etc/postfix/filename <inputfile
#
#DESCRIPTION
#       This  document describes access control on the content of message head-
#       ers and message body lines; it is implemented by the Postfix cleanup(8)
#       server  before  mail  is  queued.   See access(5) for access control on
#       remote SMTP client information.
#
#       Each message header or message body line is compared against a list  of
#       patterns.   When a match is found the corresponding action is executed,
#       and the matching process is repeated for the  next  message  header  or
#       message body line.
#
#       Note:  message  headers are examined one logical header at a time, even
#       when a message header spans multiple lines. Body lines are always exam-
#       ined one line at a time.
#
#       For  examples, see the EXAMPLES section at the end of this manual page.
#
#       Postfix header or body_checks are designed to stop a flood of mail from
#       worms or viruses; they do not decode attachments, and they do not unzip
#       archives. See the documents referenced below in the README  FILES  sec-
#       tion if you need more sophisticated content analysis.
#
#FILTERS WHILE RECEIVING MAIL
#       Postfix  implements  the  following  four  built-in  content inspection
#       classes while receiving mail:
#
#      header_checks (default: empty)
#              These are applied to initial message  headers  (except  for  the
#              headers that are processed with mime_header_checks).
#
#       mime_header_checks (default: $header_checks)
#              These are applied to MIME related message headers only.
#
#              This feature is available in Postfix 2.0 and later.
#
#       nested_header_checks (default: $header_checks)
#              These  are applied to message headers of attached email messages
#              (except   for   the   headers   that    are    processed    with
#              mime_header_checks).
#
#              This feature is available in Postfix 2.0 and later.
#
#       body_checks
#              These  are  applied  to  all other content, including multi-part
#              message boundaries.
#
#              With Postfix versions before 2.0, all content after the  initial
#              message headers is treated as body content.
#
#FILTERS AFTER RECEIVING MAIL
#       Postfix  supports  a  subset of the built-in content inspection classes
#       after the message is received:
#
#       milter_header_checks (default: empty)
#              These are applied to headers that are added with Milter applica-
#              tions.
#
#              This feature is available in Postfix 2.7 and later.
#
#FILTERS WHILE DELIVERING MAIL
#       Postfix  supports  all four content inspection classes while delivering
#       mail via SMTP.
#
#       smtp_header_checks (default: empty)
#
#       smtp_mime_header_checks (default: empty)
#
#       smtp_nested_header_checks (default: empty)
#
#       smtp_body_checks (default: empty)
#              These features are available in Postfix 2.5 and later.
#
#COMPATIBILITY
#       With Postfix version 2.2 and earlier specify "postmap -fq" to  query  a
#       table  that  contains  case sensitive patterns. By default, regexp: and
#       pcre: patterns are case insensitive.
#
#TABLE FORMAT
#       This document assumes that header and body_checks rules  are  specified
#       in  the  form  of Postfix regular expression lookup tables. Usually the
#       best performance is obtained with pcre (Perl Compatible Regular Expres-
#       sion) tables. The regexp (POSIX regular expressions) tables are usually
#       slower, but more widely available.  Use the command  "postconf  -m"  to
#       find out what lookup table types your Postfix system supports.
#
#       The general format of Postfix regular expression tables is given below.
#       For a discussion of specific pattern or flags syntax, see pcre_table(5)
#       or regexp_table(5), respectively.
#
#       /pattern/flags action
#              When /pattern/ matches the input string, execute the correspond-
#              ing action. See below for a list of possible actions.
# 
#      !/pattern/flags action
#             When /pattern/ does not match the input string, execute the cor-
#             responding action.
#
#       if /pattern/flags
#
#       endif  If  the  input  string  matches /pattern/, then match that input
#              string against the patterns between if and endif.  The if..endif
#              can nest.
#
#              Note: do not prepend whitespace to patterns inside if..endif.
#
#       if !/pattern/flags
#
#       endif  If  the  input  string does not match /pattern/, then match that
#              input string against the patterns  between  if  and  endif.  The
#              if..endif can nest.
#
#       blank lines and comments
#              Empty  lines and whitespace-only lines are ignored, as are lines
#              whose first non-whitespace character is a `#'.
#
#       multi-line text
#              A pattern/action line starts with non-whitespace  text.  A  line
#              that starts with whitespace continues a logical line.
#
#TABLE SEARCH ORDER
#       For  each  line of message input, the patterns are applied in the order
#
#       as specified in the table. When a pattern is  found  that  matches  the
#       input  line,  the  corresponding  action  is executed and then the next
#       input line is inspected.
#
#TEXT SUBSTITUTION
#       Substitution of substrings from the matched expression into the  action
#       string  is  possible using the conventional Perl syntax ($1, $2, etc.).
#       The macros in the result string may need to be written as ${n} or  $(n)
#       if they aren't followed by whitespace.
#
#       Note: since negated patterns (those preceded by !) return a result when
#       the expression does not match,  substitutions  are  not  available  for
#       negated patterns.
#
#ACTIONS
#       Action  names  are  case  insensitive. They are shown in upper case for
#       consistency with other Postfix documentation.
#
#       DISCARD optional text...
#              Claim successful delivery and silently discard the message.  Log
#              the optional text if specified, otherwise log a generic message.
#
#              Note: this action disables further header or body_checks inspec-
#              tion of the current message and affects all recipients.  To dis-
#              card only one recipient without discarding the  entire  message,
#              use the transport(5) table to direct mail to the discard(8) ser-
#              vice.
#
#              This feature is available in Postfix 2.0 and later.
#
#              This feature is not supported with smtp header/body checks.
#
#       DUNNO  Pretend that the input line  did  not  match  any  pattern,  and
#              inspect  the next input line. This action can be used to shorten
#              the table search.
#
#              For backwards compatibility reasons, Postfix also accepts OK but
#              it is (and always has been) treated as DUNNO.
#
#              This feature is available in Postfix 2.1 and later.
#
#       FILTER transport:destination
#              After the message is queued, send the entire message through the
#              specified external content filter. The transport name  specifies
#              the  first  field  of  a  mail delivery agent definition in mas-
#              ter.cf; the syntax of the next-hop destination is  described  in
#              the  manual  page  of  the  corresponding  delivery agent.  More
#              information about external content filters  is  in  the  Postfix
#              FILTER_README file.
#
#              Note  1: do not use $number regular expression substitutions for
#              transport or destination unless you know  that  the  information
#              has a trusted origin.
#
#              Note  2:  this  action overrides the main.cf content_filter set-
#              ting, and affects all recipients of the  message.  In  the  case
#              that  multiple  FILTER  actions  fire, only the last one is exe-
#              cuted.
#
#              Note 3: the purpose of the FILTER command is to override message
#              routing.   To  override  the  recipient's  transport but not the
#              next-hop destination, specify an empty filter destination (Post-
#              fix  2.7  and  later),  or  specify a transport:destination that
#              delivers through a different Postfix instance (Postfix  2.6  and
#              earlier). Other options are using the recipient-dependent trans-
#              port_maps  or  the  sender-dependent   sender_dependent_default-
#              _transport_maps features.
#
#              This feature is available in Postfix 2.0 and later.
#
#              This feature is not supported with smtp header/body checks.
#
#       HOLD optional text...
#              Arrange  for  the  message  to  be placed on the hold queue, and
#              inspect the next input line.  The message remains on hold  until
#              someone  either deletes it or releases it for delivery.  Log the
#              optional text if specified, otherwise log a generic message.
#
#              Mail that is placed on hold can be examined with the  postcat(1)
#              command,  and can be destroyed or released with the postsuper(1)
#              command.
#
#              Note: use "postsuper -r" to release mail that was kept  on  hold
#              for   a   significant  fraction  of  $maximal_queue_lifetime  or
#              $bounce_queue_lifetime, or longer. Use "postsuper -H"  only  for
#              mail that will not expire within a few delivery attempts.
#
#              Note: this action affects all recipients of the message.
#
#              This feature is available in Postfix 2.0 and later.
#
#              This feature is not supported with smtp header/body checks.
#
#       IGNORE Delete  the  current  line  from the input, and inspect the next
#             input line.
#
#       INFO optional text...
#              Log an "info:" record  with  the  optional  text...  (or  log  a
#              generic  text),  and inspect the next input line. This action is
#              useful for routine logging or for debugging.
#
#              This feature is available in Postfix 2.8 and later.
#
#       PREPEND text...
#              Prepend one line with the specified text, and inspect  the  next
#              input line.
#
#              Notes:
#
#              o      The  prepended text is output on a separate line, immedi-
#                     ately before the input that triggered the PREPEND action.
#
#              o      The  prepended  text  is not considered part of the input
#                     stream: it  is  not  subject  to  header/body  checks  or
#                     address  rewriting,  and  it does not affect the way that
#                     Postfix adds missing message headers.
#
#              o      When prepending text before a message  header  line,  the
#                     prepended  text  must  begin  with a valid message header
#                     label.
#
#              o      This action cannot be used to prepend multi-line text.
#
#              This feature is available in Postfix 2.1 and later.
#
#              This feature is not supported with milter_header_checks.
#
#       REDIRECT user@domain
#              Write a message redirection  request  to  the  queue  file,  and
#              inspect  the  next  input  line. After the message is queued, it
#              will be sent to the specified address instead  of  the  intended
#              recipient(s).
#
#              Note:  this  action overrides the FILTER action, and affects all
#              recipients of the message. If multiple  REDIRECT  actions  fire,
#              only the last one is executed.
#
#              This feature is available in Postfix 2.1 and later.
#
#              This feature is not supported with smtp header/body checks.
#
#       REPLACE text...
#              Replace  the  current  line with the specified text, and inspect
#              the next input line.
#
#              This feature is available in Postfix 2.2 and later. The descrip-
#              tion below applies to Postfix 2.2.2 and later.
#
#              Notes:
#
#              o      When  replacing  a  message  header line, the replacement
#                     text must begin with a valid header label.
#
#              o      The replaced text  remains  part  of  the  input  stream.
#                     Unlike  the  result  from  the PREPEND action, a replaced
#                     message header may be subject to  address  rewriting  and
#                     may  affect  the  way  that  Postfix adds missing message
#                     headers.
#
#       REJECT optional text...
#              Reject the entire message. Reply with optional text... when  the
#              optional text is specified, otherwise reply with a generic error
#              message.
#
#              Note: this action disables further header or body_checks inspec-
#              tion of the current message and affects all recipients.
#
#              Postfix  version  2.3  and  later support enhanced status codes.
#              When no code is specified at the beginning of optional  text...,
#              Postfix inserts a default enhanced status code of "5.7.1".
#
#              This feature is not supported with smtp header/body checks.
#
#      WARN optional text...
#             Log  a  "warning:"  record  with  the optional text... (or log a
#              generic text), and inspect the next input line. This  action  is
#              useful  for  debugging and for testing a pattern before applying
#              more drastic actions.
#
#BUGS
#       Empty lines never match, because some map types mis-behave when given a
#       zero-length  search string.  This limitation may be removed for regular
#       expression tables in a future release.
#
#       Many people overlook the main limitations  of  header  and  body_checks
#       rules.
#
#       o      These  rules  operate  on one logical message header or one body
#              line at a time. A decision made for one line is not carried over
#              to the next line.
#
#       o      If text in the message body is encoded (RFC 2045) then the rules
#              need to be specified for the encoded form.
#
#       o      Likewise, when message headers are encoded (RFC 2047)  then  the
#              rules need to be specified for the encoded form.
#
#       Message headers added by the cleanup(8) daemon itself are excluded from
#       inspection. Examples of such message headers are From:,  To:,  Message-
#       ID:, Date:.
#
#       Message  headers  deleted  by  the  cleanup(8)  daemon will be examined
#      before they are deleted. Examples are: Bcc:,  Content-Length:,  Return-
#       Path:.
#
#CONFIGURATION PARAMETERS
#       body_checks
#              Lookup  tables with content filter rules for message body lines.
#              These filters see one physical line at a time, in chunks  of  at
#              most $line_length_limit bytes.
#
#      body_checks_size_limit
#              The amount of content per message body segment (attachment) that
#              is subjected to $body_checks filtering.
#
#       header_checks
#
#       mime_header_checks (default: $header_checks)
#
#       nested_header_checks (default: $header_checks)
#              Lookup tables with  content  filter  rules  for  message  header
#              lines:  respectively,  these  are applied to the initial message
#              headers (not including MIME headers), to the MIME  headers  any-
#              where  in  the  message,  and to the initial headers of attached
#              messages.
#
#              Note: these filters see one logical message header  at  a  time,
#              even when a message header spans multiple lines. Message headers
#              that are longer than  $header_size_limit  characters  are  trun-
#              cated.
#
#       disable_mime_input_processing
#              While  receiving mail, give no special treatment to MIME related
#              message headers; all text after the initial message  headers  is
#              considered  to  be  part  of  the  message body. This means that
#              header_checks is applied to all the initial message headers, and
#              that body_checks is applied to the remainder of the message.
#
#              Note:  when  used  in  this  manner,  body_checks will process a
#              multi-line message header one line at a time.
#
#EXAMPLES
#       Header pattern to block attachments with bad file name extensions.  For
#       convenience, the PCRE /x flag is specified, so that there is no need to
#       collapse the pattern into a single line of text.  The  purpose  of  the
#       [[:xdigit:]] sub-expressions is to recognize Windows CLSID strings.
#
#       /etc/postfix/main.cf:
#           header_checks = pcre:/etc/postfix/header_checks.pcre
#
#       /etc/postfix/header_checks.pcre:
#           /^Content-(Disposition|Type).*name\s*=\s*"?(.*(\.|=2E)(
#             ade|adp|asp|bas|bat|chm|cmd|com|cpl|crt|dll|exe|
#             hlp|ht[at]|
#             inf|ins|isp|jse?|lnk|md[betw]|ms[cipt]|nws|
#             \{[[:xdigit:]]{8}(?:-[[:xdigit:]]{4}){3}-[[:xdigit:]]{12}\}|
#             ops|pcd|pif|prf|reg|sc[frt]|sh[bsm]|swf|
#             vb[esx]?|vxd|ws[cfh]))(\?=)?"?\s*(;|$)/x
#               REJECT Attachment name "$2" may not end with ".$4"
#
#       Body pattern to stop a specific HTML browser vulnerability exploit.
#
#       /etc/postfix/main.cf:
#           body_checks = regexp:/etc/postfix/body_checks
#
#       /etc/postfix/body_checks:
#           /^<iframe src=(3D)?cid:.* height=(3D)?0 width=(3D)?0>$/
#               REJECT IFRAME vulnerability exploit
#
#SEE ALSO
#      cleanup(8), canonicalize and enqueue Postfix message
#       pcre_table(5), format of PCRE lookup tables
#       regexp_table(5), format of POSIX regular expression tables
#       postconf(1), Postfix configuration utility
#       postmap(1), Postfix lookup table management
#       postsuper(1), Postfix janitor
#       postcat(1), show Postfix queue file contents
#       RFC 2045, base64 and quoted-printable encoding rules
#       RFC 2047, message header encoding for non-ASCII text
#
#README FILES
#       DATABASE_README, Postfix lookup table overview
#       CONTENT_INSPECTION_README, Postfix content inspection overview
#       BUILTIN_FILTER_README, Postfix built-in content inspection
#       BACKSCATTER_README, blocking returned forged mail
#
#LICENSE
#       The Secure Mailer license must be distributed with this software.
#
#AUTHOR(S)
#       Wietse Venema
#       IBM T.J. Watson Research
#       P.O. Box 704
#       Yorktown Heights, NY 10598, USA
#
#                                                            HEADER_CHECKS(5)
EOF
fi;

if [[ ! -e "${MAN}/transport.txt"  ]]; then
# install transport template
echo -e "Install transport manual...";
cat > ${MAN}/transport.txt << "EOF"
# TRANSPORT(5)                                                      TRANSPORT(5)
# 
# NAME
#        transport - Postfix transport table format
# 
# SYNOPSIS
#        postmap /etc/postfix/transport
# 
#        postmap -q "string" /etc/postfix/transport
# 
#        postmap -q - /etc/postfix/transport <inputfile
# 
# DESCRIPTION
#        The  optional  transport(5) table specifies a mapping from
#        email addresses to message delivery transports  and  next-
#        hop  destinations.   Message  delivery  transports such as
#        local or smtp are defined in the master.cf file, and next-
#        hop  destinations are typically hosts or domain names. The
#        table is searched by the trivial-rewrite(8) daemon.
# 
#        This  mapping  overrides  the  default   transport:nexthop
#        selection that is built into Postfix:
# 
#        local_transport (default: local:$myhostname)
#               This  is  the default for final delivery to domains
#               listed with mydestination, and for [ipaddress] des-
#               tinations    that    match    $inet_interfaces   or
#               $proxy_interfaces. The default nexthop  destination
#               is the MTA hostname.
# 
#        virtual_transport (default: virtual:)
#               This  is  the default for final delivery to domains
#               listed with  virtual_mailbox_domains.  The  default
#               nexthop destination is the recipient domain.
# 
#        relay_transport (default: relay:)
#               This  is the default for remote delivery to domains
#               listed with relay_domains. In order  of  decreasing
#               precedence,  the  nexthop destination is taken from
#               relay_transport,   sender_dependent_relayhost_maps,
#               relayhost, or from the recipient domain.
# 
#        default_transport (default: smtp:)
#               This  is  the  default for remote delivery to other
#               destinations.  In order of  decreasing  precedence,
#               the nexthop destination is taken from sender_depen-
#               dent_default_transport_maps,     default_transport,
#               sender_dependent_relayhost_maps, relayhost, or from
#               the recipient domain.
# 
#        Normally, the transport(5) table is specified  as  a  text
#        file  that serves as input to the postmap(1) command.  The
#        result, an indexed file in dbm or db format, is  used  for
#        fast  searching  by  the  mail system. Execute the command
#        "postmap /etc/postfix/transport"  to  rebuild  an  indexed
#        file after changing the corresponding transport table.
# 
#        When  the  table  is provided via other means such as NIS,
#        LDAP or SQL, the same lookups are  done  as  for  ordinary
#        indexed files.
# 
#        Alternatively,  the  table  can  be provided as a regular-
#        expression map where patterns are given as regular expres-
#        sions,  or lookups can be directed to TCP-based server. In
#        those case, the lookups are done in a  slightly  different
#        way  as  described below under "REGULAR EXPRESSION TABLES"
#        or "TCP-BASED TABLES".
# 
# CASE FOLDING
#        The search string is folded to lowercase  before  database
#        lookup.  As  of Postfix 2.3, the search string is not case
#        folded with database types such as regexp: or pcre:  whose
#        lookup fields can match both upper and lower case.
# 
# TABLE FORMAT
#        The input format for the postmap(1) command is as follows:
# 
#        pattern result
#               When  pattern  matches  the  recipient  address  or
#               domain, use the corresponding result.
# 
#        blank lines and comments
#               Empty  lines and whitespace-only lines are ignored,
#               as are lines whose first  non-whitespace  character
#               is a `#'.
# 
#        multi-line text
#               A  logical  line starts with non-whitespace text. A
#               line that starts with whitespace continues a  logi-
#               cal line.
# 
#        The  pattern specifies an email address, a domain name, or
#        a domain name hierarchy, as described  in  section  "TABLE
#        LOOKUP".
# 
#        The  result is of the form transport:nexthop and specifies
#        how or where to deliver mail. This is described in section
#        "RESULT FORMAT".
# 
# TABLE SEARCH ORDER
#        With lookups from indexed files such as DB or DBM, or from
#        networked tables such as NIS, LDAP or  SQL,  patterns  are
#        tried in the order as listed below:
# 
#        user+extension@domain transport:nexthop
#               Deliver   mail  for  user+extension@domain  through
#               transport to nexthop.
# 
#        user@domain transport:nexthop
#               Deliver mail for user@domain through  transport  to
#               nexthop.
# 
#        domain transport:nexthop
#               Deliver  mail  for domain through transport to nex-
#               thop.
# 
#        .domain transport:nexthop
#               Deliver mail for any subdomain  of  domain  through
#               transport  to  nexthop.  This applies only when the
#               string transport_maps is not  listed  in  the  par-
#               ent_domain_matches_subdomains   configuration  set-
#               ting.  Otherwise, a domain name matches itself  and
#               its subdomains.
# 
#        * transport:nexthop
#               The  special pattern * represents any address (i.e.
#               it functions  as  the  wild-card  pattern,  and  is
#               unique to Postfix transport tables).
# 
#        Note  1:  the  null  recipient  address  is  looked  up as
#        $empty_address_recipient@$myhostname (default: mailer-dae-
#        mon@hostname).
# 
#        Note  2:  user@domain  or  user+extension@domain lookup is
#        available in Postfix 2.0 and later.
# 
# RESULT FORMAT
#        The lookup result is of the form  transport:nexthop.   The
#        transport  field  specifies a mail delivery transport such
#        as smtp or local. The nexthop field  specifies  where  and
#        how to deliver mail.
# 
#        The  transport field specifies the name of a mail delivery
#        transport (the first name of a mail delivery service entry
#        in the Postfix master.cf file).
# 
#        The  interpretation  of  the  nexthop  field  is transport
#        dependent. In the case of SMTP, specify  a  service  on  a
#        non-default  port  as  host:service,  and disable MX (mail
#        exchanger) DNS lookups with [host] or [host]:port. The  []
#        form is required when you specify an IP address instead of
#        a hostname.
# 
#        A null transport and null nexthop  result  means  "do  not
#        change":  use  the delivery transport and nexthop informa-
#        tion that would be used when the  entire  transport  table
#        did not exist.
# 
#        A  non-null  transport  field  with  a  null nexthop field
#        resets the nexthop information to the recipient domain.
# 
#        A null transport field with non-null  nexthop  field  does
#        not modify the transport information.
# 
# EXAMPLES
#        In  order to deliver internal mail directly, while using a
#        mail relay for all other mail, specify a  null  entry  for
#        internal  destinations  (do not change the delivery trans-
#        port or the nexthop information) and  specify  a  wildcard
#        for all other destinations.
# 
#             my.domain    :
#             .my.domain   :
#             *            smtp:outbound-relay.my.domain
# 
#        In  order  to send mail for example.com and its subdomains
#        via the uucp transport to the UUCP host named example:
# 
#             example.com      uucp:example
#             .example.com     uucp:example
# 
#        When no nexthop host name is  specified,  the  destination
#        domain  name  is  used instead. For example, the following
#        directs mail for user@example.com via the  slow  transport
#        to  a  mail exchanger for example.com.  The slow transport
#        could be configured to run at most one delivery process at
#        a time:
# 
#             example.com      slow:
# 
#        When no transport is specified, Postfix uses the transport
#        that matches the address  domain  class  (see  DESCRIPTION
#        above).   The following sends all mail for example.com and
#        its subdomains to host gateway.example.com:
# 
#             example.com      :[gateway.example.com]
#             .example.com     :[gateway.example.com]
# 
#        In the above example, the [] suppress  MX  lookups.   This
#        prevents  mail  routing loops when your machine is primary
#        MX host for example.com.
# 
#        In the case of delivery via SMTP, one  may  specify  host-
#        name:service instead of just a host:
# 
#             example.com      smtp:bar.example:2025
# 
#        This directs mail for user@example.com to host bar.example
#        port 2025. Instead of a numerical port a symbolic name may
#        be used. Specify [] around the hostname if MX lookups must
#        be disabled.
# 
#        The error mailer can be used to bounce mail:
# 
#             .example.com     error:mail for *.example.com is not deliverable
# 
#        This causes all mail for user@anything.example.com  to  be
#        bounced.
# 
# REGULAR EXPRESSION TABLES
#        This  section  describes how the table lookups change when
#        the table is given in the form of regular expressions. For
#        a  description  of regular expression lookup table syntax,
#        see regexp_table(5) or pcre_table(5).
# 
#        Each pattern is a regular expression that  is  applied  to
#        the    entire    address    being    looked    up.   Thus,
#        some.domain.hierarchy is not  looked  up  via  its  parent
#        domains,  nor is user+foo@domain looked up as user@domain.
# 
#        Patterns are applied in the order as specified in the  ta-
#        ble,  until  a  pattern  is  found that matches the search
#        string.
# 
#        The trivial-rewrite(8) server disallows regular expression
#        substitution  of  $1  etc.  in  regular  expression lookup
#        tables, because that could open a security  hole  (Postfix
#        version 2.3 and later).
# 
# TCP-BASED TABLES
#        This  section  describes how the table lookups change when
#        lookups are directed to a TCP-based server. For a descrip-
#        tion of the TCP client/server lookup protocol, see tcp_ta-
#        ble(5).  This feature is not available up to and including
#        Postfix version 2.4.
# 
#        Each  lookup  operation  uses the entire recipient address
#        once.  Thus, some.domain.hierarchy is not  looked  up  via
#        its  parent  domains,  nor is user+foo@domain looked up as
#        user@domain.
# 
#        Results are the same as with indexed file lookups.
# 
# CONFIGURATION PARAMETERS
#        The following main.cf parameters are especially  relevant.
#        The  text  below  provides  only  a parameter summary. See
#        postconf(5) for more details including examples.
# 
#        empty_address_recipient
#               The address that is looked up instead of  the  null
#               sender address.
# 
#        parent_domain_matches_subdomains
#               List  of  Postfix features that use domain.tld pat-
#               terns  to  match  sub.domain.tld  (as  opposed   to
#               requiring .domain.tld patterns).
# 
#        transport_maps
#               List of transport lookup tables.
# 
# SEE ALSO
#        trivial-rewrite(8), rewrite and resolve addresses
#        master(5), master.cf file format
#        postconf(5), configuration parameters
#        postmap(1), Postfix lookup table manager
# 
# README FILES
#        Use  "postconf  readme_directory" or "postconf html_direc-
#        tory" to locate this information.
#        ADDRESS_REWRITING_README, address rewriting guide
#        DATABASE_README, Postfix lookup table overview
#        FILTER_README, external content filter
# 
# LICENSE
#        The Secure Mailer license must be  distributed  with  this
#        software.
# 
# AUTHOR(S)
#        Wietse Venema
#        IBM T.J. Watson Research
#        P.O. Box 704
#        Yorktown Heights, NY 10598, USA
# 
#                                                                   TRANSPORT(5)
EOF
fi;
if [[ -e "${POST}/access"  ]]; then mv -f ${POST}/access ${MAN}/access.txt; fi;

#End of mpman.sh