#!/bin/bash
#set -x
# mpreport.sh file mail gateway project for IPFire
#
# Contains logfile processing for postfix /var/log/mail files
# Last update 30.07.2023

# Variables
WDIR='/tmp';
LOGDIR='/var/log';
OUTDIR='/tmp';
LOGNR='0';
LOGNAME='mail';
LOGFILE='';
SUMFILE="${OUTDIR}/mpsummary.log";
TRFILE="${OUTDIR}/mptransport.log";
CFGTRPT='/var/ipfire/mailgateway/maps/transport'
CFGMAIN='/var/ipfire/mailgateway/main.conf'
TEMPFILE='/tmp/mail';
NOMSG='0';
ASTYLE='0';
TRN='1';
SUM='1';
ARG='';
ATIME=$(date);
LOGLINE="-----------------------------------------------------------------------------------------------------"
# read main.conf for mail server IP (MSIP) paramater
MSIP=$(cat "${CFGMAIN}" |grep MSIP |sed "s|MSIP=||;s|'||g");

# Cleaning before start
rm -f "${WDIR}/mail";
rm -f "${WDIR}/mail.?";

# Command line args test
analyze_args() {
 if [ "$ARG" = -quiet ]; then NOMSG='1'; fi;
 if [ "$ARG" = -as ]; then ASTYLE='1'; fi;
 if [ "$ARG" = -sum ]; then SUM='1'; TRN='0'; fi;
 if [ "$ARG" = -trn ]; then TRN='1'; SUM='0'; fi;
 value=$(echo ${ARG} | cut -c1-5);
 if [ "${value}" = '-log:' ]; then LOGNR=$(echo -n "${ARG}" |cut -c6-7); fi;
}

analyze_log() {

 if [ "${SUM}" = 1 ]; then
  printf '=====================================================================================================
=                                 Connection summary from mail logfile                              =
=====================================================================================================\n' > ${SUMFILE};

  echo "Report generated: $ATIME $LOGNAME.$LOGNR.gz" >> ${SUMFILE};

  printf '\nUndeliverable mails and sender verification fails:\n Time            | Address                    Relayhost\n%s\n' "${LOGLINE}" >> $SUMFILE;
  grep -iw "postfix/smtp" ${TEMPFILE} | grep "undeliverable" |sed 's/<//g;s/>//g;s/,//g;s/to=//g;s/relay=//g' |awk '{printf("%s \n"," "$1" "$2" "$3" | "$7 " - " $8)}' >> ${SUMFILE};

  printf '\nHelo command rejected:\n Time            | Address Server[IP] | HELO Name\n%s\n' "${LOGLINE}" >> $SUMFILE;
  grep -iw "NOQUEUE" ${TEMPFILE} |grep -v "unknown"| grep -e "Helo" |sed 's/<//g;s/>//g;s/>://g' |awk '{printf("%s \n"," "$1" "$2" "$3" | "$10" "$13 )}' >> ${SUMFILE};

  printf '\nRejected Connections RBL:\nNumber of connections | Server[IP] | Blocklist\n%s\n' "${LOGLINE}" >> $SUMFILE;
  grep -iw "RBLTRAP" ${TEMPFILE} |sed 's/\<unknown\>//g;s/\[//g;s/\]//g;s/://g' |awk '{printf("%s - %s\n",$10,$17)}' |sort|uniq -c|sort -nr|head -n20 >> ${SUMFILE};

  printf '\nRejected connections IPBL (service not available) top 20 list:\nNumber of connections | Host [IP]\n%s\n' "${LOGLINE}" >> $SUMFILE;
  grep -iw "NOQUEUE" ${TEMPFILE} |grep -e IPBL |sed 's/\://g' |awk '{printf("%s \n",$10 )}'|sort|uniq -c|sort -nr|head -n20  >> ${SUMFILE};

  printf '\nRejected connections TDLBL (service not available) top 20 list:\nNumber of connections | Host [IP]\n%s\n' "${LOGLINE}" >> $SUMFILE;
  grep -iw "NOQUEUE" ${TEMPFILE} |grep -e TLDBL |sed 's/\://g' |awk '{printf("%s \n",$10 )}'|sort|uniq -c|sort -nr|head -n20  >> ${SUMFILE};

  printf '\nRejected connections SDLBL (service not available) top 20 list:\nNumber of connections | Host [IP]\n%s\n' "${LOGLINE}" >> $SUMFILE;
  grep -iw "NOQUEUE" ${TEMPFILE} |grep -e SLDBL |sed 's/\://g' |awk '{printf("%s \n",$10 )}'|sort|uniq -c|sort -nr|head -n20  >> ${SUMFILE};

  printf '\nRejected unknown Connections (no reverse hostname) top 20 list:\nNumber of connections | IP\n%s\n' "${LOGLINE}" >> $SUMFILE;
  grep -iw "connect from unknown" ${TEMPFILE} |grep -ve reverse -ve CONNECT -e "\[unknown\]" |sed 's/\<unknown\>//g;s/\[//g;s/\]//g' |awk '{printf("%s \n", $8 )}' |sort |uniq -c |sort -nr |head -n20 >> ${SUMFILE};

  printf '\nInbound connections without internal top 20 list:\nNumber of connections | Host [IP]\n%s\n' "${LOGLINE}" >> $SUMFILE;
  grep -iw "connect from" ${TEMPFILE} |grep -v ${MSIP} |grep -ve NOQUEUE -ve localhost -ve lost -ve unknown |awk '{printf("%s \n", $8 )}' |sort |uniq -c |sort -nr |head -n20 >> ${SUMFILE};

  printf '\nInbound TLS connections without internal:\n Conn | TLS ver | Cipher\n%s\n' "${LOGLINE}" >> $SUMFILE;
  grep "TLS connection established from" ${TEMPFILE} |grep -v ${MSIP} |awk '{printf("%s\t| %s\n",$12, $15)}' |sort |uniq -c |sort -nr >> ${SUMFILE};

  printf '\nOutgoing TLS connections without internal:\n Conn | TLS ver | Cipher\n%s\n' "${LOGLINE}" >> $SUMFILE;
  grep "TLS connection established to" ${TEMPFILE} |grep -v "${MSIP}" |awk '{printf("%s\t| %s\n",$12, $15)}' |sort |uniq -c |sort -nr >> ${SUMFILE};

  printf '\n' >> $SUMFILE;
 fi;

 # Amavisd log lines evaluation
 if [ "$TRN" = 1 ]; then
  echo "=====================================================================================================" > $TRFILE;
  echo "=                                Transport summary from mail logfile                                =" >> $TRFILE;
  echo "=====================================================================================================" >> $TRFILE;
  echo "Report generated: $ATIME $LOGNAME.$LOGNR.gz" >> $TRFILE;
  echo " " >> $TRFILE;
  echo "Transferred mails list inbound:" >> $TRFILE;
  echo " Date   Time     | Address from / to" >> $TRFILE;
  echo ${LOGLINE} >> $TRFILE;
  grep -a amavis ${TEMPFILE} |grep -a RelayedInbound |sed s/\<\>/empty-sender/ |sed -e 's/>//g;s/<//g;s/,//g' |awk '{printf("%s \n"," "$1" " $2" "$3" | "$12" > " $14)}' >> ${TRFILE};
  echo ${LOGLINE} >> $TRFILE;
  echo " " >> $TRFILE;
  echo "Transferred mails list outgoing:" >> $TRFILE;
  echo " Date   Time     | Address from / to" >> $TRFILE;
  echo ${LOGLINE} >> $TRFILE;
  grep -a amavis ${TEMPFILE} |grep -a RelayedInternal |sed -e 's/>//g;s/<//g;s/,//g' |awk '{printf("%s \n"," "$1" " $2" "$3" | "$13" > " $15)}' >> ${TRFILE};
  grep -a amavis ${TEMPFILE} |grep -a RelayedOutbound |sed -e 's/>//g;s/<//g;s/,//g' |awk '{printf("%s \n"," "$1" " $2" "$3" | "$13" > " $15)}' >> ${TRFILE};
  echo ${LOGLINE} >> $TRFILE;
  echo " " >> $TRFILE;
  echo "Blocked sender addresses with regex phrases list:" >> $TRFILE;
  echo " Date   Time     | Rule | Address from / to" >> $TRFILE;
  echo ${LOGLINE} >> $TRFILE;
  grep -a SPBL ${TEMPFILE} |grep -v Client |sed -e 's/ NOQUEUE*.*SPBL//g;s/<//g;s/>//g;s/;//g;s/,//g;s/from=//g;s/to=//g' |awk '{printf("%s \n"," "$1" " $2" "$3" | "$6" | "$7" > " $8)}' >> ${TRFILE};
  echo ${LOGLINE} >> $TRFILE;
  echo " " >> $TRFILE;
  echo "Rejected connections with regex SPBL list top 20:" >> ${TRFILE};
  echo "Number of connections | Rule | Host [ IP ]" >> ${TRFILE};
  echo ${LOGLINE} >> $TRFILE;
  awk '/SPBL/ && /Client/{printf("%s \n",$18" "$13)}' ${TEMPFILE} |sed -e 's/<//g;s/>//g;s/;//g;s/,//g;s/\[/ \[/;s/\]:/\]/g' |sort |uniq -c |sort -nr >> ${TRFILE};
  echo ${LOGLINE} >> $TRFILE;
  echo " " >> $TRFILE;
  echo "Amavisd blocked SPAM:" >> $TRFILE;
  echo " Date   Time     | quarantine file      | Address from / to" >> $TRFILE;
  echo ${LOGLINE} >> ${TRFILE};
  grep -a amavis ${TEMPFILE} |grep -a "Blocked SPAM" |sed 's/<//g;s/>//g;s/,//g;s/MYNETS LOCAL /MYNETS-LOCAL /g' |awk '{printf("%s \n"," "$1" " $2" "$3 " | "$16" | "$12" > " $14)}'  >> ${TRFILE};
  echo ${LOGLINE} >> ${TRFILE};
  echo " " >> $TRFILE;
  echo "Amavisd banned incoming Microsoft Office files .doc .docm .xls .xlsm .ppt .pptx:" >> $TRFILE;
  echo " Date   Time     | quarantine file     | Address from / to" >> $TRFILE;
  echo ${LOGLINE} >> $TRFILE;
  grep -a amavis ${TEMPFILE} |grep -a 'Blocked BANNED' |grep '\.doc\|\.xls\|\.ppt\|\.docm\|\.xlsm' |grep -ve 'MYNETS LOCAL' |sed -e 's/ (application*.*)//g;s/>//g;s/<//g;s/,//g' |awk '{printf("%s \n"," "$1" "$2" "$3" | "$16" | "$12" > "$14)}' >> ${TRFILE};
  echo ${LOGLINE} >> $TRFILE;
  echo " " >> $TRFILE;
  echo "Amavisd banned outgoing Microsoft Office files .doc .docm .xls .xlsm .ppt .pptx:" >> $TRFILE;
  echo " Date   Time     | quarantine file     | Address from / to" >> $TRFILE;
  echo ${LOGLINE} >> $TRFILE;
  grep -a amavis ${TEMPFILE} |grep 'BANNED\|\.doc\|\.xls\|\.ppt\|\.docm\|\.xlsm' |grep "MYNETS LOCAL" |sed -e 's/ BANNED*.*LOCAL//g;s/>//g;s/<//g;s/,//g' |awk '{printf("%s \n"," "$1" "$2" "$3" | "$13" | "$9" > "$11)}' >> ${TRFILE};
  echo ${LOGLINE} >> $TRFILE;
  echo " " >> $TRFILE;
 fi;
}

# Command line evaluation
ARG=$1; analyze_args; ARG=$2; analyze_args; ARG=$3; analyze_args;
if [ ${LOGNR} -gt 31 ]; then LOGNR='0'; fi;

cd $WDIR;
if [ "${LOGNR}" = 0 ]; then 
  LOGFILE=${LOGDIR}/${LOGNAME};
  if [[ -e ${LOGFILE} ]]; then 
   cp ${LOGFILE} ${WDIR};
   chown nobody:nobody ${LOGFILE};
   analyze_log;
  else
   if [ "${SUM}" = 1 ]; then printf "Logfile not found: ${LOGFILE}\n" > ${SUMFILE}; fi;
   if [ "${TRN}" = 1 ]; then printf "Logfile not found: ${LOGFILE}\n" > ${TRFILE}; fi; 
  fi;
 fi;

if [ "${LOGNR}" != 0 ]; then
	LOGFILE="${LOGDIR}/${LOGNAME}.$LOGNR.gz";
	if [[ -e ${LOGFILE} ]]; then 
		gunzip -c ${LOGFILE} >${TEMPFILE};
		chown nobody:nobody ${TEMPFILE};
		analyze_log;
	else
		if [ "${SUM}" = 1 ]; then printf "Logfile not found: ${LOGFILE}\n" > ${SUMFILE}; fi;
		if [ "${TRN}" = 1 ]; then printf "Logfile not found: ${LOGFILE}\n" > ${TRFILE}; fi;
	fi;
fi;
rm -f ${TEMPFILE};
exit 0
