#!/bin/bash

############################################################
#                                                          #
# File: mpstart.sh                                         #
#                                                          #
# This is the main menu script for Mail Gateway on IPFire  #
#                                                          #
############################################################
# Build time: Mon Apr 22 09:59:32 AM CEST 2024

# Detect platform type 
PLATFORM=$(uname -m);

if [[ $PLATFORM == armv5tel || $PLATFORM == armv5tejl || $PLATFORM == armv6l || $PLATFORM == armv7l ]]; then
  echo -e "\033[91mInstallation only on Intel platforms. ARM based systems are not supported!\033[0m";
  unset PLATFORM;
  sleep 1;
  exit 1;
fi;

WORKDIR=${PWD};

#Initial file Check
if [[ ! -e $WORKDIR/mpconfig.sh  ]]; then echo "mpconfig.sh not found! quit installer!" exit; fi;
if [[ ! -e $WORKDIR/mpinstall.sh  ]]; then echo "mpinstall.sh not found! quit installer!" exit; fi; 
if [[ ! -e $WORKDIR/mpuninstall.sh  ]]; then echo "mpuninstall.sh not found! quit installer!" exit; fi; 
if [[ ! -e $WORKDIR/mptemplates.sh  ]]; then echo "mptemplates.sh not found! quit installer!" exit; fi;
if [[ ! -e $WORKDIR/mpup.sh  ]]; then echo "mpup.sh not found! quit installer!" exit; fi;
if [[ ! -e $WORKDIR/mpreport.sh  ]]; then echo "mpreport.sh not found! quit installer!" exit; fi;
if [[ ! -e $WORKDIR/mpman.sh  ]]; then echo "mpman.sh not found! quit installer!" exit; fi;

#Make scripts executable
chmod +x mpinstall.sh mpuninstall.sh mptemplates.sh mpconfig.sh mpwebif.sh mpman.sh mpcerts.sh mpfilter.sh;

service_stop() {
 echo -e "\033[32mStopping services for installation...\033[0m";
 if [ -e /var/spool/postfix/pid/master.pid ]; then /etc/init.d/postfix stop; fi;
 if [ -e /var/amavis/amavisd.sock ]; then /etc/init.d/amavisd stop; fi;
 pidof fetchmail
 if [ "${?}" = "0" ]; then
   /etc/init.d/fetchmail stop
 fi
};

service_start() {
 echo -e "\033[32mFinal starting services...\033[0m";
 if [ -e /etc/rc.d/init.d/amavisd ]; then /etc/init.d/amavisd start; fi;
 if [ -e /etc/rc.d/init.d/postfix ]; then /etc/init.d/postfix start; fi;
 if [ -e /etc/rc.d/init.d/fetchmail ]; then /etc/init.d/fetchmail start; fi;
};

remove_files(){
 rm -f mpconfig.sh mptemplates.sh mpinstall.sh mpuninstall.sh mplog.dat mpsum.dat mpcerts.sh mpfilter.sh mgconfig.cgi; 
 rm -f mptrn.dat mp_packages.tar mpman.sh mpwebif.sh initsripts.sh dh_2048.pem razor-agent.log mgquarantine.cgi;
 if [ -e mpreport.sh ]; then rm -f mpreport.sh mpup.sh; fi;
}

# Inital Text
clear;
echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
echo -e "\033[1;36m-            Welcome to the Mail Gateway (un)-installer for IPFire             -\033[0m";
echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
echo  " ";
echo -e "\033[97m This is Mail Gateway for filtering mails for a separate mailserver \033[0m";
echo -e "\033[97m in your intranet. IMAP or POP3 can be used with the fechtmail addon. \033[0m";
echo -e "\033[97m The gateway uses Postfix for transfering mails from the internet \033[0m";
echo -e "\033[97m to your mailsever. Amavisd and SpamAssassin is used for content filtering \033[0m";
echo -e "\033[97m and ClamAV for scanning mails for viruses.\033[0m";
echo;
echo -e "\033[1;32m Essential installation requirements:\033[0m";
echo -e " - An IPfire installation with minimum 1GB RAM an 5GB free disk space"; 
echo -e " - A static IP with valid DNS and reverse DNS record";
echo -e " - SDcard systems are nonsensical for full installation";
echo -e "   SDcard's are to slow to extract mails for checking!";
echo -e " - Connection to the internet to download the installation package";
echo;
echo -e "\033[1;32m Postfix configuration and file changes:\033[0m";
echo " The main.cf, master.cf, sender_access, smtpd_access, helo_access, transport,";
echo " esmtp_access, sld_access and tld_access will be actualized.";
echo " A backup of all original files are located under /etc/postfix/backup.";
echo " The postfix config template supports TLS with high grade encryption and DANE.";
echo " You can use this as an outbound Proxy to add TLS for the mail transport.";
echo " To use it, add an outgoing relay with the green IP of IPFire and Port 25.";
echo " ";
echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
echo " ";
read -p "To continue press [ENTER]"
clear;
echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
echo -e "\033[1;36m-            Welcome to the Mail Gateway (un)-installer for IPFire             -\033[0m";
echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
echo  " ";
echo -e "\033[1;32mAmavisd configuration changes:\033[0m"
echo "A new amavisd.conf file will be created. Amavisd blocks now:";
echo "- executables, and scripts (exe|vbs|pif|scr|cpl|bat|cmd|com)";
echo "- additional file types (ade|adp|app|bas|chm|cpl|crt|emf|fxp|grp|hlp|hta)";
echo "  (inf|ins|isp|js|jse|lnk|mda|mdb|mde|mdw|mdt|mdz|msc|msi|msp|mst)";
echo "  (ops|pcd|prg|reg|sct|shb|shs|vb|vbe|vbs|wmf|wsc|wsf|wsh)";
echo "- old archive types (arc|arj|zoo)";
echo "- WinZip vulnerab. Extensions (mim|b64|bhx|hqx|xxe|uu|uue)";
echo "- Microsoft Office files with macros (docm|dotm|xlsm|xltm|xlam|xlm|)";
echo "  (pptm|ppam|ppsm|sldm|potm|mam)";
echo "- certain double extensions in filenames";
echo " ";
echo "The quarantaine cutoff level was reduced to 10. (not all to quarantine)";
echo "Tnef Type, RTF Outlook 2003 winmail.dat is allowed";
echo "Possible SPAM and banned content is stored at /var/virusmails";
echo -e "\033[91mSPAM is rejected\033[0m";
echo
echo "This can be changed in /etc/amavisd.conf.";
echo " ";
echo -e "\033[33mThis program is free software: you can redistribute it and/or modify\033[0m";
echo -e "\033[33mit under the terms of the GNU General Public License as published by\033[0m";
echo -e "\033[33mthe Free Software Foundation, either version 3 of the License, or\033[0m";
echo -e "\033[33m(at your option) any later version.\033[0m";
echo " ";
echo -e "\033[33mThis package is distributed in the hope that it will be useful\033[0m";
echo -e "\033[33mbut WITHOUT ANY WARRANTY; without even the implied warranty of\033[0m";
echo -e "\033[33mMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.   See the\033[0m";
echo -e "\033[33mGNU General Public License for more details.\033[0m";
echo " ";
echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
echo " ";
read -p "To continue press [ENTER]";

while true
do
    clear;
    echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
    echo -e "\033[1;36m-             Welcome to the SMTP-Proxy (un)-installer for IPFire              -\033[0m";
    echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
    echo " ";
    echo -e "\033[32mPlease select your installation type\033[0m";
    echo "Press '1' for full setup";
    echo "Press '2' for postfix only setup";
    echo "Press '3' to reinstall web interface only and exit installer";
    echo " ";
    echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
    echo -n "Please select: ";
    read -n 1 installtype;
    case "$installtype" in
    1)
    break;
    ;;
    2)
    break;
    ;;
    3)
    echo "Will go to install web interface support now... "
    echo " ";
    ${WORKDIR}/mpwebif.sh 2>&1 | tee ${WORKDIR}/mpwebif.log;
    remove_files;
    exit 0;
    ;;
    *)
    echo " < Wrong selection! ";
    echo " ";
    sleep 1;
    ;;
  esac
done


#######################################
#        Main execution start         #
#######################################

echo " ";
service_stop;
echo " ";

#Sub menu full
while true
do
    clear;
    echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
    echo -e "\033[1;36m-            Welcome to the Mail Gateway (un)-installer for IPFire             -\033[0m";
    echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
    echo;
    if [ "$installtype" = "1" ]; then 
     echo -e "\033[92m Press '1' to install full (packages, templates and configure) \033[0m"
    else
     echo -e "\033[92m Press '1' to install postfix package and config templates \033[0m"
    fi
    if [ "$installtype" = "1" ]; then
     echo " Press '2' to install or update packages only"; 
    else
     echo " Press '2' to install or update Postfix only"; 
    fi;
    echo " Press '3' to install or update config templates";
    echo " Press '4' to configure domains and transport parameters";
    echo " Press '5' to install the web interface support (in development)";
    echo " Press '6' to generate TLS certificates";
    echo " Press '7' to uninstall all and quit installer";
    echo " Press 'q' to quit the installer and start services";
    echo;
    echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
    echo -n "Please select: ";
    read -n 1 answer;
    echo " ";
        case "$answer" in
            1)
            echo "Will go to install now all... ";
            echo;
	    if [[ $installtype = "1" ]]; then ${WORKDIR}/mpinstall.sh; fi;
	    if [[ $installtype = "2" ]]; then ${WORKDIR}/mpinstall.sh -opf; fi;
	    if [[ $installtype = "1" ]]; then ${WORKDIR}/mptemplates.sh; fi;
	    if [[ $installtype = "2" ]]; then ${WORKDIR}/mptemplates.sh -opf; fi;
	    if [[ $installtype = "1" ]]; then ${WORKDIR}/mpconfig.sh; fi;
	    if [[ $installtype = "2" ]]; then ${WORKDIR}/mpconfig.sh -opf; fi;
	    ${WORKDIR}/mpfilter.sh -opf;
	    ${WORKDIR}/mpcerts.sh;
            ${WORKDIR}/mpwebif.sh;
            ;;

            2)
            echo "Will go to install packages now... ";
            echo;
	    if [[ $installtype = "1" ]]; then ${WORKDIR}/mpinstall.sh; fi;
	    if [[ $installtype = "2" ]]; then ${WORKDIR}/mpinstall.sh -opf; fi;
            ;;
          
            3)
            echo "Will go to install the templates now... ";
            echo;
	    if [[ $installtype = "1" ]]; then ${WORKDIR}/mptemplates.sh; fi;
	    if [[ $installtype = "2" ]]; then ${WORKDIR}/mptemplates.sh -opf; fi;
	    ${WORKDIR}/mpfilter.sh -opf 2>&1 |tee ${WORKDIR}/mpfilter.log;
            #${WORKDIR}/mpman.sh
            ;;

            4)
            echo "Will go to configure the mailproxy now... ";
            echo;
	    if [[ $installtype = "1" ]]; then ${WORKDIR}/mpconfig.sh; fi;
	    if [[ $installtype = "2" ]]; then ${WORKDIR}/mpconfig.sh -opf; fi;
            ;;

            5)
            echo "Will go to install web interface support now... ";
            echo;
            ${WORKDIR}/mpwebif.sh 2>&1 | tee ${WORKDIR}/mpwebif.log;
            ;;

            6)
            echo "Will go to generate TLS certifactes... ";
            echo;
            ${WORKDIR}/mpcerts.sh;
            ;;

            7)
            echo "Will go to uninstall the mailproxy packages from IPFire now... ";
            echo "The installer will left also after uninstallation! Restart IPFire if needed.";
            echo "";
            ${WORKDIR}/mpuninstall.sh;
	    echo "";
	    echo -e "\033[92mAll software has been removed... )\033[0m";
            exit 0;
            ;;
            
            q)
            break;
            ;;

            *)
            echo " < Wrong selection! ";
            sleep 1;
            ;;
    esac
done;
echo " ";
service_start;
#/usr/sbin/clamd > /dev/tty12 < /dev/tty12 &
remove_files;

# move logfiles to subdir
LOGDIR="${WORKDIR}/mplogs_$(date +"%Y%m%d_%H%M%S")";
mkdir -p $LOGDIR;
mv -f ${WORKDIR}/*.log $LOGDIR;

## finish text
clear;
echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
echo " ";
echo -e "\033[92m All done! Your Mail Gateway is now ready! \033[0m";
echo -e "\033[92m The orginal config was backed up to /etc/postfix/backup\033[0m";
echo -e "\033[92m and the logfiles are saved to $LOGDIR\033[0m";
echo -e "\033[92m Attention: DNS-Servers with DNSSEC support must be used!\033[0m";
echo " ";
echo -e "\033[91m Don't forget the firewall configuration!  \033[0m";
echo -e "\033[32m In the OUTGOING firewall open the following ports:  \033[0m";
echo -e "\033[37m TCP 25   RED interface --> RED for postfix outgoing mail (SMTP) ";
echo -e "\033[37m TCP 2703 RED interface --> RED for razor2 antispam db checks \033[0m";
echo -e "\033[37m TCP all networks --> IP+PORT of your mail server \033[0m";
echo " ";
echo -e "\033[32m In the INCOMING firewall open the following ports:\033[0m";
echo -e "\033[37m TCP 25   RED --> RED interface for postfix incoming mail (SMTP) ";
echo " ";
echo -e "\033[32m If your mail server is in an different IPFire zone, \033[0m"
echo -e "\033[32m give him a appropriate FORWARD rule in the firewall... \033[0m"
if [ -f /etc/fetchmailrc ]; then 
 echo " ";
 echo -e "\033[32m In the OUTGOING firewall is additionally needed for fetchmail:  \033[0m";
 echo -e "\033[37m TCP 578  RED interface --> RED for postfix outgoing mail (SMTPS) \033[0m";
 echo -e "\033[37m TCP 110  RED interface --> RED fetchmail (POP3) \033[0m"
 echo -e "\033[37m TCP 995  RED interface --> RED fetchmail (POP3S) \033[0m"
 echo " ";
 echo -e "\033[32m Please fill the /etc/fetchmailrc with your mail account data \033[0m";
 echo -e "\033[32m and restart the service: 'service fetchmail restart'. \033[0m";
fi;
echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
echo " ";
echo -e "\033[91m Create aliases for 'virusalert@mydomain.com' and 'abuse@mydomain.com \033[0m";
echo -e "\033[37m at your mailserver. This is needed for Amsvisd status mails. \033[0m";
echo -e "\033[37m Info: mydomain.com is only a placeholder for your external maildomain. \033[0m";
echo " ";
echo -e  "\033[92m Additional tools are permanent available: \033[0m";
echo -en "\033[97m mpup\033[0m";
echo -e  "\033[37m for generating/updating postfix db files (postmap) \033[0m";
echo -en "\033[97m mpconfig.sh\033[0m";
echo -e  "\033[37m for changing postfix transport configuration \033[0m";
echo " ";
echo -e  "\033[32m Please wait 15 min on fresh ClamAV installation and \033[0m";
echo -e  "\033[392m start the service manally. Freshclam need time to download databases. \033[0m";
echo -e  " Command: \033[93m service clamav start \033[0m";
echo " ";
echo -e  "\033[32m This Mailgateway has now a web interface. Please use it for configuration.\033[0m";
echo " ";
echo -e "\033[1;36m---------------------------------------------------------------- 2022 gocart --\033[0m";
echo " ";
unset LOGDIR WORKDIR;
#End of mpstart.sh file
