#!/bin/bash
############################################################
#                                                          #
# File: mptemplates.sh                                     #
#                                                          #
# This script installing Mail Gateway templates on IPFire  #
#                                                          #
############################################################
# Build time: Mon Apr 22 09:59:32 AM CEST 2024

# Command line args test
NOMSG="0";
ONLYPF="0";
WORKDIR=${PWD};
for arg; do
  if [ $arg = "-quiet" ]; then NOMSG="1"; fi;
  if [ $arg = "-opf" ]; then ONLYPF="1"; fi;
done

echo $ONLYPF

# Vars
CONFIGDIR="/etc/postfix";
MAPSDIR="${CONFIGDIR}/maps";

LOG="$WORKDIR/installer.log"
DATE=$(date +%Y-%m-%d-%H%M%S)
BCKCONFIGDIR="${CONFIGDIR}/backup"
MAIN="${CONFIGDIR}/main.cf";
TCONF="${MAPSDIR}/transport";
VIRT="${MAPSDIR}/virtual";
ACONF="/etc/amavisd.conf";

MAPSFILES=(
 'aliases'
 'generic'
 'sasl_passwd'
 'sender_access'
 'sld_access'
 'tld_access'
 'tld_new_access'
 'transport'
 'virtual'
 'relay_domains'
)

CONFIGFILES=(
 'master.cf'
 'main.cf'
 'helo.cf'
 'ptr.cf'
 'bounce.cf'
 'network_table'
 'spamphrases-white.pcre'
 'spamphrases-block.pcre'
 'batv.regexp'
 'body_checks.pcre'
 'header_checks.pcre'
 'mime_header_checks.pcre'
 'esmtp_access'
)

write_master_cf() {
# Install master.cf new version with smtpd_proxy_filter setup
echo -en "Install master.cf template now: ";
cat > ${CONFIGDIR}/master.cf << "EOF"
#
# Postfix master process configuration file.  For details on the format
# of the file, see the Postfix master(5) manual page.
#
# ==========================================================================
# service type  private unpriv  chroot  wakeup  maxproc command + args
#               (yes)   (yes)   (yes)   (never) (100)
# ==========================================================================
smtp      inet  n       -       n       -       -       smtpd
#smtp     inet  n       -       n       -       1       postscreen
#smtpd    pass  -       -       n       -       -       smtpd
#dnsblog  unix  -       -       n       -       0       dnsblog
#tlsproxy unix  -       -       n       -       0       tlsproxy
smtps     inet  n       -       n       -       -       smtpd
   -o syslog_name=postfix/smtps
   -o smtpd_tls_wrappermode=yes
   -o smtpd_sasl_auth_enable=yes
   -o smtpd_relay_restrictions=permit_mynetworks,permit_sasl_authenticated,reject
   -o smtpd_recipient_restrictions=permit_mynetworks,permit_sasl_authenticated,reject
# Choose one: enable submission for loopback clients only, or for any client.
#127.0.0.1:submission inet n -   n       -       -       smtpd
submission inet  n       -       -       -       -       smtpd
   -o syslog_name=postfix/submission
   -o smtpd_tls_security_level=encrypt
   -o smtpd_sasl_security_options=noanonymous
   -o smtpd_sasl_auth_enable=yes
   -o smtpd_tls_auth_only=yes
   -o smtpd_helo_required=no
   -o smtpd_helo_restrictions=
   -o smtpd_client_restrictions=permit_sasl_authenticated,reject
   -o milter_macro_daemon_name=ORIGINATING
#628      inet  n       -       n       -       -       qmqpd
pickup    fifo  n       -       n       60      1       pickup
cleanup   unix  n       -       n       -       0       cleanup
   -o canonical_classes=envelope_recipient,header_recipient
   -o canonical_maps=regexp:/etc/postfix/batv.regexp
qmgr      fifo  n       -       n       300     1       qmgr
#qmgr     fifo  n       -       n       300     1       oqmgr
tlsmgr    unix  -       -       n       1000?   1       tlsmgr
rewrite   unix  -       -       n       -       -       trivial-rewrite
bounce    unix  -       -       n       -       0       bounce
defer     unix  -       -       n       -       0       bounce
trace     unix  -       -       n       -       0       bounce
verify    unix  -       -       n       -       1       verify
flush     unix  n       -       n       1000?   0       flush
proxymap  unix  -       -       n       -       -       proxymap
smtp      unix  -       -       n       -       -       smtp
# When relaying mail as backup MX, disable fallback_relay to avoid MX loops
relay     unix  -       -       n       -       -       smtp
        -o fallback_relay=
#       -o smtp_helo_timeout=5 -o smtp_connect_timeout=5
showq     unix  n       -       n       -       -       showq
error     unix  -       -       n       -       -       error
retry     unix  -       -       n       -       -       error
discard   unix  -       -       n       -       -       discard
local     unix  -       n       n       -       -       local
virtual   unix  -       n       n       -       -       virtual
lmtp      unix  -       -       n       -       -       lmtp
anvil     unix  -       -       n       -       1       anvil
scache	  unix	-	-	n	-	1	scache
postlog   unix-dgram n  -       n       -       1       postlogd
#
# ====================================================================
# Interfaces to non-Postfix software. Be sure to examine the manual
# pages of the non-Postfix software to find out what options it wants.
#
# Many of the following services use the Postfix pipe(8) delivery
# agent.  See the pipe(8) man page for information about ${recipient}
# and other message envelope options.
# ====================================================================
#
# Amavis remote transport recive connector
amavis    unix  -       -       n       -        2      smtp
    -o smtp_send_xforward_command=yes
    -o disable_mime_output_conversion=yes
    -o smtp_generic_maps=
    -o smtp_dns_support_level=disabled

# Amavis local transport recive connector
amavislt  unix  -       -       n       -        2      lmtp
    -o lmtp_data_done_timeout=1200
    -o lmtp_send_xforward_command=yes
    -o lmtp_dns_support_level=disabled
    -o lmtp_tls_note_starttls_offer=no
    -o max_use=20

127.0.0.1:10025 inet n  -       n       -       -       smtpd
    -o content_filter=
    -o local_recipient_maps=
    -o relay_recipient_maps=
    -o local_header_rewrite_clients=
    -o mynetworks=127.0.0.0/8
    -o strict_rfc821_envelopes=yes
    -o smtpd_delay_reject=no
    -o smtpd_restriction_classes=
    -o smtpd_client_restrictions=
    -o smtpd_helo_restrictions=
    -o smtpd_sender_restrictions=
    -o smtpd_end_of_data_restrictions=
    -o receive_override_options=no_unknown_recipient_checks,no_header_body_checks,no_milters,no_address_mappings
    -o smtpd_recipient_restrictions=permit_mynetworks,reject
    -o smtpd_milters=
    -o smtpd_error_sleep_time=0
    -o smtpd_soft_error_limit=1001
    -o smtpd_hard_error_limit=1000
    -o smtpd_authorized_xforward_hosts=127.0.0.0/8
    -o smtpd_tls_security_level=none
    -o smtpd_error_sleep_time=0
EOF
echo -e "\033[92mdone...\033[0m";
}

write_main_cf_all_filters() {
# Install main.cf all filers template
echo -en "Install main.cf and all active templates now :";
cat > ${CONFIGDIR}/main.cf << "EOF"
# postfix 3.6 main.cf

# Config directory settings
conf_dir = /etc/postfix
cert_dir = /var/ipfire/mailgateway/cert
maps_dir = $conf_dir/maps

# Postfix commom settings
meta_directory = ${conf_dir}
queue_directory = /var/spool/postfix
command_directory = /usr/sbin
daemon_directory = /usr/lib/postfix
data_directory = /var/lib/postfix
manpage_directory = /usr/share/man
sample_directory = ${conf_dir}
html_directory = no
readme_directory = no
shlib_directory = no
sendmail_path = /usr/sbin/sendmail
newaliases_path = /usr/bin/newaliases
mailq_path = /usr/bin/mailq
mail_owner = postfix
setgid_group = postdrop
bounce_template_file = ${conf_dir}/bounce.de-DE.cf
compatibility_level = 2
smtputf8_enable = yes
append_dot_mydomain = no
broken_sasl_auth_clients = no
recipient_delimiter = +
strict_rfc821_envelopes = yes

# banner settings
smtpd_banner = $myhostname ESMTP $mail_name
default_rbl_reply = $rbl_code RBLTRAP: $client blocked using $rbl_domain Reason: $rbl_reason 
unverified_recipient_reject_reason = Recipient address lookup failed

# disable local transport for relay mode
mydestination =
local_recipient_maps =
local_transport = error:local mail delivery is disabled
mailbox_size_limit = 0

# Enable test mode set to yes
soft_bounce = no

# Network settings
inet_interfaces = all
inet_protocols = ipv4

# DNS support level: disabled / enabled / dnssec
smtp_dns_support_level = dnssec

# Max Mailsize 32MB
message_size_limit = 33554432

# Amavisd connector
content_filter = amavislt:[127.0.0.1]:10024

# Milter setup (rspamd)
# via ip port
#smtpd_milters = inet:127.0.0.1:11332
# via unix socket
#smtpd_milters = unix:/var/run/rspamd-proxy.sock
#non_smtpd_milters = $smtpd_milters
smtpd_milters =
non_smtpd_milters =
milter_mail_macros = i {mail_addr} {client_addr} {client_name} {auth_type} {auth_authen}
milter_protocol = 6
# if milter is down, don't reject mail
milter_default_action = accept

# Own mail domain and internal mail server
mydomain =
myorigin = $mydomain
myhostname =
mynetworks = cidr:/var/ipfire/mailgateway/maps/network_table
relay_domains = lmdb:/var/ipfire/mailgateway/maps/relay_domains

# Outbound relay host if needed
smtp_sasl_auth_enable = no
smtp_sasl_security_options = noanonymous
smtp_sasl_password_maps = 
relayhost = 

# Content checks and transport lists
alias_maps = lmdb:${maps_dir}/aliases
alias_database = lmdb:${maps_dir}/aliases
virtual_alias_maps = lmdb:${maps_dir}/virtual
transport_maps = lmdb:${maps_dir}/transport
body_checks = pcre:${conf_dir}/body_checks.pcre
header_checks = pcre:${conf_dir}/header_checks.pcre
mime_header_checks = pcre:${conf_dir}/mime_header_checks.pcre
address_verify_map = lmdb:/var/spool/postfix/data/verify
smtpd_discard_ehlo_keyword_address_maps = cidr:${conf_dir}/esmtp_access

# Reject codes
reject_code = 554
access_map_reject_code = 554
invalid_hostname_reject_code = 501
multi_recipient_bounce_reject_code = 550
maps_rbl_reject_code = 550
non_fqdn_reject_code = 504
plaintext_reject_code = 550
relay_domains_reject_code = 554
unknown_address_reject_code = 550
unknown_client_reject_code = 550
unknown_hostname_reject_code = 550
unknown_local_recipient_reject_code = 550
unknown_relay_recipient_reject_code = 550
unknown_virtual_alias_reject_code = 550
unknown_virtual_mailbox_reject_code = 550
unverified_recipient_reject_code = 550
unverified_sender_reject_code = 550

# Timeouts 
smtp_mail_timeout = 60s
smtp_helo_timeout = 30s
smtp_rcpt_timeout = 60s
smtp_rset_timeout = 10s
smtp_quit_timeout = 60s
smtp_data_xfer_timeout = 60s
smtp_data_done_timeout = 300s
smtp_starttls_timeout = 60s

# Message lifetimes
bounce_queue_lifetime = 2h
maximal_queue_lifetime = 4h
delay_warning_time = 30m

# Connection limits
smtpd_client_connection_count_limit = 20
smtpd_client_message_rate_limit = 20
smtpd_client_recipient_rate_limit = 20

# Setup basic SMTP attrs
smtpd_soft_error_limit = 2
smtpd_error_sleep_time = ${stress?0}${stress:10s}
smtpd_hard_error_limit = ${stress?3}${stress:20}
smtpd_recipient_limit = 100
smtpd_timeout = ${stress?30}${stress:300}
smtpd_delay_reject = no
smtpd_helo_required = yes
smtpd_forbid_unauth_pipelining = yes

# TLS Paramaters
tls_preempt_cipherlist = yes
tls_high_cipherlist = AESGCM+EECDH:CHACHA20+EECDH:DHE-RSA-AES256-GCM-SHA384:@STRENGTH:+aRSA

# TLS inbound settings
# Security level: none / may (default) / encrypt
smtpd_tls_security_level = may
smtpd_tls_loglevel = 1
smtpd_tls_ciphers = high
smtpd_tls_eecdh_grade = auto
smtpd_tls_auth_only=yes
smtpd_tls_received_header = yes
smtpd_tls_protocols = !SSLv2, !SSLv3
smtpd_tls_mandatory_ciphers = high
smtpd_tls_mandatory_protocols = !SSLv2, !SSLv3, !TLSv1, !TLSv1.1
smtpd_tls_mandatory_exclude_ciphers = MD5, DES, ADH, RC4, PSD, SRP, 3DES, eNULL, aNULL
smtpd_tls_exclude_ciphers = MD5, DES, ADH, RC4, PSD, SRP, 3DES, eNULL, aNULL
smtpd_tls_session_cache_database = lmdb:${data_directory}/smtpd_scache
smtpd_tls_CAfile = /etc/ssl/certs/ca-bundle.trust.crt
smtpd_tls_cert_file = ${cert_dir}/postfix-rsa.crt
smtpd_tls_key_file = ${cert_dir}/postfix-rsa.key
smtpd_tls_eccert_file = ${cert_dir}/postfix-ecc.crt
smtpd_tls_eckey_file =  ${cert_dir}/postfix-ecc.key
smtpd_tls_dh1024_param_file = ${cert_dir}/dh2048.pem
smtpd_tls_dh512_param_file=
smtpd_starttls_timeout = 60s

# TLS outgoing settings
# Security Level none / may / encrypt / dane / dane-only / fingerprint / verify / secure
smtp_tls_note_starttls_offer = yes
smtp_tls_security_level = dane
smtp_tls_loglevel = 1
smtp_tls_protocols = !SSLv2, !SSLv3
smtp_tls_mandatory_ciphers  = high
smtp_tls_mandatory_protocols =  !SSLv2, !SSLv3, !TLSv1, !TLSv1.1
smtp_tls_mandatory_exclude_ciphers = MD5, DES, ADH, RC4, PSD, SRP, 3DES, eNULL, aNULL
smtp_tls_exclude_ciphers = MD5, DES, ADH, RC4, PSD, SRP, 3DES, eNULL, aNULL
smtp_tls_session_cache_database = lmdb:${data_directory}/smtp_scache
smtp_tls_verify_cert_match = hostname, nexthop, dot-nexthop
smtp_tls_cert_file = ${cert_dir}/postfix-rsa.crt
smtp_tls_key_file = ${cert_dir}/postfix-rsa.key
smtp_tls_eccert_file = ${cert_dir}/postfix-ecc.crt
smtp_tls_eckey_file = ${cert_dir}/postfix-ecc.key

# LMTP Settings
lmtp_tls_protocols = !SSLv2, !SSLv3
lmtp_tls_mandatory_protocols = !SSLv2, !SSLv3

# Security setting against SMTP Smuggling
smtpd_forbid_unauth_pipelining = yes
smtpd_forbid_bare_newline = yes
smtpd_forbid_bare_newline_exclusions = $mynetworks

# Transport Restictions
smtpd_client_restrictions =
	permit_mynetworks,
	reject_unknown_client_hostname,
	reject_unknown_reverse_client_hostname,
	check_client_access lmdb:${maps_dir}/smtpd_access,
	check_client_access lmdb:${maps_dir}/sld_access,
	check_client_access lmdb:${maps_dir}/tld_access,
	check_client_access lmdb:${maps_dir}/tld_new_access,
	check_client_access pcre:${conf_dir}/spamphrases-white.pcre,
	check_client_access pcre:${conf_dir}/spamphrases-block.pcre,
	regexp:${conf_dir}/ptr.cf,
	reject_rbl_client zen.spamhaus.org=127.0.0.[2..11],
	reject_rbl_client bl.mailspike.net,
	reject_rbl_client ix.dnsbl.manitu.net,
	reject_multi_recipient_bounce,
	sleep 1,
	reject_unauth_pipelining

smtpd_helo_restrictions =
	reject_unauth_pipelining,
	reject_invalid_helo_hostname,
	permit_mynetworks,
	reject_non_fqdn_helo_hostname,
	reject_unknown_helo_hostname,
	check_helo_access lmdb:${maps_dir}/helo_access,
	check_helo_access lmdb:${maps_dir}/sld_access,
	check_helo_access lmdb:${maps_dir}/tld_access,
	check_helo_access lmdb:${maps_dir}/tld_new_access,
	regexp:/etc/postfix/helo.cf

smtpd_sender_restrictions =
	reject_non_fqdn_sender,
	reject_unknown_sender_domain,
	permit_mynetworks,
	check_sender_access lmdb:${maps_dir}/sender_access,
	check_sender_access lmdb:${maps_dir}/sld_access,
	check_sender_access lmdb:${maps_dir}/tld_access,
	check_sender_access lmdb:${maps_dir}/tld_new_access,
	check_sender_access pcre:${conf_dir}/spamphrases-white.pcre,
	check_sender_access pcre:${conf_dir}/spamphrases-block.pcre,
	# activate sender address verification (care, blocks autoresponder and other addresses)
	# add the needed addresses to the whitelist (sender_access)
	#reject_unverified_sender

smtpd_recipient_restrictions =
	reject_non_fqdn_recipient,
	permit_mynetworks,
	reject_unknown_recipient_domain,
	reject_unauth_destination,
	# activate recipient address verification
	# cheks the internal mailserver of valid addresses
	# postfix rejects mail itself if the recipient not exist
	reject_unverified_recipient

smtpd_relay_restrictions = 
	#check_recipient_access hash:${conf_dir}/access, 
	reject_non_fqdn_sender, 
	reject_unknown_sender_domain,
	permit_sasl_authenticated, 
	permit_mynetworks, 
	reject_unauth_destination, 
	reject_non_fqdn_helo_hostname, 
	reject_invalid_helo_hostname

smtpd_data_restrictions =
	permit_sasl_authenticated,
	permit_mynetworks,
	reject_unauth_pipelining

smtpd_discard_ehlo_keywords =
	chunking,
	silent-discard

smtpd_end_of_data_restrictions =
        permit_sasl_authenticated,
        permit_mynetworks
EOF
echo -e "\033[92mdone...\033[0m";
}

write_amavisd_conf_template() {
echo -en "Install amavisd.conf template now: ";
cat > $ACONF << "EOF"
use strict;

# a minimalistic configuration file for amavisd-new with all necessary settings
#
#   see amavisd.conf-default for a list of all variables with their defaults;
#   for more details see documentation in INSTALL, README_FILES/*
#   and at http://www.ijs.si/software/amavisd/amavisd-new-docs.html


# COMMONLY ADJUSTED SETTINGS:

# @bypass_virus_checks_maps = (1);  # controls running of anti-virus code
# @bypass_spam_checks_maps  = (1);  # controls running of anti-spam code
# $bypass_decode_parts = 1;         # controls running of decoders&dearchivers

$max_servers = 2;             # num of pre-forked children (2..30 is common), -m
$daemon_user  = 'amavis';     # (no default;  customary: vscan or amavis), -u
$daemon_group = 'amavis';     # (no default;  customary: vscan or amavis), -g

$mydomain     = 'mydomain.com';       # a convenient default for other settings
$myhostname   = 'mail.mydomain.com';  # must be a fully-qualified domain name!

@local_domains_maps = ( ".$mydomain" );  # list of all local domains

@mynetworks   = qw( 127.0.0.0/8 192.168.0.0/16 10.0.0.0/8 );
@inet_acl     = qw( 127.0.0.1 );
$inet_socket_bind = '127.0.0.1'; # bind only on localhost

# $MYHOME = '/var/amavis';   # a convenient default for other settings, -H
$TEMPBASE = "$MYHOME/tmp";   # working directory, needs to exist, -T
$ENV{TMPDIR} = $TEMPBASE;    # environment variable TMPDIR, used by SA, etc.
$QUARANTINEDIR = '/var/virusmails';  # -Q
# $quarantine_subdir_levels = 1;  # add level of subdirs to disperse quarantine
# $release_format = 'resend';     # 'attach', 'plain', 'resend'
# $report_format  = 'arf';        # 'attach', 'plain', 'resend', 'arf'

# $daemon_chroot_dir = $MYHOME;   # chroot directory or undef, -R

# $db_home   = "$MYHOME/db";      # dir for bdb nanny/cache/snmp databases, -D
# $helpers_home = "$MYHOME/var";  # working directory for SpamAssassin, -S
# $lock_file = "$MYHOME/var/amavisd.lock";  # -L
# $pid_file  = "$MYHOME/var/amavisd.pid";   # -P
#NOTE: create directories $MYHOME/tmp, $MYHOME/var, $MYHOME/db manually

$log_level = 1;              # verbosity 0..5, -d
$log_recip_templ = undef;    # disable by-recipient level-0 log entries
$do_syslog = 1;              # log via syslogd (preferred)
$syslog_facility = 'mail';   # Syslog facility as a string
           # e.g.: mail, daemon, user, local0, ... local7

$enable_db  = 1;             # enable use of BerkeleyDB/libdb (SNMP and nanny)
$enable_zmq = 1;             # enable use of ZeroMQ (SNMP and nanny)
$nanny_details_level = 2;    # nanny verbosity: 1: traditional, 2: detailed
$enable_dkim_verification = 0;  # enable DKIM signatures verification
$enable_dkim_signing = 0;    # load DKIM signing code, keys defined by dkim_key

$unix_socketname = "$MYHOME/amavisd.sock";  # amavisd-release or amavis-milter
               # option(s) -p overrides $inet_socket_port and $unix_socketname

$inet_socket_port = 10024;   # listen on this local TCP port(s)
# $inet_socket_port = [10024,10026];  # listen on multiple TCP ports

$policy_bank{'MYNETS'} = {   # mail originating from @mynetworks
  originating => 1,  # is true in MYNETS by default, but let's make it explicit
  os_fingerprint_method => undef,  # don't query p0f for internal clients
};

# it is up to MTA to re-route mail from authenticated roaming users or
# from internal hosts to a dedicated TCP port (such as 10026) for filtering
$interface_policy{'10026'} = 'ORIGINATING';

$policy_bank{'ORIGINATING'} = {  # mail supposedly originating from our users
  originating => 1,  # declare that mail was submitted by our smtp client
  allow_disclaimers => 1,  # enables disclaimer insertion if available
  # notify administrator of locally originating malware
  virus_admin_maps => ["virusalert\@$mydomain"],
  spam_admin_maps  => ["virusalert\@$mydomain"],
  warnbadhsender   => 1,
  # forward to a smtpd service providing DKIM signing service
  forward_method => 'smtp:[127.0.0.1]:10027',
  # force MTA conversion to 7-bit (e.g. before DKIM signing)
  smtpd_discard_ehlo_keywords => ['8BITMIME'],
  bypass_banned_checks_maps => [1],  # allow sending any file names and types
  terminate_dsn_on_notify_success => 0,  # don't remove NOTIFY=SUCCESS option
};

$interface_policy{'SOCK'} = 'AM.PDP-SOCK'; # only applies with $unix_socketname

# Use with amavis-release over a socket or with Petr Rehor's amavis-milter.c
# (with amavis-milter.c from this package or old amavis.c client use 'AM.CL'):
$policy_bank{'AM.PDP-SOCK'} = {
  protocol => 'AM.PDP',
  auth_required_release => 0,  # do not require secret_id for amavisd-release
};

$sa_tag_level_deflt  = 2.0;  # add spam info headers if at, or above that level
$sa_tag2_level_deflt = 5.8;  # add 'spam detected' headers at that level
$sa_kill_level_deflt = 6.3;  # triggers spam evasive actions (e.g. blocks mail)
$sa_dsn_cutoff_level = 10;   # spam level beyond which a DSN is not sent
$sa_crediblefrom_dsn_cutoff_level = 15; # likewise, but for a likely valid From
$sa_quarantine_cutoff_level = 20; # spam level beyond which quarantine is off
$penpals_bonus_score = 8;    # (no effect without a @storage_sql_dsn database)
$penpals_threshold_high = $sa_kill_level_deflt;  # don't waste time on hi spam
$bounce_killer_score = 100;  # spam score points to add for joe-jobbed bounces

$sa_mail_body_size_limit = 400*1024; # don't waste time on SA if mail is larger
$sa_local_tests_only = 0;    # only tests which do not require internet access?

# @lookup_sql_dsn =
#   ( ['DBI:mysql:database=mail;host=127.0.0.1;port=3306', 'user1', 'passwd1'],
#     ['DBI:mysql:database=mail;host=host2', 'username2', 'password2'],
#     ["DBI:SQLite:dbname=$MYHOME/sql/mail_prefs.sqlite", '', ''] );
# @storage_sql_dsn = @lookup_sql_dsn;  # none, same, or separate database
# @storage_redis_dsn = ( {server=>'127.0.0.1:6379', db_id=>1} );
# $redis_logging_key = 'amavis-log';
# $redis_logging_queue_size_limit = 300000;  # about 250 MB / 100000

# $timestamp_fmt_mysql = 1; # if using MySQL *and* msgs.time_iso is TIMESTAMP;
#   defaults to 0, which is good for non-MySQL or if msgs.time_iso is CHAR(16)

$virus_admin               = "virusalert\@$mydomain";  # notifications recip.
$spam_admin		   = "virusalert\@$mydomain";  # notifications spamadmin

$mailfrom_notify_admin     = "virusalert\@$mydomain";  # notifications sender
$mailfrom_notify_recip     = "virusalert\@$mydomain";  # notifications sender
$mailfrom_notify_spamadmin = "spam.police\@$mydomain"; # notifications sender
#$mailfrom_notify_spamadmin = "virusalert\@$mydomain"; 
$mailfrom_to_quarantine = ''; # null return path; uses original sender if undef

@addr_extension_virus_maps      = ('virus');
@addr_extension_banned_maps     = ('banned');
@addr_extension_spam_maps       = ('spam');
@addr_extension_bad_header_maps = ('badh');
# $recipient_delimiter = '+';  # undef disables address extensions altogether
# when enabling addr extensions do also Postfix/main.cf: recipient_delimiter=+

$path = '/usr/local/sbin:/usr/local/bin:/usr/sbin:/sbin:/usr/bin:/bin';
# $dspam = 'dspam';

$MAXLEVELS = 14;
$MAXFILES = 3000;
$MIN_EXPANSION_QUOTA =      100*1024;  # bytes  (default undef, not enforced)
$MAX_EXPANSION_QUOTA = 500*1024*1024;  # bytes  (default undef, not enforced)

$sa_spam_subject_tag = '***Spam*** ';
$defang_virus  = 1;  # MIME-wrap passed infected mail
$defang_banned = 1;  # MIME-wrap passed mail containing banned name
# for defanging bad headers only turn on certain minor contents categories:
$defang_by_ccat{CC_BADH.",3"} = 1;  # NUL or CR character in header
$defang_by_ccat{CC_BADH.",5"} = 1;  # header line longer than 998 characters
$defang_by_ccat{CC_BADH.",6"} = 1;  # header field syntax error

# OTHER MORE COMMON SETTINGS (defaults may suffice):

# $notify_method  = 'smtp:[127.0.0.1]:10025';
# $forward_method = 'smtp:[127.0.0.1]:10025';  # set to undef with milter!

$final_virus_destiny      = D_DISCARD;
$final_banned_destiny     = D_DISCARD;
$final_spam_destiny       = D_DISCARD;  #!!!  D_DISCARD / D_REJECT
$final_bad_header_destiny = D_PASS;
# $bad_header_quarantine_method = undef;

# $os_fingerprint_method = 'p0f:127.0.0.1:10030';  # to query p0f-analyzer.pl

## hierarchy by which a final setting is chosen:
##   policy bank (based on port or IP address) -> *_by_ccat
##   *_by_ccat (based on mail contents) -> *_maps
##   *_maps (based on recipient address) -> final configuration value


# SOME OTHER VARIABLES WORTH CONSIDERING (see amavisd.conf-default for all)

# Notify virus sender?
$warnvirussender = 0; 
# Notify spam sender?
$warnspamsender = 0;  
# Notify sender of banned files?  can do it...
$warnbannedsender = 0;
# Notify sender of syntactically invalid header containing non-ASCII characters? do not!
$warnbadhsender = 0;
# Notify virus (or banned files) RECIPIENT? If you want...
$warnvirusrecip = 0;
$warnbannedrecip = 1;
$warnbadhrecip = 0;

# $warnbadhsender,
# $warnvirusrecip, $warnbannedrecip, $warnbadhrecip, (or @warn*recip_maps)
#
# @bypass_virus_checks_maps, @bypass_spam_checks_maps,
# @bypass_banned_checks_maps, @bypass_header_checks_maps,
#
# @virus_lovers_maps, @spam_lovers_maps,
# @banned_files_lovers_maps, @bad_header_lovers_maps,
#
# @blacklist_sender_maps, @score_sender_maps,
#
# $clean_quarantine_method, $virus_quarantine_to, $banned_quarantine_to,
# $bad_header_quarantine_to, $spam_quarantine_to,
#
# $defang_bad_header, $defang_undecipherable, $defang_spam


# REMAINING IMPORTANT VARIABLES ARE LISTED HERE BECAUSE OF LONGER ASSIGNMENTS

@keep_decoded_original_maps = (new_RE(
  qr'^MAIL$',                # let virus scanner see full original message
  qr'^MAIL-UNDECIPHERABLE$', # same as ^MAIL$ if mail is undecipherable
  qr'^(ASCII(?! cpio)|text|uuencoded|xxencoded|binhex)'i,
# qr'^Zip archive data',     # don't trust Archive::Zip
));

@virus_name_to_spam_score_maps = (new_RE(
  [ qr'^Phishing\.'                                             => 6.1 ],
  [ qr'^Structured\.(SSN|CreditCardNumber)\b'                   => 6.1 ],
  [ qr'^(?:Email|HTML|Sanesecurity)\.(?:Phishing|SpearL?)\.'i   => 6.1 ],
  [ qr'^(?:Email|HTML|Sanesecurity)\.(?:Spam|Scam)[a-z0-9]?\.'i => 6.1 ],
  [ qr'^Sanesecurity\.(Malware|Rogue|Trojan)\.'                 => undef ],
#  [ qr'^Email\.Spam.*-SecuriteInfo\.com(\.|\z)'                => 6.1 ], # only with SECURITEINFO signatures
#  [ qr'^SecuriteInfo\.com\.Spam\.'                             => 6.1 ], # only with SECURITEINFO signatures
  [ qr'^winnow\.(?:botnets?|phish|complex|mailer)\.'x           => 6.1 ],
  [ qr'^winnow\.spam(?:domain)?\.'x                             => 6.1 ],
  [ qr'^winnow\.(?:malware|trojan|compromised)\.'x              => undef ],
  [ qr'^winnow\.'x                                              => 6.1 ],
  [ qr'^PhishTank\.Phishing\.'                                  => 6.1 ],
  [ qr'^Bofhland\.Malware\.'                                    => undef ],
  [ qr'^Porcupine\.(Malware|JS|Java|Win32|MSIL|VBS)\.'   	=> undef ],
  [ qr'^Porcupine\.'                                     	=> 6.1 ],
#  [ qr'^MBL_'							=> 5.8 ], # only with MALWARE PATROL signatures
  [ qr'^URLhaus\.'                                     	        => undef ]
));

$banned_filename_re = new_RE(

### BLOCKED ANYWHERE
# qr'^UNDECIPHERABLE$',  # is or contains any undecipherable components
  qr'^\.(exe-ms|dll)$',                   # banned file(1) types, rudimentary
  qr'^\.(exe|lha|cab|dll)$',              # banned file(1) types
  qr'^\.(arj|zoo)$',                      # banned old archive types
  qr'^\.(eml)$',                          # banned old Outlook Express RFC822 attachment
# qr'^\.(tnef)$',                         # banned Winmail.dat Outlook RTF

### BLOCK THE FOLLOWING, EXCEPT WITHIN UNIX ARCHIVES:
  [ qr'^\.(gz|bz2)$'             => 0 ],  # allow any in gzip or bzip2
  [ qr'^\.(rpm|cpio|tar)$'       => 0 ],  # allow any in Unix-type archives

  qr'.\.(pif|scr)$'i,                     # banned extensions - rudimentary
# qr'^\.zip$',                            # block zip type

### BLOCK THE FOLLOWING, EXCEPT WITHIN ARCHIVES:
# [ qr'^\.(zip|rar|arc|arj|zoo)$'=> 0 ],  # allow any within these archives

  qr'^application/x-msdownload$'i,        # block these MIME types
  qr'^application/x-msdos-program$'i,
  qr'^application/hta$'i,

### BLOCK MS Powerpoint MIME types
  qr'^application/vnd.ms-powerpoint$'i,
# qr'^application/vnd.openxmlformats-officedocument.presentationml.presentation$'i,
  qr'^application/vnd.ms-powerpoint.addin.macroEnabled.12$'i,
  qr'^application/vnd.ms-powerpoint.presentation.macroEnabled.1$'i,
  qr'^application/vnd.ms-powerpoint.template.macroEnabled.12$'i,
  qr'^application/vnd.ms-powerpoint.slideshow.macroEnabled.12$'i,

### BLOCK MS Excel MIME types
  qr'^application/vnd.ms-excel$'i,
# qr'^application/vnd.openxmlformats-officedocument.spreadsheetml.sheet$'i,
  qr'^application/vnd.ms-excel.sheet.macroEnabled.12'i,
  qr'^application/vnd.ms-excel.template.macroEnabled.12'i,
  qr'^application/vnd.ms-excel.addin.macroEnabled.12$'i,
  qr'^application/vnd.ms-excel.sheet.binary.macroEnabled.12$'i,

### BLOCK MS Word MIME types
  qr'^application/msword$'i,
# qr'^application/vnd.openxmlformats-officedocument.wordprocessingml.document$'i,
  qr'^application/vnd.openxmlformats-officedocument.wordprocessingml.template$'i,
  qr'^application/vnd.ms-word.document.macroEnabled.12$'i,
  qr'^application/vnd.ms-powerpoint.presentation.macroEnabled.12$'i,
  qr'^application/vnd.ms-word.template.macroEnabled.12$'i,
  qr'^application/vnd.ms-powerpoint.slideshow.macroEnabled.12$'i,

### BLOCK MS Access mdb MIME type
  qr'^application/vnd.ms-access'i, 

# qr'^message/partial$'i,         # rfc2046 MIME type
# qr'^message/external-body$'i,   # rfc2046 MIME type

  qr'^(application/x-msmetafile|image/x-wmf)$'i,  # Windows Metafile MIME type
  qr'^\.wmf$',                            # Windows Metafile file(1) type

  # block certain double extensions in filenames
  qr'^(?!cid:).*\.[^./]*[A-Za-z][^./]*\.\s*(exe|vbs|pif|scr|bat|cmd|com|cpl|dll)[.\s]*$'i,

# qr'\{[0-9a-f]{8}(-[0-9a-f]{4}){3}-[0-9a-f]{12}\}?'i, # Class ID CLSID, strict
# qr'\{[0-9a-z]{4,}(-[0-9a-z]{4,}){0,7}\}?'i, # Class ID extension CLSID, loose

# qr'.\.(exe|vbs|pif|scr|cpl)$'i,             # banned extension - basic
# qr'.\.(exe|vbs|pif|scr|cpl|bat|cmd|com)$'i, # banned extension - basic+cmd
  qr'.\.(ade|adp|app|bas|bat|chm|cmd|com|cpl|crt|emf|exe|fxp|grp|hlp|hta|
         inf|ini|ins|isp|js|jse|lib|lnk|mda|mdb|mde|mdt|mdw|mdz|msc|msi|
         msp|mst|ocx|ops|pcd|pif|prg|reg|scr|sct|shb|shs|sys|vb|vbe|vbs|vxd|
         wmf|wsc|wsf|wsh)$'ix,                # banned extensions - long
  qr'.\.(asd|asf|asx|url|vcs|wmd|wmz)$'i,     # consider also
  qr'.\.(ani|cur|ico)$'i,                     # banned cursors and icons filename
  qr'.\.(arj|lha|zoo)$'i,                     # banned old archive types
  qr'.\.(iso|img|nrg)$'i,                     # banned disc image files
  qr'^\.ani$',                                # banned animated cursor file(1) type
  qr'.\.(mim|b64|bhx|hqx|xxe|uu|uue)$'i,      # banned extension - WinZip vulnerab.
  qr'.\.(docm|dotm|xlsm|xltm|xlam|xlm|
        pptm|ppam|ppsm|sldm|potm|mam)$'i,     # microsoft office files with macros
  qr'.\.(doc|xls|ppt)$'i,                     # microsoft office old file types
# qr'.\.(pptx)$'i,              	      # microsoft office powerpoint files
# qr'.\.(xlsx)$'i,              	      # microsoft office excel files
# qr'.\.(docx)$'i,                            # microsoft office word files
);

# See http://support.microsoft.com/default.aspx?scid=kb;EN-US;q262631
# and http://www.cknow.com/vtutor/vtextensions.htm

# ENVELOPE SENDER SOFT-WHITELISTING / SOFT-BLACKLISTING

@score_sender_maps = ({ # a by-recipient hash lookup table,
                        # results from all matching recipient tables are summed

# ## per-recipient personal tables  (NOTE: positive: black, negative: white)
# 'user1@example.com'  => [{'bla-mobile.press@example.com' => 10.0}],
# 'user3@example.com'  => [{'.ebay.com'                 => -3.0}],
# 'user4@example.com'  => [{'cleargreen@cleargreen.com' => -7.0,
#                           '.cleargreen.com'           => -5.0}],

  ## site-wide opinions about senders (the '.' matches any recipient)
  '.' => [  # the _first_ matching sender determines the score boost

   new_RE(  # regexp-type lookup table, just happens to be all soft-blacklist
    [qr'^(bulkmail|offers|cheapbenefits|earnmoney|foryou)@'i         => 5.0],
    [qr'^(greatcasino|investments|lose_weight_today|market\.alert)@'i=> 5.0],
    [qr'^(money2you|MyGreenCard|new\.tld\.registry|opt-out|opt-in)@'i=> 5.0],
    [qr'^(optin|saveonlsmoking2002k|specialoffer|specialoffers)@'i   => 5.0],
    [qr'^(stockalert|stopsnoring|wantsome|workathome|yesitsfree)@'i  => 5.0],
    [qr'^(your_friend|greatoffers)@'i                                => 5.0],
    [qr'^(inkjetplanet|marketopt|MakeMoney)\d*@'i                    => 5.0],
   ),

#  read_hash("/var/amavis/sender_scores_sitewide"),

   { # a hash-type lookup table (associative array)
     'nobody@cert.org'                        => -3.0,
     'cert-advisory@us-cert.gov'              => -3.0,
     'owner-alert@iss.net'                    => -3.0,
     'slashdot@slashdot.org'                  => -3.0,
     'securityfocus.com'                      => -3.0,
     'ntbugtraq@listserv.ntbugtraq.com'       => -3.0,
     'security-alerts@linuxsecurity.com'      => -3.0,
     'mailman-announce-admin@python.org'      => -3.0,
     'amavis-user-admin@lists.sourceforge.net'=> -3.0,
     'amavis-user-bounces@lists.sourceforge.net' => -3.0,
     'spamassassin.apache.org'                => -3.0,
     'notification-return@lists.sophos.com'   => -3.0,
     'owner-postfix-users@postfix.org'        => -3.0,
     'owner-postfix-announce@postfix.org'     => -3.0,
     'owner-sendmail-announce@lists.sendmail.org'   => -3.0,
     'sendmail-announce-request@lists.sendmail.org' => -3.0,
     'donotreply@sendmail.org'                => -3.0,
     'ca+envelope@sendmail.org'               => -3.0,
     'noreply@freshmeat.net'                  => -3.0,
     'owner-technews@postel.acm.org'          => -3.0,
     'ietf-123-owner@loki.ietf.org'           => -3.0,
     'cvs-commits-list-admin@gnome.org'       => -3.0,
     'rt-users-admin@lists.fsck.com'          => -3.0,
     'clp-request@comp.nus.edu.sg'            => -3.0,
     'surveys-errors@lists.nua.ie'            => -3.0,
     'emailnews@genomeweb.com'                => -5.0,
     'yahoo-dev-null@yahoo-inc.com'           => -3.0,
     'returns.groups.yahoo.com'               => -3.0,
     'clusternews@linuxnetworx.com'           => -3.0,
     lc('lvs-users-admin@LinuxVirtualServer.org')    => -3.0,
     lc('owner-textbreakingnews@CNNIMAIL12.CNN.COM') => -5.0,

     # soft-blacklisting (positive score)
     'sender@example.net'                     =>  3.0,
     '.example.net'                           =>  1.0,

   },
  ],  # end of site-wide tables
});


@decoders = (
  ['mail', \&do_mime_decode],
# [[qw(asc uue hqx ync)], \&do_ascii],  # not safe
  ['F',    \&do_uncompress, ['unfreeze', 'freeze -d', 'melt', 'fcat'] ],
  ['Z',    \&do_uncompress, ['uncompress', 'gzip -d', 'zcat'] ],
  ['gz',   \&do_uncompress, 'gzip -d'],
  ['gz',   \&do_gunzip],
  ['bz2',  \&do_uncompress, 'bzip2 -d'],
  ['xz',   \&do_uncompress,
           ['xzdec', 'xz -dc', 'unxz -c', 'xzcat'] ],
  ['lzma', \&do_uncompress,
           ['lzmadec', 'xz -dc --format=lzma',
            'lzma -dc', 'unlzma -c', 'lzcat', 'lzmadec'] ],
  ['lrz',  \&do_uncompress,
           ['lrzip -q -k -d -o -', 'lrzcat -q -k'] ],
  ['lzo',  \&do_uncompress, 'lzop -d'],
  ['lz4',  \&do_uncompress, ['lz4c -d'] ],
  ['rpm',  \&do_uncompress, ['rpm2cpio.pl', 'rpm2cpio'] ],
  [['cpio','tar'], \&do_pax_cpio, ['pax', 'gcpio', 'cpio'] ],
           # ['/usr/local/heirloom/usr/5bin/pax', 'pax', 'gcpio', 'cpio']
  ['deb',  \&do_ar, 'ar'],
# ['a',    \&do_ar, 'ar'],  # unpacking .a seems an overkill
  ['rar',  \&do_unrar, ['unrar', 'rar'] ],
  ['arj',  \&do_unarj, ['unarj', 'arj'] ],
  ['arc',  \&do_arc,   ['nomarch', 'arc'] ],
  ['zoo',  \&do_zoo,   ['zoo', 'unzoo'] ],
  ['doc',  \&do_ole,   'ripole'],
  ['cab',  \&do_cabextract, 'cabextract'],
  ['tnef', \&do_tnef_ext, 'tnef'],
  ['tnef', \&do_tnef],
# ['lha',  \&do_lha,   'lha'],  # not safe, use 7z instead
# ['sit',  \&do_unstuff, 'unstuff'],  # not safe
  [['zip','kmz'], \&do_7zip,  ['7za', '7z'] ],
  [['zip','kmz'], \&do_unzip],
  ['7z',   \&do_7zip,  ['7zr', '7za', '7z'] ],
  [[qw(gz bz2 Z tar)],
           \&do_7zip,  ['7za', '7z'] ],
  [[qw(xz lzma jar cpio arj rar swf lha iso cab deb rpm)],
           \&do_7zip,  '7z' ],
  ['exe',  \&do_executable, ['unrar','rar'], 'lha', ['unarj','arj'] ],
);


@av_scanners = (

# ### http://www.clamav.net/
  ['ClamAV-clamd',
    \&ask_daemon, ["CONTSCAN {}\n", "/var/run/clamav/clamd"],
    qr/\bOK$/m, qr/\bFOUND$/m,
    qr/^.*?: (?!Infected Archive)(.*) FOUND$/m ],

# ### fully-fledged checker for JPEG marker segments of invalid length
  ['check-jpeg',
   sub { use JpegTester (); Amavis::AV::ask_av(\&JpegTester::test_jpeg, @_) },
    ["{}/*"], undef, [1], qr/^(bad jpeg: .*)$/m ],

# ### a generic SMTP-client interface to a SMTP-based virus scanner
# ['av_smtp', \&ask_av_smtp,
#   ['{}', 'smtp:[127.0.0.1]:5525', 'dummy@localhost'],
#   qr/^2/, qr/^5/, qr/^\s*(.*?)\s*$/m ],

);

@av_scanners_backup = (

  ### http://www.clamav.net/   - backs up clamd or Mail::ClamAV
  ['ClamAV-clamscan', 'clamscan',
    "--stdout --no-summary -r --tempdir=$TEMPBASE {}",
    [0], qr/:.*\sFOUND$/m, qr/^.*?: (?!Infected Archive)(.*) FOUND$/m ],

);

1;  # insure a defined return value
EOF

echo -e "\033[92mdone...\033[0m";
}

write_spamassassin_config() {
echo -en "Install spamassassin config template now: ";
cat > /etc/mail/spamassassin/local.cf << "EOF"
##############################################################################
#                                                                            #
# This is the right place to customize your installation of SpamAssassin.    #
# Only a small subset of options are listed below                            #
# https://spamassassin.apache.org/full/3.4.x/doc/Mail_SpamAssassin_Conf.html #
#                                                                            #
##############################################################################

#   Add *****SPAM***** to the Subject header of spam e-mails
rewrite_header Subject ****SPAM****

# Save spam messages as a message/rfc822 MIME attachment instead of
# modifying the original message (0: off, 2: use text/plain instead)
report_safe 0

# Set which networks or hosts are considered 'trusted' by your mail
# server (i.e. not spammers)
trusted_networks 192.168.0.0/16

# Set file-locking method (flock is not safe over NFS, but is faster)
lock_method flock

# Set the threshold at which a message is considered spam (default: 5.0)
# required_score 5.0

# Use Bayesian classifier (default: 1)
use_bayes 1
bayes_path /var/amavis/.spamassassin/bayes
bayes_auto_learn 1
bayes_auto_expire 1
bayes_file_mode 0600

# Tells SA that we want to use Razor version 2
use_razor2 1
razor_config /var/amavis/.razor/razor-agent.conf

# By default SpamAssassin runs the Realtime Blackhole List checks. 
skip_rbl_checks 0
dns_query_restriction deny support-intelligence.net

# If you are sure you have DNS access set it to "yes".
dns_available yes

# Whether to decode non- UTF-8 and non-ASCII textual parts and recode
# them to UTF-8 before the text is given over to rules processing.
normalize_charset 1

# TxRep - Normalize scores with sender reputation records
use_txrep 1
txrep_factor 0.5

# enable OLEVBMacro
ifplugin Mail::SpamAssassin::Plugin::OLEVBMacro
    body     OLEMACRO eval:check_olemacro()
    describe OLEMACRO Attachment has an Office Macro

    body     OLEMACRO_MALICE eval:check_olemacro_malice()
    describe OLEMACRO_MALICE Potentially malicious Office Macro

    body     OLEMACRO_ENCRYPTED eval:check_olemacro_encrypted()
    describe OLEMACRO_ENCRYPTED Has an Office doc that is encrypted

    body     OLEMACRO_RENAME eval:check_olemacro_renamed()
    describe OLEMACRO_RENAME Has an Office doc that has been renamed

    body     OLEMACRO_ZIP_PW eval:check_olemacro_zip_password()
    describe OLEMACRO_ZIP_PW Has an Office doc that is password protected in a zip

    body     OLEMACRO_CSV eval:check_olemacro_csv()
    describe OLEMACRO_CSV Malicious csv file that tries to exec cmd.exe detected
endif

ifplugin Mail::SpamAssassin::Plugin::Shortcircuit

# default: strongly-whitelisted mails are *really* whitelisted now, if the
# shortcircuiting plugin is active, causing early exit to save CPU load.
# Uncomment to turn this on

# shortcircuit USER_IN_WHITELIST       on
# shortcircuit USER_IN_DEF_WHITELIST   on
# shortcircuit USER_IN_ALL_SPAM_TO     on
# shortcircuit SUBJECT_IN_WHITELIST    on

# the opposite; blacklisted mails can also save CPU

# shortcircuit USER_IN_BLACKLIST       on
# shortcircuit USER_IN_BLACKLIST_TO    on
# shortcircuit SUBJECT_IN_BLACKLIST    on

# if you have taken the time to correctly specify your "trusted_networks",
# this is another good way to save CPU

# shortcircuit ALL_TRUSTED             on

# and a well-trained bayes DB can save running rules, too

# shortcircuit BAYES_99                spam
# shortcircuit BAYES_00                ham

endif # Mail::SpamAssassin::Plugin::Shortcircuit
EOF
echo -e "\033[92mdone...\033[0m";
}

write_header_checks_template(){
echo -en "Install header_checks.pcre template now: ";
cat > ${CONFIGDIR}/header_checks.pcre << "EOF"
#
# header_checks - Postfix built-in content inspection
# postmap ist not needed for this file
# manual at /etc/postfix/man/header_checks
#
/^x-originating-ip*/ IGNORE
/^X-Virus-Scanned*/ IGNORE
/^Received:\s+.*/ IGNORE
EOF
echo -e "\033[92mdone...\033[0m";
}

write_esmtp_access_template(){
echo -en "Install esmtp_access template now: ";
cat > ${CONFIGDIR}/esmtp_access << "EOF"
#
# esmtp_access - Postfix
# DSN requests werden nur aus dem internen Netzen erlaubt
#
192.168.0.0/16  silent-discard
172.16.0.0/12   silent-discard
10.0.0.0/8      silent-discard
0.0.0.0/0       silent-discard, dsn
EOF
echo -e "\033[92mdone...\033[0m";
}

write_ptr_cf_template() {
echo -en "Install ptr.cf template now: ";
cat > /etc/postfix/ptr.cf << "EOF"
#
# /etc/postfix/ptr.cf
# postmap ist not needed for this file
#  
#/([0-9]{1,3}(\-|\.)[0-9]{1,3}(\-|\.)[0-9]{1,3}(\-|\.)[0-9]{1,3}.+[a-z0-9]+\.[a-z0-9]{2,6})$/ 550  Access denied - no dynamic IP allowed
/^(p.*\.dip.?\.t\-ipconnect\.de)$/                                                           550  Access denied - no dynamic IP allowed
/(\.adsl\.alicedsl\.de)$/                                                                    550  Access denied - no dynamic IP allowed
/^(chello[0-9]+\.[0-9]+\.[0-9]+\.vie\.surfer\.at)$/                                          550  Access denied - no dynamic IP allowed

EOF
echo -e "\033[92mdone...\033[0m";
}

write_helo_cf_template(){
# install helo.cf template
echo -en "Install helo.cf template now: ";
cat > /etc/postfix/helo.cf << "EOF"
#
# /etc/postfix/helo.cf
# postmap is not needed for this file
#  
#/(.*[0-9]{1,3}([\.|\-][0-9]{1,3}){3}.*)/     553 invalid helo [1]
/(.*\.intra)$/                               553 invalid helo [2]
/(.*\.local)$/                               553 invalid helo [3]
/(.*\.lan)$/                                 553 invalid helo [4]
/(.*\.priv)$/                                553 invalid helo [5]
/(.*\.private)$/                             553 invalid helo [6]
/(.*\.localdomain)$/                         553 invalid helo [7]
/(.*\.online)$/                              553 invalid helo [8]

EOF
echo -e "\033[92mdone...\033[0m";
}

write_body_checks_template(){
echo -en "Install body_checks.pcre template now: ";
cat > $CONFIGDIR/body_checks.pcre << "EOF"
/^((Content-(Disposition: attachment;|Type:).*|\ +)| *)(file)?name\ *=\ *"?.*\.(lnk|asd|hlp|ocx|reg|bat|c[ho]m|cmd|exe|dll|vxd|pif|scr|hta|jse?|sh[mbs]|vb[esx]|ws[fh]|wmf)"?\ *$/ REJECT attachment type not allowed
EOF
rm -f $CONFIGDIR/body_checks;
echo -e "\033[92mdone...\033[0m";
}

write_mime_header_checks_template(){
echo -en "Install mime_header_checks.pcre template now: ";
cat > $CONFIGDIR/mime_header_checks.pcre << "EOF"
/^((Content-(Disposition: attachment;|Type:).*|\ +)| *)(file)?name\ *=\ *"?.*\.(lnk|asd|hlp|ocx|reg|bat|c[ho]m|cmd|exe|dll|vxd|pif|scr|hta|jse?|sh[mbs]|vb[esx]|ws[fh]|wmf)"?\ *$/ REJECT attachment type not allowed
EOF
echo -e "\033[92mdone...\033[0m";
}

write_batv_template(){
echo -en "Install batv template now: ";
cat > $CONFIGDIR/batv.regexp << "EOF"
/^prvs=[0-9]{4}[0-9A-Fa-f]{6}=(.*)$/ $1
EOF
echo -e "\033[92mdone...\033[0m";
}

config_amavisd() {
 CFILE="/etc/postfix/main.cf";
 if [[ $ONLYPF = "1" ]]; then
   TESTVAR=$(grep 'content_filter' $CFILE |awk '{print $2}'); 
   if [ "$TESTVAR" = "=" ]; then
    LINE=$(grep -n "content_filter" $CFILE | awk -F: '{ print $1; }');
    sed -i "${LINE}d" $CFILE;
    LINE=$(grep -n "Amavisd connector" $CFILE | awk -F: '{ print $1; }');
    sed -i "${LINE}d" $CFILE;
    #Remove next empty line
    sed -i "${LINE}d" $CFILE;
    echo  -e "\033[32mAmavisd connector in main.cf has been removed...\033[0m";
   fi;
 fi;
}

activate_razor() {
# Activation of Razor2
if [[ ! -e /var/amavis/.razor/servers.discovery.lst ]]; then
 echo -e "\033[32mActivate Razor2...\033[0m";
 razor-admin --home=/var/amavis/.razor --discover &> /dev/null;
 razor-admin --home=/var/amavis/.razor --create &> /dev/null;
 razor-admin --home=/var/amavis/.razor --register;
else
 echo -e "\033[32mRazor2 already configured...\033[0m";
fi;
}

write_virtual_template() {
echo -n "Install virtual template now: ";
cat > ${MAPSDIR}/virtual << "EOF"
# Use the postmap command whenever you change the this file
#
postmaster      postmaster@mydomain.de
abuse           abuse@mydomain.de
EOF
echo -e "\033[92mdone...\033[0m";
}

write_transport_template() {
echo -n "Install transport template now: ";
cat > ${MAPSDIR}/transport << "EOF"
# /etc/postfix/transport
# Use the postmap command whenever you change the this file
#
# example mydomain.com smtp:server.mydomain.local:8025
#
EOF
echo -e "\033[92mdone...\033[0m";
}

check_bounce_cf_template() {
if [[ ! -e ${CONFIGDIR}/bounce.cf  ]]; then
 cat > ${CONFIGDIR}/bounce.cf << "EOF2"
# To change Postfix DSN messages, perhaps to add non-English text,
# follow instructions in the bounce(5) manual page.
#

#
# The failure template is used when mail is returned to the sender;
# either the destination rejected the message, or the destination
# could not be reached before the message expired in the queue.
#

failure_template = <<EOF
Charset: us-ascii
From: MAILER-DAEMON (Mail Delivery System)
Subject: Undelivered Mail Returned to Sender
Postmaster-Subject: Postmaster Copy: Undelivered Mail

This is the mail system at host $myhostname.

I'm sorry to have to inform you that your message could not
be delivered to one or more recipients. It's attached below.

For further assistance, please send mail to postmaster.

If you do so, please include this problem report. You can
delete your own text from the attached returned message.

                   The mail system
EOF


#
# The delay template is used when mail is delayed. Note a neat trick:
# the default template displays the delay_warning_time value as hours
# by appending the _hours suffix to the parameter name; it displays
# the maximal_queue_lifetime value as days by appending the _days
# suffix.
#
# Other suffixes are: _seconds, _minutes, _weeks. There are no other
# main.cf parameters that have this special behavior.
#
# You need to adjust these suffixes (and the surrounding text) if
# you have very different settings for these time parameters.
#

delay_template = <<EOF
Charset: us-ascii
From: MAILER-DAEMON (Mail Delivery System)
Subject: Delayed Mail (still being retried)
Postmaster-Subject: Postmaster Warning: Delayed Mail

This is the mail system at host $myhostname.

####################################################################
# THIS IS A WARNING ONLY.  YOU DO NOT NEED TO RESEND YOUR MESSAGE. #
####################################################################

Your message could not be delivered for more than $delay_warning_time_hours hour(s).
It will be retried until it is $maximal_queue_lifetime_minutes minutes old.

For further assistance, please send mail to postmaster.

If you do so, please include this problem report. You can
delete your own text from the attached returned message.

                   The mail system
EOF


#
# The success template is used when mail is delivered to mailbox,
# when an alias or list is expanded, or when mail is delivered to a
# system that does not announce DSN support. It is an error to specify
# a Postmaster-Subject: here.
#

success_template = <<EOF
Charset: us-ascii
From: MAILER-DAEMON (Mail Delivery System)
Subject: Successful Mail Delivery Report

This is the mail system at host $myhostname.

Your message was successfully delivered to the destination(s)
listed below. If the message was delivered to mailbox you will
receive no further notifications. Otherwise you may still receive
notifications of mail delivery errors from other systems.

                   The mail system
EOF


#
# The verify template is used for address verification (sendmail -bv
# address...) or for verbose mail delivery (sendmail -v address...).
# It is an error to specify a Postmaster-Subject: here.
#

verify_template = <<EOF
Charset: us-ascii
From: MAILER-DAEMON (Mail Delivery System)
Subject: Mail Delivery Status Report

This is the mail system at host $myhostname.

Enclosed is the mail delivery report that you requested.

                   The mail system
EOF

EOF2
fi;
}

check_network_table_template() {
echo -en "Install network_table template now: ";
if [ ! -e ${CONFIGDIR}/network_table ]; then
cat > ${CONFIGDIR}/network_table << "EOF"
#
# IPFire Mail Gateway Project 
# network_table file
#
# Postmap is not needed for this cidr file 
# This file is only for a list of hosts or networks to enable relaying mail
# Do not remove the 127.0.0.0/8 OK entry
#
# Network   OK/REJECT
#
127.0.0.0/8 OK
EOF
echo -e "\033[92mdone...\033[0m";
else
  echo -e "\033[93malready exist...\033[0m";
fi;
}

check_relay_domains_template() {
  echo -en "Install relay_domains template now: ";
  if [ ! -e ${MAPSDIR}/relay_domains ]; then
  cat > ${MAPSDIR}/relay_domains << "EOF"
#
# IPFire Mail Gateway Project 
# relay_domains file
#
# Use the "postmap lmdb:/etc/postfix/maps/relay_domains"
# command whenever you change the file
# This file is only for a list of relayed domains
#
# The placeholder is only needed to supress postmap error message
# Postfix does not use this valve
# 
# doamin       placeholder for postmap
# mydomain.com 1
#
EOF
  echo -e "\033[92mdone...\033[0m";
  postmap lmdb:${MAPSDIR}/relay_domains > /dev/null;
else
  echo -e "\033[93malready exist...\033[0m";
fi;
}

check_relay_recipients_template() {
  echo -en "Install relay_recipients template now: ";
  if [ ! -e ${MAPSDIR}/relay_recipients ]; then
  cat > ${MAPSDIR}/relay_recipients << "EOF"
#
# IPFire Mail Gateway Project 
# relay_recipients file
#
# Use the "postmap lmdb:/etc/postfix/maps/relay_recipients"
# command whenever you change this file
#
# Relay recipients access control file (ACL)
#
# Address example 
# name@domain.com OK   # full address
#
EOF
  postmap lmdb:${MAPSDIR}/relay_recipients > /dev/null;
  echo -e "\033[92mdone...\033[0m";
else
  echo -e "\033[93malready exist...\033[0m";
fi;
}

check_sasl_passwd_template() {
  echo -en "Install sasl_passwd template now: ";
  if [ ! -f ${MAPSDIR}/sasl_passwd ]; then
  cat > ${MAPSDIR}/sasl_passwd << "EOF"
#
# IPFire Mail Gateway Project 
# sasl_passwd file
#
# Use the "postmap lmdb:/etc/postfix/maps/sasl_passwd"
# command whenever you change the file
#
# destination                   credentials
# [mail.isp.example]:587        username:password
#
# smtp.domain.com:587 user@domain.com:changeme

EOF
  postmap lmdb:${MAPSDIR}/sasl_passwd > /dev/null;
  echo -e "\033[92mdone...\033[0m";
else
  echo -e "\033[93malready exist...\033[0m";
fi;
}

# backup postfix and amavisd config files
backup_config_files() {

  # Check if Postfix is already installed and backup files
  if [[ -e /usr/sbin/postfix ]] ; then

    # move aliases to maps dir
    if [ ! -d ${MAPSDIR} ]; then mkdir -p ${MAPSDIR}; fi;
    if [ -f /etc/aliases ]; then mv -f /etc/aliases ${MAPSDIR}; fi;
    if [ -f ${CONFIGDIR}/aliases ]; then mv -f ${CONFIGDIR}/aliases ${MAPSDIR}; fi;
    rm -f {/etc/aliases.db,${CONFIGDIR}/aliases.db};

    BACKUPCONFDIR="${CONFIGDIR}/backup/$(date +"%Y%m%d_%H%M%S")";
    echo -en "\033[32mBackup existing config files to ${BACKUPCONFDIR} now: \033[0m";
    mkdir -p ${BACKUPCONFDIR};

    # copy main config files to backup folder
    for i in ${CONFIGFILES[@]}; do
      if [ -f ${CONFIGDIR}/${i} ]; then /bin/cp ${CONFIGDIR}/${i} ${BACKUPCONFDIR}; fi;
    done
 
    # move main maps files from old location to backup folder
    for i in ${MAPSFILES[@]}; do
      if [ -f ${CONFIGDIR}/${i} ]; then /bin/mv -f ${CONFIGDIR}/${i} ${BACKUPCONFDIR}; fi;
    done

    # copy postfix main maps files to backup folder
    for i in ${MAPSFILES[@]}; do
      if [ -f ${MAPSDIR}/${i} ]; then /bin/cp ${MAPSDIR}/${i} ${BACKUPCONFDIR}; fi;
    done
    /bin/cp -f "/etc/amavisd.conf" ${BACKUPCONFDIR}/amavisd.conf;
    rm -f ${CONFIGDIR}/*.db
  fi;

  # delete not needed postfix config files
  rm -f  ${CONFIGDIR}/{mysql-canonical.cf,mysql-mydestination.cf,mysql-virtual.cf};

  echo -e "\033[92mdone...\033[0m";
}

# check logrotate entry for postfix
add_logrotate_postfix(){
cat >> /etc/logrotate.d/postfix << "EOF"
# Postfix
/var/log/mail {
    daily
    rotate 30
    copytruncate
    compress
    notifempty
    missingok
}
EOF
}

##############################
# main execution start here! #
##############################
# Create backUP dir for Postfix if not alread done
if [ ! -d "${BCKCONFIGDIR}" ]; then
    mkdir ${BCKCONFIGDIR};
fi
backup_config_files;

while true
do
    clear;
    echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
    echo -e "\033[1;36m-                 Mail Gateway configuration template selection                -\033[0m"
    echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
    echo " ";
    if [ $ONLYPF = "1" ]; then
      echo -e "\033[33mInstalling the postfix only templates. \033[0m";
      echo " ";
    fi;
    echo -e "\033[32mPlease select your postfix template type: \033[0m";
    echo "Press '1' for all checks and filters (default)";
    echo "Press 'q' to quit this menu and continue installation";

    echo " ";
    echo -e "\033[1;36m--------------------------------------------------------------------------------\033[0m";
    echo -n "Please select: ";
    read -n 1 menuanswer;
    echo " ";
    echo " ";
    case ${menuanswer} in
    1)
	write_main_cf_all_filters
	write_master_cf;
	if [ "${ONLYPF}" = "1" ]; then config_amavisd; fi;
	if [ "${ONLYPF}" = "0" ]; then write_spamassassin_config; fi;
	break;
	;;
    q)
      echo -e "\033[93mTemplates installation exit...\033[0m";
      echo " ";
      unset MAPSFILES CONFIGFILES MAPSDIR CONFIGDIR LOG ROTATE MAIN TCONF VIRT ACONF;
      exit
      ;;
  esac
done

# ceate maps dir
mkdir -p ${MAPSDIR};

# Install templates
write_esmtp_access_template;
write_ptr_cf_template;
write_helo_cf_template;
write_header_checks_template;
write_body_checks_template;
write_mime_header_checks_template;
write_batv_template;
write_amavisd_conf_template;
write_virtual_template;
write_transport_template;
check_bounce_cf_template;
check_network_table_template;
check_relay_domains_template;
check_relay_recipients_template;
check_sasl_passwd_template;
add_logrotate_postfix;
activate_razor;

# Set group rights 
usermod -a -G clamav amavis
usermod -a -G clamav clamav
usermod -a -G amavis clamav
usermod -a -G amavis amavis

echo -e "\033[93mTemplates installation done...\033[0m";
echo " ";

# remove obsolete berkeley database files
rm -f ${MAPSDIR}/*.db

unset MAPSFILES CONFIGFILES MAPSDIR CONFIGDIR LOG ROTATE MAIN TCONF VIRT ACONF ONLYPF NOMSG;
#End of templates.sh
