#!/bin/bash

############################################################
#                                                          #
# File: mpuninstall.sh                                     #
#                                                          #
# This script removes Mail Gateway packages from IPFire    #
#                                                          #
# Build time: Mon Apr 22 09:59:32 AM CEST 2024
#                                                          #
############################################################

# Detect platform type 
MACHINE=$(uname -m);

if [[ $MACHINE == armv5tel || $MACHINE == armv5tejl || $MACHINE == armv6l || $MACHINE == armv7l ]]; then
  echo -e "\033[91mInstallation only on Intel systems. ARM based systems are not supported!\033[0m";
  unset MACHINE;
  sleep 2;
  exit 1;
fi;

# Command line args test
NOMSG="0";
ONLYPF="0";
for arg; do
  if [ ${arg} = "-quiet" ]; then NOMSG="1"; fi;
  if [ ${arg} = "-opf" ]; then ONLYPF="1"; printf "Start postfix only uninstallation now...\n"; fi;
done

if [ -f /etc/postfix/main.cf ]; then
  printf "\033[32mStart uninstallation now...\033[0m\n";
 else 
  echo -e "\033[32mPostfix is not installed! Exiting..\033[0m";
  echo -e "\033[32mRestart the installer if needed.\033[0m";
  rm -f mpconfig.sh mptemplates.sh mpinstall.sh mpuninstall.sh mplog.dat mpsum.dat;
  rm -f mptrn.dat mp_packages.tar mpman.sh mpwebif.sh dh_2048.pem razor-agent.log 
  if [ -f mpreport.sh ]; then rm -f mpreport.sh mpup.sh; fi;
  echo "";
 exit 1
fi;

# spamassassin
remove_sa() {
printf "\033[32mRemove spamassassin now...\033[0m";
rm -rfv \
/usr/bin/sa-check_spamd \
/usr/bin/sa-compile \
/usr/bin/sa-update \
/usr/bin/sa-learn \
/usr/bin/spamc \
/usr/bin/spamd \
/usr/bin/sa-awl \
/usr/bin/spamassassin \
/usr/lib/perl5/site_perl/${MACHINE}-linux-thread-multi/auto/Mail/SpamAssassin \
/usr/lib/perl5/site_perl/Mail/SpamAssassin.pm;

rm -rdfv \
/etc/mail/spamassassin/ \
/usr/lib/perl5/site_perl/Mail/SpamAssassin/ \
/usr/share/spamassassin/
printf "/n";
}

# Amavisd
remove_amavisd() {
printf "\033[32mRemove amavisd now...\033[0m\n\n";
rm -rfv \
/etc/amavisd.conf \
/usr/local/bin/amavisdctrl \
/usr/sbin/p0f-analyzer.pl \
/usr/sbin/amavisd-submit \
/usr/sbin/amavisd-status \
/usr/sbin/amavisd-signer \
/usr/sbin/amavisd-release \
/usr/sbin/amavisd-nanny \
/usr/sbin/amavisd-agent \
/usr/sbin/amavis-services \
/usr/sbin/amavis-mc_init.sh \
/usr/sbin/amavis-mc \
/usr/bin/amavisd \
/usr/lib/perl5/site_perl/JpegTester.pm \
/usr/lib/perl5/site_perl/TinyRedis.pm \
/var/virusmails \
/var/amavis;
echo " ";
}


# Postfix
remove_postfix() {

printf "\033[32mRemove postfix now...\033[0m\n\n";
rm -rfv \
/usr/sbin/postlock \
/usr/sbin/sendmail \
/usr/sbin/postmulti \
/usr/sbin/postsuper \
/usr/sbin/postfix \
/usr/sbin/postlog \
/usr/sbin/postalias \
/usr/sbin/postcat \
/usr/sbin/postconf \
/usr/sbin/postqueue \
/usr/sbin/postmap \
/usr/sbin/postdrop \
/usr/sbin/postkick \
/usr/bin/newaliases \
/usr/bin/mailq \
/var/ipfire/backup/addons/includes/postfix \
/usr/lib/postfix \
/var/lib/postfix;
rm -rdfv /var/spool/postfix/;
printf "\n";
}


remove_perl_modules() {
printf "\033[32mRemove Perl modules now...\033[0m\n\n";
# spf
rm -rfv \
/usr/lib/perl5/site_perl/Mail/SPF \
/usr/lib/perl5/site_perl/Mail/SPF.pm \
/usr/lib/perl5/site_perl/${MACHINE}-linux-thread-multi/auto/Mail/SPF \
/usr/bin/spfquery;

# dkim
rm -rfv \
/usr/lib/perl5/site_perl/Mail/DKIM \
/usr/lib/perl5/site_perl/Mail/DKIM.pm \
/usr/lib/perl5/site_perl/Mail/sample_mime_lite.pl \
/usr/lib/perl5/site_perl/${MACHINE}-linux-thread-multi/auto/Mail/DKIM
}

## Uninstall decoders
remove_decoder() {
printf "\033[32mRemove decoders now...\033[0m\n";
# cabextract
rm -rfv \
/usr/bin/cabextract;

# lzop
rm -rfv \
/usr/bin/lzop;

# nomarch
rm -rfv \
/usr/bin/nomarch;

# tnef
rm -rfv \
/usr/bin/tnef;

# unrar
rm -rfv \
/usr/bin/unrar;
printf "\n";
}

remove_razor2() {
# razor-agent
echo -e "\033[32mRemove Razor2 now\033[0m";
rm -rfv \
/usr/bin/razor-revoke \
/usr/bin/razor-check \
/usr/bin/razor-report \
/usr/bin/razor-client \
/usr/bin/razor-admin
rm -rdvf \
/usr/lib/perl5/site_perl/Razor2/ \
/usr/lib/perl5/site_perl/auto/Razor2/; 
}

# Delete symlinks for Postfix, Amavisd, Spamassassin and Clamav
remove_symlinks() {
echo -e "\033[32mRemove symlinks now\033[0m";
rm -rfv \
/etc/rc.d/rc0.d/{K??amavisd,K??clamav,K??postfix} \
/etc/rc.d/rc3.d/{S??amavisd,S??clamav,S??postfix} \
/etc/rc.d/rc6.d/{K??amavisd,K??clamav,K??postfix} \
/etc/init.d/{clamav,spamassassin,amavisd,postfix} \
/opt/pakfire/db/installed/extra-{postfix,amavisd,clamav};
}

remove_mailutils() {
echo -e "\033[32mRemove mailutils now: \033[0m";
rm -rfv \
/usr/bin/mail \
/usr/bin/frm \
/usr/bin/sieve \
/usr/bin/messages \
/usr/bin/mailutils-config \
/usr/bin/dotlock \
/usr/bin/mu-mh \
/usr/share/mailutils \
/usr/sbin/imap4d \
/usr/sbin/maidag \
/usr/sbin/pop3d \
/usr/sbin/comsatd \
/usr/lib/mailutils \
/usr/lib/libmu* \
/usr/lib/libmail*
}

remove_symlinks_pf() {
echo -e "\033[32mRemoving Symlinks now\033[0m";
rm -rfv \
/etc/rc.d/rc0.d/K23postfix \
/etc/rc.d/rc3.d/S46postfix \
/etc/rc.d/rc6.d/K23postfix;
rm -rfv /opt/pakfire/db/installed/extra-postfix;
echo "";
}

remove_webif() {
echo -e "\033[32mRemoving web interface now\033[0m";
rm -rfv \
/srv/web/ipfire/cgi-bin/{mgconfig,mgquarantine}.cgi \
/var/ipfire/addon-lang/mailgate.{de,en}.pl
}


##############################
# main execution start here! #
##############################

rm -rf /etc/postfix;
rm -rf /usr/bin/7z
rm -rf /usr/lib/p7zip
rm -rf /var/virusmails

if [ "${ONLYPF}" = 1 ]; then
	/etc/init.d/postfix stop;
	remove_postfix;
	remove_symlinks_pf;
else
	/etc/init.d/clamav stop;
	/etc/init.d/postfix stop;
	/etc/init.d/amavisd stop;
	pidof fetchmail;
	if [ "${?}" = "0" ]; then
		/etc/init.d/fetchmail stop;
	fi
	remove_postfix;
	remove_symlinks;
	remove_razor2;
	remove_decoder;
	remove_perl_modules;
	remove_mailutils;
	remove_webif;
	remove_sa;
fi; 

# Remove additional scripts
rm -rfv /etc/fcron.daily/mpclean.sh;
rm -rfv /usr/local/bin/{mpup.sh,mpreport.sh};
rm -rfv /cgi-bin/logs.cgi/{mptrn.dat,mpsum.dat,mplog.dat}

# Remove installer files
rm -f mpconfig.sh mptemplates.sh mpinstall.sh mpuninstall.sh mplog.dat mpsum.dat;
rm -f mptrn.dat mp_packages.tar mpman.sh mpwebif.sh dh_2048.pem razor-agent.log 
if [ -f mpreport.sh ]; then rm -f mpreport.sh mpup.sh; fi;

rm -rdfv /var/ipfire/mailgateway/maps/;

printf "\033[1;36m
--------------------------------------------------------------------------------
-                    Mail Gateway uninstallation finished                      -
--------------------------------------------------------------------------------\033[92m\n
All packages has been removed from this system now.
The /var/ipfire/mailgateway directory is not removed. It contains the main
Mailgatewey configuration files and certificates for possible reinstallation.
This can be removed manuallay if not more needed.\033[1;36m\n
--------------------------------------------------------------------------------\033[0m\n";

#End of uninstall.sh
